{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "29b483d6",
   "metadata": {
    "papermill": {
     "duration": 0.006731,
     "end_time": "2024-09-05T18:32:50.446711",
     "exception": false,
     "start_time": "2024-09-05T18:32:50.439980",
     "status": "completed"
    },
    "tags": []
   },
   "source": [
    "# Training from scratch"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "8e773f81",
   "metadata": {
    "papermill": {
     "duration": 0.003925,
     "end_time": "2024-09-05T18:32:50.457167",
     "exception": false,
     "start_time": "2024-09-05T18:32:50.453242",
     "status": "completed"
    },
    "tags": []
   },
   "source": [
    "Our task is to learn the ff. dataset consisting of noisy measurements around a quadratic curve:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "70f9f72e",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-09-05T18:32:50.468145Z",
     "iopub.status.busy": "2024-09-05T18:32:50.467697Z",
     "iopub.status.idle": "2024-09-05T18:32:50.488898Z",
     "shell.execute_reply": "2024-09-05T18:32:50.488507Z"
    },
    "papermill": {
     "duration": 0.027698,
     "end_time": "2024-09-05T18:32:50.490326",
     "exception": false,
     "start_time": "2024-09-05T18:32:50.462628",
     "status": "completed"
    },
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "from chapter import *"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "b8595b05",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-09-05T18:32:50.497780Z",
     "iopub.status.busy": "2024-09-05T18:32:50.497580Z",
     "iopub.status.idle": "2024-09-05T18:32:51.025815Z",
     "shell.execute_reply": "2024-09-05T18:32:51.024746Z"
    },
    "papermill": {
     "duration": 0.535267,
     "end_time": "2024-09-05T18:32:51.029191",
     "exception": false,
     "start_time": "2024-09-05T18:32:50.493924",
     "status": "completed"
    },
    "tags": []
   },
   "outputs": [],
   "source": [
    "%config InlineBackend.figure_format = \"svg\"\n",
    "import numpy as np\n",
    "import matplotlib.pyplot as plt\n",
    "RANDOM_SEED = 42\n",
    "np.random.seed(RANDOM_SEED)\n",
    "\n",
    "N = 1500\n",
    "X = np.linspace(-1, 5, N)\n",
    "Y = X ** 2 + 0.5 * np.random.normal(size=N, scale=3)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "3b317134",
   "metadata": {
    "papermill": {
     "duration": 0.008757,
     "end_time": "2024-09-05T18:32:51.266066",
     "exception": false,
     "start_time": "2024-09-05T18:32:51.257309",
     "status": "completed"
    },
    "tags": []
   },
   "source": [
    "Helper for loading the samples:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "53807b30",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-09-05T18:32:51.284851Z",
     "iopub.status.busy": "2024-09-05T18:32:51.284533Z",
     "iopub.status.idle": "2024-09-05T18:32:51.289967Z",
     "shell.execute_reply": "2024-09-05T18:32:51.289187Z"
    },
    "papermill": {
     "duration": 0.017968,
     "end_time": "2024-09-05T18:32:51.292651",
     "exception": false,
     "start_time": "2024-09-05T18:32:51.274683",
     "status": "completed"
    },
    "tags": []
   },
   "outputs": [],
   "source": [
    "import random\n",
    "random.seed(RANDOM_SEED)\n",
    "\n",
    "class DataLoader:\n",
    "    def __init__(self, dataset, batch_size):\n",
    "        \"\"\"Iterate over a partition of the dataset.\"\"\"\n",
    "        self.batch_size = batch_size\n",
    "        self.dataset = [(Node(x), Node(y)) for x, y in dataset]\n",
    "    \n",
    "    def load(self):\n",
    "        return random.sample(self.dataset, self.batch_size)\n",
    "\n",
    "    def __len__(self):\n",
    "        return len(self.dataset)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "f4eeaddf",
   "metadata": {
    "papermill": {
     "duration": 0.009035,
     "end_time": "2024-09-05T18:32:51.310382",
     "exception": false,
     "start_time": "2024-09-05T18:32:51.301347",
     "status": "completed"
    },
    "tags": []
   },
   "source": [
    "The function `optim_step` implements one step of SGD. Note that gradients accumulate, so we can implement batch size. But for simplicity, we only consider one training instance per update. Here `loss_fn` is the MSE between two nodes."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "b995afa2",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-09-05T18:32:51.329920Z",
     "iopub.status.busy": "2024-09-05T18:32:51.329426Z",
     "iopub.status.idle": "2024-09-05T18:32:51.333472Z",
     "shell.execute_reply": "2024-09-05T18:32:51.332899Z"
    },
    "papermill": {
     "duration": 0.015636,
     "end_time": "2024-09-05T18:32:51.335369",
     "exception": false,
     "start_time": "2024-09-05T18:32:51.319733",
     "status": "completed"
    },
    "tags": []
   },
   "outputs": [],
   "source": [
    "def optim_step(model, lr=1.0):\n",
    "    for p in model.parameters():\n",
    "        p.data -= lr * p.grad \n",
    "\n",
    "def loss_fn(y_pred, y_true):\n",
    "    return (y_pred - y_true) ** 2"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "539ec8f2",
   "metadata": {
    "papermill": {
     "duration": 0.00943,
     "end_time": "2024-09-05T18:32:51.353296",
     "exception": false,
     "start_time": "2024-09-05T18:32:51.343866",
     "status": "completed"
    },
    "tags": []
   },
   "source": [
    "Running the training algorithm:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "149c00fa",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-09-05T18:32:51.373475Z",
     "iopub.status.busy": "2024-09-05T18:32:51.373118Z",
     "iopub.status.idle": "2024-09-05T18:33:16.711409Z",
     "shell.execute_reply": "2024-09-05T18:33:16.710965Z"
    },
    "papermill": {
     "duration": 25.351447,
     "end_time": "2024-09-05T18:33:16.713241",
     "exception": false,
     "start_time": "2024-09-05T18:32:51.361794",
     "status": "completed"
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "438d45f5487d4d1896e2b76c972aff8e",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "  0%|          | 0/5000 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "from tqdm.notebook import tqdm\n",
    "\n",
    "def train(model, dataset, steps, lr=0.1, batch_size=32):\n",
    "    dataloader = DataLoader(dataset, batch_size)\n",
    "    history = []\n",
    "    for _ in tqdm(range(steps)):\n",
    "        for x, y in dataloader.load():\n",
    "            loss = loss_fn(model([x]), y)\n",
    "            loss.backward()\n",
    "            optim_step(model, lr=lr)\n",
    "            \n",
    "            model.zero_grad()\n",
    "            history.append(loss.data)\n",
    "    \n",
    "    return history\n",
    "\n",
    "dataset = list(zip(X, Y))\n",
    "model = MLP(1, [8, 4, 1], \"tanh\")\n",
    "losses = train(model, dataset, lr=0.003, batch_size=8, steps=5000)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "0212dc0a",
   "metadata": {
    "papermill": {
     "duration": 0.006672,
     "end_time": "2024-09-05T18:33:16.729571",
     "exception": false,
     "start_time": "2024-09-05T18:33:16.722899",
     "status": "completed"
    },
    "tags": []
   },
   "source": [
    "Loss curve moving average decreasing:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "1db8c74b",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-09-05T18:33:16.743663Z",
     "iopub.status.busy": "2024-09-05T18:33:16.743386Z",
     "iopub.status.idle": "2024-09-05T18:33:17.005647Z",
     "shell.execute_reply": "2024-09-05T18:33:17.004261Z"
    },
    "papermill": {
     "duration": 0.27399,
     "end_time": "2024-09-05T18:33:17.009146",
     "exception": false,
     "start_time": "2024-09-05T18:33:16.735156",
     "status": "completed"
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"494.203125pt\" height=\"266.51625pt\" viewBox=\"0 0 494.203125 266.51625\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-01T13:17:27.447606</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 266.51625 \n",
       "L 494.203125 266.51625 \n",
       "L 494.203125 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 40.603125 228.96 \n",
       "L 487.003125 228.96 \n",
       "L 487.003125 7.2 \n",
       "L 40.603125 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <path d=\"M 60.894034 228.96 \n",
       "L 60.894034 7.2 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_2\">\n",
       "      <defs>\n",
       "       <path id=\"m9814d222c3\" d=\"M 0 0 \n",
       "L 0 3.5 \n",
       "\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9814d222c3\" x=\"60.894034\" y=\"228.96\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(57.712784 243.558437) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-30\" d=\"M 2034 4250 \n",
       "Q 1547 4250 1301 3770 \n",
       "Q 1056 3291 1056 2328 \n",
       "Q 1056 1369 1301 889 \n",
       "Q 1547 409 2034 409 \n",
       "Q 2525 409 2770 889 \n",
       "Q 3016 1369 3016 2328 \n",
       "Q 3016 3291 2770 3770 \n",
       "Q 2525 4250 2034 4250 \n",
       "z\n",
       "M 2034 4750 \n",
       "Q 2819 4750 3233 4129 \n",
       "Q 3647 3509 3647 2328 \n",
       "Q 3647 1150 3233 529 \n",
       "Q 2819 -91 2034 -91 \n",
       "Q 1250 -91 836 529 \n",
       "Q 422 1150 422 2328 \n",
       "Q 422 3509 836 4129 \n",
       "Q 1250 4750 2034 4750 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <path d=\"M 111.684795 228.96 \n",
       "L 111.684795 7.2 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9814d222c3\" x=\"111.684795\" y=\"228.96\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 100 -->\n",
       "      <g transform=\"translate(102.141045 243.558437) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-31\" d=\"M 794 531 \n",
       "L 1825 531 \n",
       "L 1825 4091 \n",
       "L 703 3866 \n",
       "L 703 4441 \n",
       "L 1819 4666 \n",
       "L 2450 4666 \n",
       "L 2450 531 \n",
       "L 3481 531 \n",
       "L 3481 0 \n",
       "L 794 0 \n",
       "L 794 531 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <path d=\"M 162.475556 228.96 \n",
       "L 162.475556 7.2 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9814d222c3\" x=\"162.475556\" y=\"228.96\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 200 -->\n",
       "      <g transform=\"translate(152.931806 243.558437) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-32\" d=\"M 1228 531 \n",
       "L 3431 531 \n",
       "L 3431 0 \n",
       "L 469 0 \n",
       "L 469 531 \n",
       "Q 828 903 1448 1529 \n",
       "Q 2069 2156 2228 2338 \n",
       "Q 2531 2678 2651 2914 \n",
       "Q 2772 3150 2772 3378 \n",
       "Q 2772 3750 2511 3984 \n",
       "Q 2250 4219 1831 4219 \n",
       "Q 1534 4219 1204 4116 \n",
       "Q 875 4013 500 3803 \n",
       "L 500 4441 \n",
       "Q 881 4594 1212 4672 \n",
       "Q 1544 4750 1819 4750 \n",
       "Q 2544 4750 2975 4387 \n",
       "Q 3406 4025 3406 3419 \n",
       "Q 3406 3131 3298 2873 \n",
       "Q 3191 2616 2906 2266 \n",
       "Q 2828 2175 2409 1742 \n",
       "Q 1991 1309 1228 531 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <path d=\"M 213.266318 228.96 \n",
       "L 213.266318 7.2 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9814d222c3\" x=\"213.266318\" y=\"228.96\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 300 -->\n",
       "      <g transform=\"translate(203.722568 243.558437) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-33\" d=\"M 2597 2516 \n",
       "Q 3050 2419 3304 2112 \n",
       "Q 3559 1806 3559 1356 \n",
       "Q 3559 666 3084 287 \n",
       "Q 2609 -91 1734 -91 \n",
       "Q 1441 -91 1130 -33 \n",
       "Q 819 25 488 141 \n",
       "L 488 750 \n",
       "Q 750 597 1062 519 \n",
       "Q 1375 441 1716 441 \n",
       "Q 2309 441 2620 675 \n",
       "Q 2931 909 2931 1356 \n",
       "Q 2931 1769 2642 2001 \n",
       "Q 2353 2234 1838 2234 \n",
       "L 1294 2234 \n",
       "L 1294 2753 \n",
       "L 1863 2753 \n",
       "Q 2328 2753 2575 2939 \n",
       "Q 2822 3125 2822 3475 \n",
       "Q 2822 3834 2567 4026 \n",
       "Q 2313 4219 1838 4219 \n",
       "Q 1578 4219 1281 4162 \n",
       "Q 984 4106 628 3988 \n",
       "L 628 4550 \n",
       "Q 988 4650 1302 4700 \n",
       "Q 1616 4750 1894 4750 \n",
       "Q 2613 4750 3031 4423 \n",
       "Q 3450 4097 3450 3541 \n",
       "Q 3450 3153 3228 2886 \n",
       "Q 3006 2619 2597 2516 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-33\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <path d=\"M 264.057079 228.96 \n",
       "L 264.057079 7.2 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9814d222c3\" x=\"264.057079\" y=\"228.96\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 400 -->\n",
       "      <g transform=\"translate(254.513329 243.558437) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-34\" d=\"M 2419 4116 \n",
       "L 825 1625 \n",
       "L 2419 1625 \n",
       "L 2419 4116 \n",
       "z\n",
       "M 2253 4666 \n",
       "L 3047 4666 \n",
       "L 3047 1625 \n",
       "L 3713 1625 \n",
       "L 3713 1100 \n",
       "L 3047 1100 \n",
       "L 3047 0 \n",
       "L 2419 0 \n",
       "L 2419 1100 \n",
       "L 313 1100 \n",
       "L 313 1709 \n",
       "L 2253 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-34\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <path d=\"M 314.84784 228.96 \n",
       "L 314.84784 7.2 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9814d222c3\" x=\"314.84784\" y=\"228.96\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 500 -->\n",
       "      <g transform=\"translate(305.30409 243.558437) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-35\" d=\"M 691 4666 \n",
       "L 3169 4666 \n",
       "L 3169 4134 \n",
       "L 1269 4134 \n",
       "L 1269 2991 \n",
       "Q 1406 3038 1543 3061 \n",
       "Q 1681 3084 1819 3084 \n",
       "Q 2600 3084 3056 2656 \n",
       "Q 3513 2228 3513 1497 \n",
       "Q 3513 744 3044 326 \n",
       "Q 2575 -91 1722 -91 \n",
       "Q 1428 -91 1123 -41 \n",
       "Q 819 9 494 109 \n",
       "L 494 744 \n",
       "Q 775 591 1075 516 \n",
       "Q 1375 441 1709 441 \n",
       "Q 2250 441 2565 725 \n",
       "Q 2881 1009 2881 1497 \n",
       "Q 2881 1984 2565 2268 \n",
       "Q 2250 2553 1709 2553 \n",
       "Q 1456 2553 1204 2497 \n",
       "Q 953 2441 691 2322 \n",
       "L 691 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-35\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <path d=\"M 365.638601 228.96 \n",
       "L 365.638601 7.2 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9814d222c3\" x=\"365.638601\" y=\"228.96\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 600 -->\n",
       "      <g transform=\"translate(356.094851 243.558437) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-36\" d=\"M 2113 2584 \n",
       "Q 1688 2584 1439 2293 \n",
       "Q 1191 2003 1191 1497 \n",
       "Q 1191 994 1439 701 \n",
       "Q 1688 409 2113 409 \n",
       "Q 2538 409 2786 701 \n",
       "Q 3034 994 3034 1497 \n",
       "Q 3034 2003 2786 2293 \n",
       "Q 2538 2584 2113 2584 \n",
       "z\n",
       "M 3366 4563 \n",
       "L 3366 3988 \n",
       "Q 3128 4100 2886 4159 \n",
       "Q 2644 4219 2406 4219 \n",
       "Q 1781 4219 1451 3797 \n",
       "Q 1122 3375 1075 2522 \n",
       "Q 1259 2794 1537 2939 \n",
       "Q 1816 3084 2150 3084 \n",
       "Q 2853 3084 3261 2657 \n",
       "Q 3669 2231 3669 1497 \n",
       "Q 3669 778 3244 343 \n",
       "Q 2819 -91 2113 -91 \n",
       "Q 1303 -91 875 529 \n",
       "Q 447 1150 447 2328 \n",
       "Q 447 3434 972 4092 \n",
       "Q 1497 4750 2381 4750 \n",
       "Q 2619 4750 2861 4703 \n",
       "Q 3103 4656 3366 4563 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-36\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <path d=\"M 416.429362 228.96 \n",
       "L 416.429362 7.2 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9814d222c3\" x=\"416.429362\" y=\"228.96\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 700 -->\n",
       "      <g transform=\"translate(406.885612 243.558437) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-37\" d=\"M 525 4666 \n",
       "L 3525 4666 \n",
       "L 3525 4397 \n",
       "L 1831 0 \n",
       "L 1172 0 \n",
       "L 2766 4134 \n",
       "L 525 4134 \n",
       "L 525 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-37\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <path d=\"M 467.220124 228.96 \n",
       "L 467.220124 7.2 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m9814d222c3\" x=\"467.220124\" y=\"228.96\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- 800 -->\n",
       "      <g transform=\"translate(457.676374 243.558437) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-38\" d=\"M 2034 2216 \n",
       "Q 1584 2216 1326 1975 \n",
       "Q 1069 1734 1069 1313 \n",
       "Q 1069 891 1326 650 \n",
       "Q 1584 409 2034 409 \n",
       "Q 2484 409 2743 651 \n",
       "Q 3003 894 3003 1313 \n",
       "Q 3003 1734 2745 1975 \n",
       "Q 2488 2216 2034 2216 \n",
       "z\n",
       "M 1403 2484 \n",
       "Q 997 2584 770 2862 \n",
       "Q 544 3141 544 3541 \n",
       "Q 544 4100 942 4425 \n",
       "Q 1341 4750 2034 4750 \n",
       "Q 2731 4750 3128 4425 \n",
       "Q 3525 4100 3525 3541 \n",
       "Q 3525 3141 3298 2862 \n",
       "Q 3072 2584 2669 2484 \n",
       "Q 3125 2378 3379 2068 \n",
       "Q 3634 1759 3634 1313 \n",
       "Q 3634 634 3220 271 \n",
       "Q 2806 -91 2034 -91 \n",
       "Q 1263 -91 848 271 \n",
       "Q 434 634 434 1313 \n",
       "Q 434 1759 690 2068 \n",
       "Q 947 2378 1403 2484 \n",
       "z\n",
       "M 1172 3481 \n",
       "Q 1172 3119 1398 2916 \n",
       "Q 1625 2713 2034 2713 \n",
       "Q 2441 2713 2670 2916 \n",
       "Q 2900 3119 2900 3481 \n",
       "Q 2900 3844 2670 4047 \n",
       "Q 2441 4250 2034 4250 \n",
       "Q 1625 4250 1398 4047 \n",
       "Q 1172 3844 1172 3481 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-38\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"127.246094\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_10\">\n",
       "     <!-- steps -->\n",
       "     <g transform=\"translate(250.382813 257.236562) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-73\" d=\"M 2834 3397 \n",
       "L 2834 2853 \n",
       "Q 2591 2978 2328 3040 \n",
       "Q 2066 3103 1784 3103 \n",
       "Q 1356 3103 1142 2972 \n",
       "Q 928 2841 928 2578 \n",
       "Q 928 2378 1081 2264 \n",
       "Q 1234 2150 1697 2047 \n",
       "L 1894 2003 \n",
       "Q 2506 1872 2764 1633 \n",
       "Q 3022 1394 3022 966 \n",
       "Q 3022 478 2636 193 \n",
       "Q 2250 -91 1575 -91 \n",
       "Q 1294 -91 989 -36 \n",
       "Q 684 19 347 128 \n",
       "L 347 722 \n",
       "Q 666 556 975 473 \n",
       "Q 1284 391 1588 391 \n",
       "Q 1994 391 2212 530 \n",
       "Q 2431 669 2431 922 \n",
       "Q 2431 1156 2273 1281 \n",
       "Q 2116 1406 1581 1522 \n",
       "L 1381 1569 \n",
       "Q 847 1681 609 1914 \n",
       "Q 372 2147 372 2553 \n",
       "Q 372 3047 722 3315 \n",
       "Q 1072 3584 1716 3584 \n",
       "Q 2034 3584 2315 3537 \n",
       "Q 2597 3491 2834 3397 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-74\" d=\"M 1172 4494 \n",
       "L 1172 3500 \n",
       "L 2356 3500 \n",
       "L 2356 3053 \n",
       "L 1172 3053 \n",
       "L 1172 1153 \n",
       "Q 1172 725 1289 603 \n",
       "Q 1406 481 1766 481 \n",
       "L 2356 481 \n",
       "L 2356 0 \n",
       "L 1766 0 \n",
       "Q 1100 0 847 248 \n",
       "Q 594 497 594 1153 \n",
       "L 594 3053 \n",
       "L 172 3053 \n",
       "L 172 3500 \n",
       "L 594 3500 \n",
       "L 594 4494 \n",
       "L 1172 4494 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-65\" d=\"M 3597 1894 \n",
       "L 3597 1613 \n",
       "L 953 1613 \n",
       "Q 991 1019 1311 708 \n",
       "Q 1631 397 2203 397 \n",
       "Q 2534 397 2845 478 \n",
       "Q 3156 559 3463 722 \n",
       "L 3463 178 \n",
       "Q 3153 47 2828 -22 \n",
       "Q 2503 -91 2169 -91 \n",
       "Q 1331 -91 842 396 \n",
       "Q 353 884 353 1716 \n",
       "Q 353 2575 817 3079 \n",
       "Q 1281 3584 2069 3584 \n",
       "Q 2775 3584 3186 3129 \n",
       "Q 3597 2675 3597 1894 \n",
       "z\n",
       "M 3022 2063 \n",
       "Q 3016 2534 2758 2815 \n",
       "Q 2500 3097 2075 3097 \n",
       "Q 1594 3097 1305 2825 \n",
       "Q 1016 2553 972 2059 \n",
       "L 3022 2063 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-70\" d=\"M 1159 525 \n",
       "L 1159 -1331 \n",
       "L 581 -1331 \n",
       "L 581 3500 \n",
       "L 1159 3500 \n",
       "L 1159 2969 \n",
       "Q 1341 3281 1617 3432 \n",
       "Q 1894 3584 2278 3584 \n",
       "Q 2916 3584 3314 3078 \n",
       "Q 3713 2572 3713 1747 \n",
       "Q 3713 922 3314 415 \n",
       "Q 2916 -91 2278 -91 \n",
       "Q 1894 -91 1617 61 \n",
       "Q 1341 213 1159 525 \n",
       "z\n",
       "M 3116 1747 \n",
       "Q 3116 2381 2855 2742 \n",
       "Q 2594 3103 2138 3103 \n",
       "Q 1681 3103 1420 2742 \n",
       "Q 1159 2381 1159 1747 \n",
       "Q 1159 1113 1420 752 \n",
       "Q 1681 391 2138 391 \n",
       "Q 2594 391 2855 752 \n",
       "Q 3116 1113 3116 1747 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-73\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-74\" x=\"52.099609\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"91.308594\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-70\" x=\"152.832031\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-73\" x=\"216.308594\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <path d=\"M 40.603125 222.505427 \n",
       "L 487.003125 222.505427 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"m07ddcb5391\" d=\"M 0 0 \n",
       "L -3.5 0 \n",
       "\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m07ddcb5391\" x=\"40.603125\" y=\"222.505427\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(27.240625 226.304646) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <path d=\"M 40.603125 173.641984 \n",
       "L 487.003125 173.641984 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m07ddcb5391\" x=\"40.603125\" y=\"173.641984\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 20 -->\n",
       "      <g transform=\"translate(20.878125 177.441203) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <path d=\"M 40.603125 124.77854 \n",
       "L 487.003125 124.77854 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m07ddcb5391\" x=\"40.603125\" y=\"124.77854\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 40 -->\n",
       "      <g transform=\"translate(20.878125 128.577759) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-34\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <path d=\"M 40.603125 75.915097 \n",
       "L 487.003125 75.915097 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m07ddcb5391\" x=\"40.603125\" y=\"75.915097\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 60 -->\n",
       "      <g transform=\"translate(20.878125 79.714316) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-36\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <path d=\"M 40.603125 27.051653 \n",
       "L 487.003125 27.051653 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-opacity: 0.6; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m07ddcb5391\" x=\"40.603125\" y=\"27.051653\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 80 -->\n",
       "      <g transform=\"translate(20.878125 30.850872) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-38\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- MSE -->\n",
       "     <g transform=\"translate(14.798438 128.727656) rotate(-90) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-4d\" d=\"M 628 4666 \n",
       "L 1569 4666 \n",
       "L 2759 1491 \n",
       "L 3956 4666 \n",
       "L 4897 4666 \n",
       "L 4897 0 \n",
       "L 4281 0 \n",
       "L 4281 4097 \n",
       "L 3078 897 \n",
       "L 2444 897 \n",
       "L 1241 4097 \n",
       "L 1241 0 \n",
       "L 628 0 \n",
       "L 628 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-53\" d=\"M 3425 4513 \n",
       "L 3425 3897 \n",
       "Q 3066 4069 2747 4153 \n",
       "Q 2428 4238 2131 4238 \n",
       "Q 1616 4238 1336 4038 \n",
       "Q 1056 3838 1056 3469 \n",
       "Q 1056 3159 1242 3001 \n",
       "Q 1428 2844 1947 2747 \n",
       "L 2328 2669 \n",
       "Q 3034 2534 3370 2195 \n",
       "Q 3706 1856 3706 1288 \n",
       "Q 3706 609 3251 259 \n",
       "Q 2797 -91 1919 -91 \n",
       "Q 1588 -91 1214 -16 \n",
       "Q 841 59 441 206 \n",
       "L 441 856 \n",
       "Q 825 641 1194 531 \n",
       "Q 1563 422 1919 422 \n",
       "Q 2459 422 2753 634 \n",
       "Q 3047 847 3047 1241 \n",
       "Q 3047 1584 2836 1778 \n",
       "Q 2625 1972 2144 2069 \n",
       "L 1759 2144 \n",
       "Q 1053 2284 737 2584 \n",
       "Q 422 2884 422 3419 \n",
       "Q 422 4038 858 4394 \n",
       "Q 1294 4750 2059 4750 \n",
       "Q 2388 4750 2728 4690 \n",
       "Q 3069 4631 3425 4513 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-45\" d=\"M 628 4666 \n",
       "L 3578 4666 \n",
       "L 3578 4134 \n",
       "L 1259 4134 \n",
       "L 1259 2753 \n",
       "L 3481 2753 \n",
       "L 3481 2222 \n",
       "L 1259 2222 \n",
       "L 1259 531 \n",
       "L 3634 531 \n",
       "L 3634 0 \n",
       "L 628 0 \n",
       "L 628 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-4d\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-53\" x=\"86.279297\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-45\" x=\"149.755859\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_29\">\n",
       "    <path d=\"M 60.894034 17.28 \n",
       "L 61.401942 133.448027 \n",
       "L 61.909849 124.819271 \n",
       "L 62.417757 166.624096 \n",
       "L 62.925665 174.044013 \n",
       "L 63.433572 172.635173 \n",
       "L 63.94148 195.981532 \n",
       "L 64.449387 194.02982 \n",
       "L 64.957295 208.197389 \n",
       "L 65.465203 186.886037 \n",
       "L 65.97311 177.789933 \n",
       "L 66.481018 179.618386 \n",
       "L 66.988925 206.199982 \n",
       "L 67.496833 209.911308 \n",
       "L 68.004741 178.734105 \n",
       "L 68.512648 191.88606 \n",
       "L 69.020556 170.944811 \n",
       "L 69.528463 203.545227 \n",
       "L 70.036371 207.342877 \n",
       "L 70.544279 199.908186 \n",
       "L 71.052186 212.162863 \n",
       "L 71.560094 205.405632 \n",
       "L 72.068002 212.776215 \n",
       "L 72.575909 208.204376 \n",
       "L 73.083817 209.990795 \n",
       "L 73.591724 204.32717 \n",
       "L 74.099632 210.632852 \n",
       "L 74.60754 212.077881 \n",
       "L 75.115447 212.219166 \n",
       "L 75.623355 207.358329 \n",
       "L 76.131262 206.494822 \n",
       "L 76.63917 204.061384 \n",
       "L 77.147078 207.323044 \n",
       "L 77.654985 205.384438 \n",
       "L 78.162893 209.47772 \n",
       "L 78.670801 214.657548 \n",
       "L 79.178708 204.056862 \n",
       "L 80.194523 214.480388 \n",
       "L 80.702431 211.534509 \n",
       "L 81.210339 213.781603 \n",
       "L 81.718246 210.154491 \n",
       "L 82.226154 202.112979 \n",
       "L 82.734061 203.535113 \n",
       "L 83.241969 196.880006 \n",
       "L 83.749877 206.561779 \n",
       "L 84.257784 211.591073 \n",
       "L 85.273599 210.634134 \n",
       "L 85.781507 200.379387 \n",
       "L 86.289415 203.226861 \n",
       "L 86.797322 213.158644 \n",
       "L 87.813138 199.048796 \n",
       "L 88.321045 199.687795 \n",
       "L 88.828953 203.14532 \n",
       "L 89.33686 214.882436 \n",
       "L 89.844768 202.947428 \n",
       "L 90.352676 207.655423 \n",
       "L 90.860583 206.21105 \n",
       "L 91.368491 210.386201 \n",
       "L 91.876398 212.270318 \n",
       "L 92.384306 197.80653 \n",
       "L 92.892214 212.850521 \n",
       "L 93.400121 214.896943 \n",
       "L 94.415936 208.792689 \n",
       "L 94.923844 213.174936 \n",
       "L 95.431752 210.834887 \n",
       "L 95.939659 214.506241 \n",
       "L 96.447567 212.384298 \n",
       "L 96.955475 208.161258 \n",
       "L 97.463382 208.054482 \n",
       "L 97.97129 202.895371 \n",
       "L 98.479197 199.601054 \n",
       "L 98.987105 208.148569 \n",
       "L 99.495013 208.469756 \n",
       "L 100.00292 215.457044 \n",
       "L 100.510828 214.502838 \n",
       "L 101.018735 210.706742 \n",
       "L 101.526643 213.959774 \n",
       "L 102.034551 213.536434 \n",
       "L 102.542458 215.487513 \n",
       "L 103.050366 212.609232 \n",
       "L 103.558273 215.272824 \n",
       "L 104.066181 196.659337 \n",
       "L 104.574089 209.821397 \n",
       "L 105.081996 209.446401 \n",
       "L 105.589904 209.739962 \n",
       "L 106.097812 213.416346 \n",
       "L 106.605719 213.074649 \n",
       "L 107.113627 213.526527 \n",
       "L 107.621534 205.744464 \n",
       "L 108.129442 209.9232 \n",
       "L 108.63735 205.807024 \n",
       "L 109.145257 216.99306 \n",
       "L 109.653165 215.713327 \n",
       "L 110.161072 204.041864 \n",
       "L 110.66898 212.376257 \n",
       "L 111.176888 215.083264 \n",
       "L 111.684795 207.983485 \n",
       "L 112.192703 213.225744 \n",
       "L 112.70061 213.18996 \n",
       "L 113.208518 206.65908 \n",
       "L 113.716426 211.444422 \n",
       "L 114.224333 214.059239 \n",
       "L 114.732241 207.543587 \n",
       "L 115.240149 211.632935 \n",
       "L 115.748056 207.223685 \n",
       "L 116.255964 214.767277 \n",
       "L 116.763871 209.975166 \n",
       "L 117.271779 213.080542 \n",
       "L 117.779687 214.750284 \n",
       "L 118.287594 214.250985 \n",
       "L 118.795502 213.272022 \n",
       "L 119.303409 208.748754 \n",
       "L 119.811317 213.219103 \n",
       "L 120.319225 214.945769 \n",
       "L 120.827132 212.92765 \n",
       "L 121.33504 212.812956 \n",
       "L 121.842948 206.127067 \n",
       "L 122.350855 214.097799 \n",
       "L 123.36667 194.034653 \n",
       "L 123.874578 212.408002 \n",
       "L 124.382486 214.866071 \n",
       "L 124.890393 218.06847 \n",
       "L 125.398301 214.077389 \n",
       "L 125.906208 208.1563 \n",
       "L 126.414116 217.496558 \n",
       "L 126.922024 211.160311 \n",
       "L 127.429931 215.158601 \n",
       "L 127.937839 210.427361 \n",
       "L 128.445746 210.801508 \n",
       "L 128.953654 209.810991 \n",
       "L 129.461562 215.177014 \n",
       "L 129.969469 210.804126 \n",
       "L 130.477377 209.202291 \n",
       "L 130.985285 213.10798 \n",
       "L 131.493192 209.809118 \n",
       "L 132.0011 214.040653 \n",
       "L 132.509007 212.299615 \n",
       "L 133.016915 209.484761 \n",
       "L 133.524823 214.549878 \n",
       "L 134.03273 211.517647 \n",
       "L 134.540638 195.745739 \n",
       "L 135.048545 209.969844 \n",
       "L 135.556453 211.800244 \n",
       "L 136.064361 215.013058 \n",
       "L 136.572268 214.323563 \n",
       "L 137.080176 204.402287 \n",
       "L 137.588083 213.746015 \n",
       "L 138.095991 213.311568 \n",
       "L 138.603899 211.685061 \n",
       "L 139.111806 211.894848 \n",
       "L 139.619714 208.774552 \n",
       "L 140.127622 215.911854 \n",
       "L 140.635529 215.574215 \n",
       "L 141.143437 214.585331 \n",
       "L 141.651344 215.628849 \n",
       "L 142.159252 216.051816 \n",
       "L 142.66716 216.05546 \n",
       "L 143.175067 216.450391 \n",
       "L 144.69879 214.253603 \n",
       "L 145.206698 213.363768 \n",
       "L 145.714605 213.043471 \n",
       "L 146.222513 213.239841 \n",
       "L 146.73042 215.865119 \n",
       "L 148.254143 210.423571 \n",
       "L 148.762051 213.593522 \n",
       "L 149.269959 213.958291 \n",
       "L 149.777866 206.867595 \n",
       "L 150.285774 214.087368 \n",
       "L 150.793681 214.679693 \n",
       "L 151.301589 215.884823 \n",
       "L 151.809497 215.566616 \n",
       "L 152.317404 213.157173 \n",
       "L 152.825312 212.866593 \n",
       "L 153.333219 213.971607 \n",
       "L 153.841127 214.579947 \n",
       "L 154.349035 212.265461 \n",
       "L 154.856942 216.312775 \n",
       "L 155.36485 213.503377 \n",
       "L 155.872757 217.348751 \n",
       "L 156.380665 212.378517 \n",
       "L 156.888573 213.967031 \n",
       "L 157.39648 210.730308 \n",
       "L 157.904388 215.507094 \n",
       "L 158.412296 211.720833 \n",
       "L 158.920203 215.53017 \n",
       "L 159.428111 209.890803 \n",
       "L 159.936018 212.698949 \n",
       "L 160.443926 214.476441 \n",
       "L 160.951834 215.136445 \n",
       "L 161.459741 213.533821 \n",
       "L 161.967649 214.778985 \n",
       "L 162.475556 214.618666 \n",
       "L 162.983464 210.145845 \n",
       "L 163.491372 212.637383 \n",
       "L 163.999279 213.736075 \n",
       "L 164.507187 212.049285 \n",
       "L 165.015095 215.453822 \n",
       "L 165.523002 214.39845 \n",
       "L 166.03091 213.752939 \n",
       "L 166.538817 217.14416 \n",
       "L 167.046725 211.610015 \n",
       "L 167.554633 216.852396 \n",
       "L 168.06254 214.722907 \n",
       "L 168.570448 211.410265 \n",
       "L 170.094171 216.633341 \n",
       "L 170.602078 212.616126 \n",
       "L 171.109986 217.77018 \n",
       "L 171.617893 212.366598 \n",
       "L 172.125801 215.163278 \n",
       "L 172.633709 211.935021 \n",
       "L 173.141616 209.475257 \n",
       "L 173.649524 213.732472 \n",
       "L 174.157432 211.480633 \n",
       "L 174.665339 214.242283 \n",
       "L 175.173247 214.186647 \n",
       "L 175.681154 210.141954 \n",
       "L 176.189062 213.473995 \n",
       "L 176.69697 215.347139 \n",
       "L 177.204877 214.11309 \n",
       "L 177.712785 214.528497 \n",
       "L 178.220692 213.034784 \n",
       "L 178.7286 206.267317 \n",
       "L 179.236508 213.5935 \n",
       "L 180.252323 213.846987 \n",
       "L 180.76023 208.483197 \n",
       "L 181.268138 212.051437 \n",
       "L 181.776046 211.559022 \n",
       "L 182.283953 213.608068 \n",
       "L 182.791861 214.176381 \n",
       "L 183.299769 213.819689 \n",
       "L 183.807676 214.733944 \n",
       "L 184.315584 214.874916 \n",
       "L 185.331399 210.796103 \n",
       "L 185.839307 215.307701 \n",
       "L 186.855122 218.88 \n",
       "L 187.363029 216.577357 \n",
       "L 187.870937 216.257694 \n",
       "L 188.378845 218.12809 \n",
       "L 188.886752 212.750164 \n",
       "L 189.39466 217.1249 \n",
       "L 189.902567 214.778422 \n",
       "L 190.410475 198.213777 \n",
       "L 190.918383 209.526801 \n",
       "L 191.42629 214.09154 \n",
       "L 191.934198 211.615242 \n",
       "L 192.442106 213.047236 \n",
       "L 192.950013 214.835445 \n",
       "L 193.457921 209.030324 \n",
       "L 193.965828 217.654388 \n",
       "L 194.473736 216.715748 \n",
       "L 194.981644 214.909292 \n",
       "L 195.489551 214.240138 \n",
       "L 195.997459 209.301151 \n",
       "L 196.505366 216.613215 \n",
       "L 197.013274 211.603422 \n",
       "L 197.521182 213.126274 \n",
       "L 198.029089 211.892135 \n",
       "L 198.536997 213.262727 \n",
       "L 199.044904 214.176729 \n",
       "L 199.552812 216.026062 \n",
       "L 200.06072 215.691839 \n",
       "L 200.568627 213.455573 \n",
       "L 201.076535 213.238947 \n",
       "L 201.584443 213.66217 \n",
       "L 202.09235 213.087801 \n",
       "L 202.600258 214.312245 \n",
       "L 203.108165 216.162177 \n",
       "L 203.616073 215.830339 \n",
       "L 204.123981 211.52747 \n",
       "L 205.139796 217.390748 \n",
       "L 205.647703 213.826104 \n",
       "L 206.155611 212.582525 \n",
       "L 206.663519 210.46421 \n",
       "L 207.171426 217.359346 \n",
       "L 207.679334 213.364171 \n",
       "L 208.187242 216.051241 \n",
       "L 208.695149 210.028606 \n",
       "L 209.203057 213.791158 \n",
       "L 209.710964 212.960577 \n",
       "L 210.218872 212.858958 \n",
       "L 210.72678 213.649956 \n",
       "L 211.742595 213.392202 \n",
       "L 212.250502 215.857841 \n",
       "L 213.266318 209.219949 \n",
       "L 213.774225 216.054351 \n",
       "L 214.282133 212.918754 \n",
       "L 214.79004 215.828375 \n",
       "L 215.297948 214.800699 \n",
       "L 215.805856 213.234215 \n",
       "L 216.821671 212.354816 \n",
       "L 217.329579 215.516393 \n",
       "L 217.837486 215.812818 \n",
       "L 218.345394 197.726387 \n",
       "L 218.853301 217.011983 \n",
       "L 219.361209 214.859698 \n",
       "L 219.869117 213.880704 \n",
       "L 220.377024 210.129775 \n",
       "L 220.884932 215.367516 \n",
       "L 221.392839 214.647444 \n",
       "L 221.900747 204.730332 \n",
       "L 222.408655 212.07221 \n",
       "L 222.916562 210.760988 \n",
       "L 223.42447 213.350289 \n",
       "L 223.932377 210.515947 \n",
       "L 224.440285 211.114791 \n",
       "L 224.948193 215.344956 \n",
       "L 225.4561 214.596259 \n",
       "L 225.964008 209.939071 \n",
       "L 226.471916 213.19954 \n",
       "L 226.979823 215.366758 \n",
       "L 227.487731 215.01217 \n",
       "L 227.995638 215.229299 \n",
       "L 228.503546 211.20755 \n",
       "L 229.011454 216.232745 \n",
       "L 230.027269 215.743867 \n",
       "L 230.535176 214.696585 \n",
       "L 231.043084 214.019386 \n",
       "L 231.550992 214.616747 \n",
       "L 232.058899 212.442772 \n",
       "L 232.566807 215.571178 \n",
       "L 233.582622 214.203399 \n",
       "L 234.09053 216.683023 \n",
       "L 234.598437 216.929131 \n",
       "L 235.106345 212.80775 \n",
       "L 235.614253 214.380424 \n",
       "L 236.12216 214.785047 \n",
       "L 236.630068 213.829264 \n",
       "L 237.137975 216.776084 \n",
       "L 237.645883 215.292428 \n",
       "L 238.153791 215.495818 \n",
       "L 238.661698 212.923951 \n",
       "L 239.169606 214.175901 \n",
       "L 239.677513 215.747386 \n",
       "L 240.185421 211.871944 \n",
       "L 240.693329 217.150392 \n",
       "L 241.201236 212.136444 \n",
       "L 241.709144 210.93089 \n",
       "L 242.217051 210.844644 \n",
       "L 242.724959 215.049834 \n",
       "L 243.232867 215.905428 \n",
       "L 243.740774 215.158676 \n",
       "L 244.248682 213.054437 \n",
       "L 244.75659 213.011283 \n",
       "L 245.264497 216.421561 \n",
       "L 245.772405 209.59022 \n",
       "L 246.280312 214.785351 \n",
       "L 246.78822 216.825202 \n",
       "L 247.296128 212.356699 \n",
       "L 247.804035 215.146981 \n",
       "L 248.311943 216.680134 \n",
       "L 248.81985 215.330987 \n",
       "L 249.327758 216.634058 \n",
       "L 249.835666 213.945451 \n",
       "L 250.343573 212.800266 \n",
       "L 250.851481 212.372613 \n",
       "L 251.359389 210.578692 \n",
       "L 251.867296 216.538933 \n",
       "L 252.375204 213.842462 \n",
       "L 252.883111 213.01096 \n",
       "L 253.391019 215.194866 \n",
       "L 253.898927 214.123637 \n",
       "L 254.406834 216.749041 \n",
       "L 254.914742 214.786827 \n",
       "L 255.422649 215.179871 \n",
       "L 255.930557 213.820538 \n",
       "L 256.438465 213.568803 \n",
       "L 257.45428 214.733968 \n",
       "L 257.962187 213.413209 \n",
       "L 258.470095 214.51863 \n",
       "L 258.978003 213.565539 \n",
       "L 259.48591 216.09997 \n",
       "L 259.993818 216.391496 \n",
       "L 260.501726 216.495262 \n",
       "L 261.009633 214.135632 \n",
       "L 261.517541 209.018674 \n",
       "L 262.025448 215.785319 \n",
       "L 262.533356 214.708383 \n",
       "L 263.041264 217.43621 \n",
       "L 263.549171 216.40989 \n",
       "L 264.057079 217.219897 \n",
       "L 264.564986 216.287672 \n",
       "L 265.072894 212.739262 \n",
       "L 265.580802 212.437239 \n",
       "L 266.088709 211.772259 \n",
       "L 266.596617 213.412769 \n",
       "L 267.104524 216.078067 \n",
       "L 267.612432 216.477252 \n",
       "L 268.12034 215.38596 \n",
       "L 268.628247 213.597096 \n",
       "L 269.136155 215.838731 \n",
       "L 269.644063 216.898581 \n",
       "L 270.15197 209.69048 \n",
       "L 270.659878 214.498316 \n",
       "L 271.167785 213.472652 \n",
       "L 271.675693 213.980581 \n",
       "L 272.183601 213.214699 \n",
       "L 272.691508 211.775781 \n",
       "L 273.199416 212.228836 \n",
       "L 273.707323 216.639218 \n",
       "L 274.215231 214.641466 \n",
       "L 274.723139 215.395788 \n",
       "L 275.231046 213.879654 \n",
       "L 275.738954 210.25807 \n",
       "L 276.246861 217.333399 \n",
       "L 276.754769 214.596639 \n",
       "L 277.262677 216.955672 \n",
       "L 277.770584 217.417617 \n",
       "L 278.278492 212.336423 \n",
       "L 278.7864 215.670518 \n",
       "L 279.294307 212.880402 \n",
       "L 279.802215 211.872466 \n",
       "L 280.310122 215.391873 \n",
       "L 280.81803 215.70992 \n",
       "L 281.325938 212.185815 \n",
       "L 281.833845 213.936396 \n",
       "L 282.341753 213.530336 \n",
       "L 282.84966 212.189949 \n",
       "L 283.357568 210.070702 \n",
       "L 283.865476 215.214555 \n",
       "L 284.373383 216.052266 \n",
       "L 284.881291 216.433909 \n",
       "L 285.389199 214.67797 \n",
       "L 285.897106 212.404146 \n",
       "L 286.405014 213.080214 \n",
       "L 286.912921 213.090969 \n",
       "L 287.420829 213.483892 \n",
       "L 287.928737 213.669326 \n",
       "L 288.436644 216.396405 \n",
       "L 288.944552 214.820372 \n",
       "L 289.452459 212.803746 \n",
       "L 289.960367 213.977346 \n",
       "L 290.468275 216.909829 \n",
       "L 290.976182 217.367017 \n",
       "L 291.991997 210.751098 \n",
       "L 292.499905 209.897285 \n",
       "L 293.007813 216.959094 \n",
       "L 293.51572 209.989732 \n",
       "L 294.023628 215.770928 \n",
       "L 294.531536 213.222453 \n",
       "L 295.039443 213.804756 \n",
       "L 295.547351 211.670205 \n",
       "L 296.055258 216.133445 \n",
       "L 296.563166 215.968618 \n",
       "L 297.071074 215.363182 \n",
       "L 297.578981 216.929684 \n",
       "L 298.086889 216.605689 \n",
       "L 298.594796 211.012444 \n",
       "L 299.102704 212.233659 \n",
       "L 299.610612 215.958127 \n",
       "L 300.118519 215.311204 \n",
       "L 300.626427 211.20158 \n",
       "L 301.134334 213.772044 \n",
       "L 301.642242 215.667094 \n",
       "L 302.15015 209.533963 \n",
       "L 302.658057 210.792955 \n",
       "L 303.165965 215.867097 \n",
       "L 303.673873 215.660835 \n",
       "L 304.18178 209.613817 \n",
       "L 304.689688 213.569251 \n",
       "L 305.197595 215.425052 \n",
       "L 306.213411 215.497478 \n",
       "L 306.721318 213.110013 \n",
       "L 307.229226 217.214822 \n",
       "L 307.737133 213.946906 \n",
       "L 308.245041 215.451581 \n",
       "L 308.752949 214.883542 \n",
       "L 309.260856 212.832896 \n",
       "L 309.768764 216.378607 \n",
       "L 310.276671 216.766906 \n",
       "L 310.784579 214.212346 \n",
       "L 311.292487 215.148212 \n",
       "L 311.800394 212.461194 \n",
       "L 312.308302 214.943568 \n",
       "L 312.81621 214.381908 \n",
       "L 313.324117 213.459481 \n",
       "L 313.832025 216.38829 \n",
       "L 314.339932 211.774094 \n",
       "L 314.84784 215.896071 \n",
       "L 315.355748 213.042039 \n",
       "L 315.863655 213.576704 \n",
       "L 316.371563 213.30041 \n",
       "L 316.87947 218.029139 \n",
       "L 317.387378 216.910982 \n",
       "L 317.895286 209.83548 \n",
       "L 318.403193 215.426601 \n",
       "L 319.419008 215.574728 \n",
       "L 319.926916 213.720339 \n",
       "L 320.434824 212.784664 \n",
       "L 320.942731 208.623609 \n",
       "L 321.450639 215.024093 \n",
       "L 321.958547 216.288999 \n",
       "L 322.974362 210.757458 \n",
       "L 323.482269 210.261364 \n",
       "L 323.990177 215.758254 \n",
       "L 324.498085 217.155139 \n",
       "L 325.005992 214.433438 \n",
       "L 325.5139 214.246313 \n",
       "L 326.021807 211.234925 \n",
       "L 327.037623 216.000311 \n",
       "L 327.54553 216.793083 \n",
       "L 328.053438 214.72548 \n",
       "L 328.561346 214.962217 \n",
       "L 329.069253 211.857166 \n",
       "L 329.577161 215.650652 \n",
       "L 330.085068 216.140873 \n",
       "L 330.592976 217.567616 \n",
       "L 331.100884 213.412285 \n",
       "L 331.608791 211.735208 \n",
       "L 332.116699 216.905151 \n",
       "L 332.624606 215.942582 \n",
       "L 333.640422 215.326342 \n",
       "L 334.148329 214.254429 \n",
       "L 334.656237 214.401555 \n",
       "L 335.164144 215.349328 \n",
       "L 335.672052 216.601485 \n",
       "L 336.17996 218.260061 \n",
       "L 336.687867 213.325404 \n",
       "L 337.195775 217.548259 \n",
       "L 337.703683 213.129375 \n",
       "L 338.21159 212.644845 \n",
       "L 339.227405 216.232794 \n",
       "L 339.735313 214.57287 \n",
       "L 340.243221 214.936913 \n",
       "L 340.751128 216.239756 \n",
       "L 341.259036 215.160402 \n",
       "L 341.766943 215.903497 \n",
       "L 342.274851 212.807624 \n",
       "L 342.782759 212.175369 \n",
       "L 343.290666 215.017011 \n",
       "L 343.798574 214.430007 \n",
       "L 344.306481 215.003594 \n",
       "L 344.814389 212.594567 \n",
       "L 345.322297 214.787087 \n",
       "L 345.830204 215.600049 \n",
       "L 346.338112 210.081048 \n",
       "L 346.84602 214.651741 \n",
       "L 347.353927 214.33357 \n",
       "L 347.861835 216.454113 \n",
       "L 348.369742 214.387902 \n",
       "L 348.87765 215.28032 \n",
       "L 349.385558 215.695555 \n",
       "L 349.893465 209.62074 \n",
       "L 350.401373 213.073833 \n",
       "L 350.90928 215.463947 \n",
       "L 351.417188 213.549835 \n",
       "L 351.925096 213.891871 \n",
       "L 352.433003 218.564347 \n",
       "L 352.940911 215.882022 \n",
       "L 353.448818 217.695086 \n",
       "L 353.956726 212.663333 \n",
       "L 354.972541 216.891286 \n",
       "L 355.480449 213.977291 \n",
       "L 355.988357 215.969833 \n",
       "L 356.496264 213.908561 \n",
       "L 357.004172 213.851808 \n",
       "L 357.512079 217.848887 \n",
       "L 358.019987 216.842614 \n",
       "L 358.527895 217.24251 \n",
       "L 359.035802 214.012822 \n",
       "L 359.54371 215.891269 \n",
       "L 360.559525 213.50572 \n",
       "L 361.067433 212.916779 \n",
       "L 361.57534 212.753728 \n",
       "L 362.083248 213.55942 \n",
       "L 362.591155 217.367652 \n",
       "L 363.099063 217.017238 \n",
       "L 363.606971 217.148501 \n",
       "L 364.114878 213.519894 \n",
       "L 364.622786 216.899441 \n",
       "L 365.130694 215.594928 \n",
       "L 365.638601 216.112474 \n",
       "L 366.146509 210.324531 \n",
       "L 366.654416 210.748802 \n",
       "L 367.162324 217.461902 \n",
       "L 367.670232 215.016334 \n",
       "L 368.178139 214.307062 \n",
       "L 368.686047 215.084285 \n",
       "L 369.193954 214.932239 \n",
       "L 369.701862 216.141934 \n",
       "L 370.20977 215.653433 \n",
       "L 370.717677 215.403603 \n",
       "L 371.225585 214.922878 \n",
       "L 371.733493 214.780535 \n",
       "L 372.2414 216.522386 \n",
       "L 372.749308 212.828986 \n",
       "L 373.257215 216.507842 \n",
       "L 373.765123 215.104626 \n",
       "L 374.273031 216.673932 \n",
       "L 374.780938 216.11532 \n",
       "L 375.288846 216.50306 \n",
       "L 375.796753 212.876315 \n",
       "L 376.304661 213.061803 \n",
       "L 376.812569 217.207936 \n",
       "L 377.320476 214.226326 \n",
       "L 377.828384 213.403918 \n",
       "L 378.844199 214.615329 \n",
       "L 379.352107 212.130408 \n",
       "L 380.367922 215.35541 \n",
       "L 380.87583 213.19175 \n",
       "L 381.383737 213.206495 \n",
       "L 381.891645 213.797914 \n",
       "L 382.399552 215.9345 \n",
       "L 382.90746 211.961525 \n",
       "L 383.415368 217.503938 \n",
       "L 383.923275 216.299909 \n",
       "L 384.431183 214.29226 \n",
       "L 384.93909 217.085579 \n",
       "L 385.446998 214.677386 \n",
       "L 385.954906 212.935599 \n",
       "L 386.462813 212.947258 \n",
       "L 386.970721 216.408245 \n",
       "L 387.478628 214.382653 \n",
       "L 387.986536 212.928994 \n",
       "L 388.494444 212.839124 \n",
       "L 389.002351 214.235929 \n",
       "L 389.510259 212.582757 \n",
       "L 390.018167 211.93361 \n",
       "L 390.526074 212.046198 \n",
       "L 391.033982 216.005247 \n",
       "L 391.541889 215.514315 \n",
       "L 392.049797 210.393923 \n",
       "L 392.557705 216.2979 \n",
       "L 393.065612 214.875682 \n",
       "L 393.57352 217.33457 \n",
       "L 394.081427 209.183137 \n",
       "L 394.589335 215.330632 \n",
       "L 395.60515 213.226999 \n",
       "L 396.113058 213.273587 \n",
       "L 396.620965 215.763269 \n",
       "L 397.128873 213.026184 \n",
       "L 397.636781 215.289104 \n",
       "L 398.144688 214.479933 \n",
       "L 398.652596 218.060291 \n",
       "L 399.160504 215.4052 \n",
       "L 400.176319 213.685834 \n",
       "L 400.684226 215.581518 \n",
       "L 401.192134 215.91326 \n",
       "L 401.700042 213.058544 \n",
       "L 402.207949 216.994549 \n",
       "L 402.715857 216.342274 \n",
       "L 403.223764 209.951394 \n",
       "L 403.731672 214.542373 \n",
       "L 404.23958 216.052352 \n",
       "L 404.747487 213.235697 \n",
       "L 405.255395 217.557879 \n",
       "L 405.763302 210.408508 \n",
       "L 406.27121 217.93894 \n",
       "L 406.779118 216.194837 \n",
       "L 407.287025 212.583765 \n",
       "L 407.794933 211.643555 \n",
       "L 408.302841 214.996159 \n",
       "L 409.318656 213.23857 \n",
       "L 409.826563 211.888756 \n",
       "L 410.334471 217.473443 \n",
       "L 410.842379 213.321599 \n",
       "L 411.350286 213.919388 \n",
       "L 411.858194 213.768894 \n",
       "L 412.366101 213.925995 \n",
       "L 412.874009 214.297187 \n",
       "L 413.381917 216.24667 \n",
       "L 413.889824 215.984648 \n",
       "L 414.397732 217.548554 \n",
       "L 414.90564 215.817376 \n",
       "L 415.413547 213.060138 \n",
       "L 415.921455 215.030444 \n",
       "L 416.429362 215.030074 \n",
       "L 416.93727 210.731019 \n",
       "L 417.445178 216.501632 \n",
       "L 417.953085 215.27905 \n",
       "L 418.460993 215.122355 \n",
       "L 418.9689 215.648082 \n",
       "L 419.476808 215.700944 \n",
       "L 419.984716 214.412221 \n",
       "L 420.492623 215.931192 \n",
       "L 421.000531 211.768755 \n",
       "L 421.508438 216.449011 \n",
       "L 422.016346 212.533195 \n",
       "L 423.032161 215.449969 \n",
       "L 423.540069 211.444071 \n",
       "L 424.047977 214.648324 \n",
       "L 424.555884 216.482981 \n",
       "L 425.063792 214.300471 \n",
       "L 425.571699 216.46499 \n",
       "L 426.079607 212.801127 \n",
       "L 426.587515 214.861079 \n",
       "L 427.095422 213.883538 \n",
       "L 427.60333 214.299539 \n",
       "L 428.111237 212.024233 \n",
       "L 428.619145 213.78732 \n",
       "L 429.127053 216.969884 \n",
       "L 429.63496 217.292155 \n",
       "L 430.142868 216.105638 \n",
       "L 430.650775 213.298951 \n",
       "L 431.666591 216.59916 \n",
       "L 432.682406 211.44192 \n",
       "L 433.190314 213.932765 \n",
       "L 433.698221 212.927388 \n",
       "L 434.206129 213.486307 \n",
       "L 434.714036 215.006954 \n",
       "L 435.729852 213.081938 \n",
       "L 436.237759 211.181408 \n",
       "L 436.745667 214.852019 \n",
       "L 437.253574 213.588883 \n",
       "L 437.761482 210.985698 \n",
       "L 438.26939 204.725194 \n",
       "L 438.777297 215.65518 \n",
       "L 439.285205 215.587679 \n",
       "L 439.793112 215.9558 \n",
       "L 440.30102 211.855827 \n",
       "L 440.808928 215.091417 \n",
       "L 441.316835 216.583132 \n",
       "L 441.824743 211.915542 \n",
       "L 442.840558 215.187679 \n",
       "L 443.348466 216.203845 \n",
       "L 443.856373 213.795959 \n",
       "L 444.364281 210.597929 \n",
       "L 444.872189 212.660795 \n",
       "L 445.380096 213.93889 \n",
       "L 445.888004 209.598575 \n",
       "L 446.395911 213.743056 \n",
       "L 446.903819 210.243547 \n",
       "L 447.411727 211.712684 \n",
       "L 447.919634 214.620411 \n",
       "L 448.427542 214.130158 \n",
       "L 448.935449 215.946582 \n",
       "L 449.443357 214.801622 \n",
       "L 449.951265 214.19671 \n",
       "L 450.459172 217.134568 \n",
       "L 450.96708 215.507992 \n",
       "L 451.474988 212.219289 \n",
       "L 451.982895 213.555109 \n",
       "L 452.490803 213.942069 \n",
       "L 452.99871 213.804458 \n",
       "L 453.506618 214.551688 \n",
       "L 454.014526 211.995601 \n",
       "L 454.522433 212.460907 \n",
       "L 455.030341 215.914654 \n",
       "L 455.538248 216.748191 \n",
       "L 456.046156 214.613926 \n",
       "L 456.554064 216.70122 \n",
       "L 457.061971 215.143529 \n",
       "L 457.569879 215.265472 \n",
       "L 458.077787 215.254242 \n",
       "L 458.585694 213.109553 \n",
       "L 459.093602 216.310417 \n",
       "L 459.601509 214.537692 \n",
       "L 460.109417 213.61552 \n",
       "L 460.617325 217.416904 \n",
       "L 461.125232 208.962254 \n",
       "L 461.63314 215.856399 \n",
       "L 462.141047 216.894772 \n",
       "L 462.648955 216.474751 \n",
       "L 463.156863 216.882363 \n",
       "L 463.66477 213.715594 \n",
       "L 464.172678 214.928684 \n",
       "L 465.188493 214.157369 \n",
       "L 465.696401 215.047563 \n",
       "L 466.204308 215.063577 \n",
       "L 466.712216 215.397112 \n",
       "L 466.712216 215.397112 \n",
       "\" clip-path=\"url(#p0d24e3c68c)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 1.5; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 40.603125 228.96 \n",
       "L 40.603125 7.2 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 487.003125 228.96 \n",
       "L 487.003125 7.2 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 40.603125 228.96 \n",
       "L 487.003125 228.96 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 40.603125 7.2 \n",
       "L 487.003125 7.2 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"patch_7\">\n",
       "     <path d=\"M 424.728125 29.878125 \n",
       "L 480.003125 29.878125 \n",
       "Q 482.003125 29.878125 482.003125 27.878125 \n",
       "L 482.003125 14.2 \n",
       "Q 482.003125 12.2 480.003125 12.2 \n",
       "L 424.728125 12.2 \n",
       "Q 422.728125 12.2 422.728125 14.2 \n",
       "L 422.728125 27.878125 \n",
       "Q 422.728125 29.878125 424.728125 29.878125 \n",
       "z\n",
       "\" style=\"fill: #ffffff; opacity: 0.8; stroke: #cccccc; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"line2d_30\">\n",
       "     <path d=\"M 426.728125 20.298437 \n",
       "L 436.728125 20.298437 \n",
       "L 446.728125 20.298437 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 1.5; stroke-linecap: square\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- train -->\n",
       "     <g transform=\"translate(454.728125 23.798437) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-72\" d=\"M 2631 2963 \n",
       "Q 2534 3019 2420 3045 \n",
       "Q 2306 3072 2169 3072 \n",
       "Q 1681 3072 1420 2755 \n",
       "Q 1159 2438 1159 1844 \n",
       "L 1159 0 \n",
       "L 581 0 \n",
       "L 581 3500 \n",
       "L 1159 3500 \n",
       "L 1159 2956 \n",
       "Q 1341 3275 1631 3429 \n",
       "Q 1922 3584 2338 3584 \n",
       "Q 2397 3584 2469 3576 \n",
       "Q 2541 3569 2628 3553 \n",
       "L 2631 2963 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-61\" d=\"M 2194 1759 \n",
       "Q 1497 1759 1228 1600 \n",
       "Q 959 1441 959 1056 \n",
       "Q 959 750 1161 570 \n",
       "Q 1363 391 1709 391 \n",
       "Q 2188 391 2477 730 \n",
       "Q 2766 1069 2766 1631 \n",
       "L 2766 1759 \n",
       "L 2194 1759 \n",
       "z\n",
       "M 3341 1997 \n",
       "L 3341 0 \n",
       "L 2766 0 \n",
       "L 2766 531 \n",
       "Q 2569 213 2275 61 \n",
       "Q 1981 -91 1556 -91 \n",
       "Q 1019 -91 701 211 \n",
       "Q 384 513 384 1019 \n",
       "Q 384 1609 779 1909 \n",
       "Q 1175 2209 1959 2209 \n",
       "L 2766 2209 \n",
       "L 2766 2266 \n",
       "Q 2766 2663 2505 2880 \n",
       "Q 2244 3097 1772 3097 \n",
       "Q 1472 3097 1187 3025 \n",
       "Q 903 2953 641 2809 \n",
       "L 641 3341 \n",
       "Q 956 3463 1253 3523 \n",
       "Q 1550 3584 1831 3584 \n",
       "Q 2591 3584 2966 3190 \n",
       "Q 3341 2797 3341 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-69\" d=\"M 603 3500 \n",
       "L 1178 3500 \n",
       "L 1178 0 \n",
       "L 603 0 \n",
       "L 603 3500 \n",
       "z\n",
       "M 603 4863 \n",
       "L 1178 4863 \n",
       "L 1178 4134 \n",
       "L 603 4134 \n",
       "L 603 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6e\" d=\"M 3513 2113 \n",
       "L 3513 0 \n",
       "L 2938 0 \n",
       "L 2938 2094 \n",
       "Q 2938 2591 2744 2837 \n",
       "Q 2550 3084 2163 3084 \n",
       "Q 1697 3084 1428 2787 \n",
       "Q 1159 2491 1159 1978 \n",
       "L 1159 0 \n",
       "L 581 0 \n",
       "L 581 3500 \n",
       "L 1159 3500 \n",
       "L 1159 2956 \n",
       "Q 1366 3272 1645 3428 \n",
       "Q 1925 3584 2291 3584 \n",
       "Q 2894 3584 3203 3211 \n",
       "Q 3513 2838 3513 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-74\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-72\" x=\"39.208984\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"80.322266\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-69\" x=\"141.601562\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6e\" x=\"169.384766\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p0d24e3c68c\">\n",
       "   <rect x=\"40.603125\" y=\"7.2\" width=\"446.4\" height=\"221.76\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 800x400 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "w = 50\n",
    "loss_avg = np.array(losses).reshape(-1, w).mean(axis=1)\n",
    "\n",
    "fig, ax = plt.subplots(1, 1, figsize=(8, 4))\n",
    "ax.plot(loss_avg, label=\"train\")\n",
    "ax.grid(linestyle=\"dotted\", alpha=0.6)\n",
    "ax.set_ylabel(\"MSE\")\n",
    "ax.set_xlabel(\"steps\")\n",
    "ax.legend();"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "32a4f0d9",
   "metadata": {
    "papermill": {
     "duration": 0.009278,
     "end_time": "2024-09-05T18:33:17.031929",
     "exception": false,
     "start_time": "2024-09-05T18:33:17.022651",
     "status": "completed"
    },
    "tags": []
   },
   "source": [
    "Model learned: ヾ( ˃ᴗ˂ )◞ • *✰"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "4779d99d",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-09-05T18:33:17.050922Z",
     "iopub.status.busy": "2024-09-05T18:33:17.050673Z",
     "iopub.status.idle": "2024-09-05T18:33:17.641828Z",
     "shell.execute_reply": "2024-09-05T18:33:17.641098Z"
    },
    "papermill": {
     "duration": 0.608943,
     "end_time": "2024-09-05T18:33:17.649977",
     "exception": false,
     "start_time": "2024-09-05T18:33:17.041034",
     "status": "completed"
    },
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"384.620312pt\" height=\"269.186037pt\" viewBox=\"0 0 384.620312 269.186037\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-01T13:17:27.769798</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 269.186037 \n",
       "L 384.620312 269.186037 \n",
       "L 384.620312 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 42.620313 231.629787 \n",
       "L 377.420313 231.629787 \n",
       "L 377.420313 9.869787 \n",
       "L 42.620313 9.869787 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mdf0c0967a6\" d=\"M 0 0.707107 \n",
       "C 0.187527 0.707107 0.367398 0.632602 0.5 0.5 \n",
       "C 0.632602 0.367398 0.707107 0.187527 0.707107 0 \n",
       "C 0.707107 -0.187527 0.632602 -0.367398 0.5 -0.5 \n",
       "C 0.367398 -0.632602 0.187527 -0.707107 0 -0.707107 \n",
       "C -0.187527 -0.707107 -0.367398 -0.632602 -0.5 -0.5 \n",
       "C -0.632602 -0.367398 -0.707107 -0.187527 -0.707107 0 \n",
       "C -0.707107 0.187527 -0.632602 0.367398 -0.5 0.5 \n",
       "C -0.367398 0.632602 -0.187527 0.707107 0 0.707107 \n",
       "z\n",
       "\" style=\"stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p88b5a78c04)\">\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"57.838494\" y=\"181.658187\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"58.041539\" y=\"187.45932\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"58.244583\" y=\"180.386682\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"58.447628\" y=\"172.503995\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"58.650672\" y=\"188.471675\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"58.853717\" y=\"188.519008\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"59.056761\" y=\"172.137423\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"59.259805\" y=\"179.539192\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"59.46285\" y=\"190.792437\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"59.665894\" y=\"181.670155\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"59.868939\" y=\"190.830784\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"60.071983\" y=\"190.898051\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"60.275028\" y=\"184.532518\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"60.478072\" y=\"204.104856\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"60.681117\" y=\"202.44404\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"60.884161\" y=\"191.956204\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"61.087206\" y=\"196.083462\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"61.29025\" y=\"184.105347\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"61.493294\" y=\"195.224039\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"61.696339\" y=\"199.837562\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"61.899383\" y=\"173.808013\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"62.102428\" y=\"189.176637\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"62.305472\" y=\"186.563502\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"62.508517\" y=\"200.12746\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"62.711561\" y=\"192.19519\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"62.914606\" y=\"186.301762\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"63.11765\" y=\"197.778085\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"63.320695\" y=\"183.989548\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"63.523739\" y=\"192.878147\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"63.726783\" y=\"190.121955\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"63.929828\" y=\"192.973301\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"64.132872\" y=\"170.782752\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"64.335917\" y=\"187.728854\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"64.538961\" y=\"197.231447\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"64.742006\" y=\"180.238278\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"64.94505\" y=\"198.792966\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"65.148095\" y=\"185.881361\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"65.351139\" y=\"205.569472\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"65.554184\" y=\"199.889348\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"65.757228\" y=\"186.113385\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"65.960272\" y=\"181.247171\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"66.163317\" y=\"186.425571\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"66.366361\" y=\"189.066249\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"66.569406\" y=\"190.786594\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"66.77245\" y=\"201.493887\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"66.975495\" y=\"194.660038\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"67.178539\" y=\"192.351194\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"67.381584\" y=\"178.639696\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"67.584628\" y=\"185.143171\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"67.787673\" y=\"204.268372\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"67.990717\" y=\"185.397888\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"68.193761\" y=\"191.861483\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"68.396806\" y=\"194.543923\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"68.59985\" y=\"182.907468\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"68.802895\" y=\"179.146416\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"69.005939\" y=\"180.087673\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"69.208984\" y=\"196.165917\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"69.412028\" y=\"191.40151\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"69.615073\" y=\"185.636051\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"69.818117\" y=\"179.835916\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"70.021162\" y=\"193.052448\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"70.224206\" y=\"190.429855\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"70.42725\" y=\"198.80759\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"70.630295\" y=\"199.658079\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"70.833339\" y=\"181.495111\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"71.036384\" y=\"176.604953\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"71.239428\" y=\"189.580513\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"71.442473\" y=\"179.871621\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"71.645517\" y=\"185.722468\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"71.848562\" y=\"194.878727\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"72.051606\" y=\"185.794642\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"72.254651\" y=\"175.169033\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"72.457695\" y=\"189.462675\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"72.660739\" y=\"174.996808\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"72.863784\" y=\"212.941319\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"73.066828\" y=\"181.794072\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"73.269873\" y=\"188.485571\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"73.472917\" y=\"192.016754\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"73.675962\" y=\"188.509764\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"73.879006\" y=\"207.381562\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"74.082051\" y=\"191.397456\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"74.285095\" y=\"186.204586\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"74.48814\" y=\"176.082932\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"74.691184\" y=\"194.20048\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"74.894228\" y=\"196.862084\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"75.097273\" y=\"194.115061\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"75.300317\" y=\"181.307464\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"75.503362\" y=\"186.654109\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"75.706406\" y=\"194.463602\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"75.909451\" y=\"185.04504\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"76.112495\" y=\"188.846733\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"76.31554\" y=\"180.981206\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"76.518584\" y=\"196.148303\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"76.721629\" y=\"192.786787\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"76.924673\" y=\"193.400921\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"77.127717\" y=\"203.137884\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"77.330762\" y=\"187.225533\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"77.533806\" y=\"187.572896\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"77.736851\" y=\"189.9212\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"77.939895\" y=\"192.122166\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"78.14294\" y=\"202.84911\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"78.345984\" y=\"193.865842\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"78.549029\" y=\"193.1885\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"78.752073\" y=\"197.380633\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"78.955118\" y=\"191.601598\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"79.158162\" y=\"186.5078\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"79.361206\" y=\"173.107654\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"79.564251\" y=\"188.64249\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"79.767295\" y=\"187.918309\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"79.97034\" y=\"190.953535\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"80.173384\" y=\"207.690203\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"80.376429\" y=\"190.573398\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"80.579473\" y=\"189.814273\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"80.782518\" y=\"168.069667\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"80.985562\" y=\"192.155703\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"81.188607\" y=\"187.707107\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"81.391651\" y=\"190.779599\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"81.594695\" y=\"201.07909\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"81.79774\" y=\"180.162602\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"82.000784\" y=\"183.729465\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"82.203829\" y=\"183.400454\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"82.406873\" y=\"198.831213\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"82.609918\" y=\"177.907781\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"82.812962\" y=\"203.342393\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"83.016007\" y=\"185.349232\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"83.219051\" y=\"170.844954\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"83.422096\" y=\"199.688669\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"83.62514\" y=\"195.868955\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"83.828184\" y=\"189.85916\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"84.031229\" y=\"195.346948\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"84.234273\" y=\"204.857714\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"84.437318\" y=\"190.210687\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"84.640362\" y=\"200.479193\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"84.843407\" y=\"186.586747\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"85.046451\" y=\"199.229934\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"85.249496\" y=\"176.879971\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"85.45254\" y=\"198.04068\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"85.655584\" y=\"193.884236\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"85.858629\" y=\"183.617682\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"86.061673\" y=\"202.161239\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"86.264718\" y=\"188.970237\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"86.467762\" y=\"179.209516\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"86.670807\" y=\"205.63687\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"86.873851\" y=\"189.421139\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"87.076896\" y=\"188.759966\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"87.27994\" y=\"184.051597\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"87.482985\" y=\"202.361792\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"87.686029\" y=\"203.138351\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"87.889073\" y=\"186.466107\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"88.092118\" y=\"188.523819\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"88.295162\" y=\"188.964451\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"88.498207\" y=\"188.114324\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"88.701251\" y=\"197.433156\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"88.904296\" y=\"189.18679\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"89.10734\" y=\"188.654419\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"89.310385\" y=\"197.800087\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"89.513429\" y=\"174.442513\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"89.716474\" y=\"187.071508\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"89.919518\" y=\"202.175443\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"90.122562\" y=\"185.451612\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"90.325607\" y=\"200.248017\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"90.528651\" y=\"184.303779\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"90.731696\" y=\"180.955001\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"90.93474\" y=\"198.904077\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"91.137785\" y=\"182.757292\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"91.340829\" y=\"187.762176\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"91.543874\" y=\"184.070446\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"91.746918\" y=\"174.34954\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"91.949963\" y=\"193.773544\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"92.153007\" y=\"198.394897\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"92.356051\" y=\"199.64059\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"92.559096\" y=\"198.988187\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"92.76214\" y=\"192.310679\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"92.965185\" y=\"188.536286\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"93.168229\" y=\"189.135075\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"93.371274\" y=\"184.162216\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"93.574318\" y=\"191.553051\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"93.777363\" y=\"178.516083\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"93.980407\" y=\"194.096819\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"94.183452\" y=\"167.068228\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"94.386496\" y=\"186.057938\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"94.58954\" y=\"199.505687\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"94.792585\" y=\"201.455341\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"94.995629\" y=\"187.394953\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"95.198674\" y=\"193.803533\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"95.401718\" y=\"185.3228\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"95.604763\" y=\"187.516553\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"95.807807\" y=\"192.47615\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"96.010852\" y=\"199.500302\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"96.213896\" y=\"205.564708\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"96.416941\" y=\"195.89734\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"96.619985\" y=\"184.10448\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"96.823029\" y=\"189.935026\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"97.026074\" y=\"203.172143\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"97.229118\" y=\"190.327693\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"97.432163\" y=\"188.416455\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"97.635207\" y=\"199.92564\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"97.838252\" y=\"190.535509\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"98.041296\" y=\"191.411012\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"98.244341\" y=\"202.303577\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"98.447385\" y=\"188.716518\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"98.65043\" y=\"186.88692\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"98.853474\" y=\"182.16456\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"99.056518\" y=\"182.438718\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"99.259563\" y=\"204.476712\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"99.462607\" y=\"200.500515\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"99.665652\" y=\"187.346243\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"99.868696\" y=\"187.365948\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"100.071741\" y=\"187.36271\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"100.274785\" y=\"157.131436\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"100.47783\" y=\"186.872582\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"100.680874\" y=\"181.764262\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"100.883919\" y=\"183.416642\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"101.086963\" y=\"186.165505\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"101.290007\" y=\"194.93044\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"101.493052\" y=\"185.204724\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"101.696096\" y=\"199.089361\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"101.899141\" y=\"194.239615\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"102.102185\" y=\"196.497679\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"102.30523\" y=\"191.364594\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"102.508274\" y=\"171.141533\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"102.711319\" y=\"209.035261\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"102.914363\" y=\"185.905913\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"103.117408\" y=\"206.739829\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"103.320452\" y=\"196.409471\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"103.523496\" y=\"182.272845\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"103.726541\" y=\"191.561026\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"103.929585\" y=\"201.912238\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"104.13263\" y=\"198.63286\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"104.335674\" y=\"185.999241\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"104.538719\" y=\"198.777393\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"104.741763\" y=\"190.202939\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"104.944808\" y=\"191.754714\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"105.147852\" y=\"198.074419\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"105.350897\" y=\"172.750066\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"105.553941\" y=\"186.433796\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"105.756985\" y=\"210.527556\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"105.96003\" y=\"190.493162\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"106.163074\" y=\"198.180575\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"106.366119\" y=\"184.464001\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"106.569163\" y=\"199.369215\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"106.772208\" y=\"193.230324\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"106.975252\" y=\"187.617267\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"107.178297\" y=\"184.350144\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"107.381341\" y=\"203.069709\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"107.584386\" y=\"195.226674\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"107.78743\" y=\"196.49993\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"107.990474\" y=\"198.116726\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"108.193519\" y=\"176.203102\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"108.396563\" y=\"188.529183\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"108.599608\" y=\"203.62192\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"108.802652\" y=\"183.882446\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"109.005697\" y=\"172.971269\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"109.208741\" y=\"182.843306\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"109.411786\" y=\"205.962115\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"109.61483\" y=\"196.582925\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"109.817875\" y=\"180.716527\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"110.020919\" y=\"198.604853\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"110.223963\" y=\"188.170929\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"110.427008\" y=\"185.172085\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"110.630052\" y=\"200.586316\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"110.833097\" y=\"192.725598\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"111.036141\" y=\"221.549787\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"111.239186\" y=\"201.4625\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"111.44223\" y=\"194.467203\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"111.645275\" y=\"203.480971\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"111.848319\" y=\"177.383499\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"112.051364\" y=\"205.12687\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"112.254408\" y=\"196.153216\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"112.457452\" y=\"190.978315\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"112.660497\" y=\"179.101138\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"112.863541\" y=\"205.163863\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"113.066586\" y=\"181.612605\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"113.26963\" y=\"192.053721\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"113.472675\" y=\"201.034279\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"113.675719\" y=\"187.95044\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"113.878764\" y=\"190.328638\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"114.081808\" y=\"197.564889\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"114.284852\" y=\"191.489191\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"114.487897\" y=\"195.606972\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"114.690941\" y=\"191.081843\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"114.893986\" y=\"186.105495\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"115.09703\" y=\"177.728997\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"115.300075\" y=\"203.306475\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"115.503119\" y=\"172.760212\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"115.706164\" y=\"209.764527\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"115.909208\" y=\"193.446958\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"116.112253\" y=\"186.734566\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"116.315297\" y=\"189.511631\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"116.518341\" y=\"197.691553\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"116.721386\" y=\"193.927824\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"116.92443\" y=\"196.500942\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"117.127475\" y=\"197.36593\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"117.330519\" y=\"184.320694\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"117.533564\" y=\"188.775057\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"117.736608\" y=\"198.278689\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"117.939653\" y=\"183.841782\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"118.142697\" y=\"189.198967\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"118.345742\" y=\"184.609366\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"118.548786\" y=\"186.260033\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"118.75183\" y=\"199.46549\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"118.954875\" y=\"197.020241\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"119.157919\" y=\"185.164577\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"119.360964\" y=\"186.394904\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"119.564008\" y=\"192.103814\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"119.767053\" y=\"190.840885\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"119.970097\" y=\"180.317503\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"120.173142\" y=\"197.241737\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"120.376186\" y=\"186.914286\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"120.579231\" y=\"193.691467\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"120.782275\" y=\"193.820245\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"120.985319\" y=\"181.88145\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"121.188364\" y=\"184.34615\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"121.391408\" y=\"184.441896\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"121.594453\" y=\"179.972354\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"121.797497\" y=\"191.597127\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"122.000542\" y=\"185.596247\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"122.203586\" y=\"194.572813\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"122.406631\" y=\"188.81178\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"122.609675\" y=\"192.914515\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"122.81272\" y=\"190.843162\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"123.015764\" y=\"186.316167\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"123.218808\" y=\"199.107439\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"123.421853\" y=\"172.723391\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"123.624897\" y=\"200.780548\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"123.827942\" y=\"202.65212\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"124.030986\" y=\"181.144543\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"124.234031\" y=\"184.44971\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"124.437075\" y=\"185.95261\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"124.64012\" y=\"185.899101\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"124.843164\" y=\"191.687421\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"125.046209\" y=\"199.68994\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"125.249253\" y=\"190.858262\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"125.452297\" y=\"197.664106\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"125.655342\" y=\"182.678313\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"125.858386\" y=\"192.828804\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"126.061431\" y=\"198.95886\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"126.264475\" y=\"194.37486\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"126.46752\" y=\"187.70501\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"126.670564\" y=\"196.536311\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"126.873609\" y=\"198.860919\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"127.076653\" y=\"189.186294\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"127.279698\" y=\"189.156962\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"127.482742\" y=\"195.951298\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"127.685786\" y=\"195.607873\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"127.888831\" y=\"189.219602\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"128.091875\" y=\"204.423032\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"128.29492\" y=\"204.036303\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"128.497964\" y=\"197.774913\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"128.701009\" y=\"193.180565\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"128.904053\" y=\"188.410645\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"129.107098\" y=\"177.841307\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"129.310142\" y=\"183.417935\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"129.513187\" y=\"192.617462\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"129.716231\" y=\"191.320648\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"129.919275\" y=\"200.210978\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"130.12232\" y=\"191.275383\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"130.325364\" y=\"193.702246\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"130.528409\" y=\"188.142357\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"130.731453\" y=\"198.539819\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"130.934498\" y=\"186.31866\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"131.137542\" y=\"177.11595\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"131.340587\" y=\"191.96625\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"131.543631\" y=\"187.319592\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"131.746676\" y=\"184.684409\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"131.94972\" y=\"194.549932\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"132.152764\" y=\"188.862238\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"132.355809\" y=\"190.75584\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"132.558853\" y=\"189.962212\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"132.761898\" y=\"197.827623\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"132.964942\" y=\"190.578966\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"133.167987\" y=\"186.265831\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"133.371031\" y=\"177.606828\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"133.574076\" y=\"182.039434\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"133.77712\" y=\"171.198711\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"133.980165\" y=\"197.634461\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"134.183209\" y=\"182.754816\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"134.386253\" y=\"188.972418\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"134.589298\" y=\"170.769259\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"134.792342\" y=\"197.907027\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"134.995387\" y=\"198.166628\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"135.198431\" y=\"195.963967\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"135.401476\" y=\"209.750417\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"135.60452\" y=\"195.245654\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"135.807565\" y=\"197.334177\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"136.010609\" y=\"189.067843\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"136.213654\" y=\"187.307853\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"136.416698\" y=\"173.379669\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"136.619742\" y=\"181.740254\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"136.822787\" y=\"195.550939\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"137.025831\" y=\"198.436785\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"137.228876\" y=\"185.813195\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"137.43192\" y=\"202.203801\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"137.634965\" y=\"173.621994\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"137.838009\" y=\"179.501451\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"138.041054\" y=\"194.409841\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"138.244098\" y=\"205.651864\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"138.447143\" y=\"177.836526\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"138.650187\" y=\"191.111699\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"138.853231\" y=\"178.830638\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"139.056276\" y=\"204.461681\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"139.25932\" y=\"195.417387\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"139.462365\" y=\"189.910214\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"139.665409\" y=\"189.502533\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"139.868454\" y=\"193.976009\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"140.071498\" y=\"184.225507\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"140.274543\" y=\"199.51097\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"140.477587\" y=\"191.098005\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"140.680632\" y=\"188.687666\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"140.883676\" y=\"185.086037\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"141.08672\" y=\"183.268729\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"141.289765\" y=\"199.874044\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"141.492809\" y=\"203.552555\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"141.695854\" y=\"178.046367\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"141.898898\" y=\"186.579638\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"142.101943\" y=\"196.339776\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"142.304987\" y=\"175.473086\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"142.508032\" y=\"188.446193\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"142.711076\" y=\"178.777369\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"142.91412\" y=\"188.817393\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"143.117165\" y=\"170.725982\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"143.320209\" y=\"173.459927\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"143.523254\" y=\"191.585621\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"143.726298\" y=\"180.494208\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"143.929343\" y=\"183.41591\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"144.132387\" y=\"176.82944\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"144.335432\" y=\"197.937351\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"144.538476\" y=\"182.945397\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"144.741521\" y=\"179.537328\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"144.944565\" y=\"205.026136\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"145.147609\" y=\"199.77753\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"145.350654\" y=\"207.49765\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"145.553698\" y=\"191.427948\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"145.756743\" y=\"182.450879\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"145.959787\" y=\"175.304944\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"146.162832\" y=\"188.209199\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"146.365876\" y=\"174.089374\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"146.568921\" y=\"201.312095\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"146.771965\" y=\"204.204686\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"146.97501\" y=\"189.23886\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"147.178054\" y=\"185.219276\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"147.381098\" y=\"188.958204\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"147.584143\" y=\"207.355834\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"147.787187\" y=\"189.395032\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"147.990232\" y=\"200.368565\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"148.193276\" y=\"182.445247\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"148.396321\" y=\"185.153218\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"148.599365\" y=\"196.951792\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"148.80241\" y=\"193.053877\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"149.005454\" y=\"197.956245\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"149.208499\" y=\"188.889043\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"149.411543\" y=\"179.628787\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"149.614587\" y=\"197.173942\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"149.817632\" y=\"183.637443\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"150.020676\" y=\"192.968777\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"150.223721\" y=\"195.308449\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"150.426765\" y=\"189.054941\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"150.62981\" y=\"197.424505\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"150.832854\" y=\"193.021101\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"151.035899\" y=\"198.8174\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"151.238943\" y=\"170.123773\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"151.441988\" y=\"187.563841\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"151.645032\" y=\"194.181845\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"151.848076\" y=\"185.862554\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"152.051121\" y=\"188.777538\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"152.254165\" y=\"189.72028\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"152.45721\" y=\"182.112241\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"152.660254\" y=\"180.771645\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"152.863299\" y=\"192.398823\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"153.066343\" y=\"192.767074\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"153.269388\" y=\"189.999629\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"153.472432\" y=\"208.320272\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"153.675477\" y=\"201.14963\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"153.878521\" y=\"174.995147\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"154.081565\" y=\"172.432344\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"154.28461\" y=\"189.548456\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"154.487654\" y=\"182.024944\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"154.690699\" y=\"184.384744\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"154.893743\" y=\"159.266066\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"155.096788\" y=\"176.973039\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"155.299832\" y=\"188.230819\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"155.502877\" y=\"195.684404\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"155.705921\" y=\"201.536748\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"155.908966\" y=\"185.094011\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"156.11201\" y=\"193.744665\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"156.315054\" y=\"199.732301\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"156.518099\" y=\"192.659055\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"156.721143\" y=\"196.554108\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"156.924188\" y=\"171.4239\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"157.127232\" y=\"178.675522\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"157.330277\" y=\"186.688988\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"157.533321\" y=\"173.161947\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"157.736366\" y=\"185.822453\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"157.93941\" y=\"194.27964\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"158.142455\" y=\"172.629844\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"158.345499\" y=\"181.499429\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"158.548543\" y=\"195.731792\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"158.751588\" y=\"188.011107\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"158.954632\" y=\"194.171778\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"159.157677\" y=\"198.718694\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"159.360721\" y=\"177.751139\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"159.563766\" y=\"168.794521\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"159.76681\" y=\"198.71601\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"159.969855\" y=\"180.89567\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"160.172899\" y=\"191.841848\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"160.375944\" y=\"190.311101\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"160.578988\" y=\"191.215349\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"160.782032\" y=\"193.62633\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"160.985077\" y=\"185.309139\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"161.188121\" y=\"193.227054\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"161.391166\" y=\"183.198099\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"161.59421\" y=\"186.053132\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"161.797255\" y=\"187.712194\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"162.000299\" y=\"193.718987\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"162.203344\" y=\"190.670994\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"162.406388\" y=\"178.550435\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"162.609433\" y=\"180.804542\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"162.812477\" y=\"194.14783\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"163.015521\" y=\"184.339471\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"163.218566\" y=\"178.379885\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"163.42161\" y=\"200.259971\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"163.624655\" y=\"180.160026\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"163.827699\" y=\"191.033612\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"164.030744\" y=\"179.807898\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"164.233788\" y=\"191.839628\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"164.436833\" y=\"201.22353\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"164.639877\" y=\"199.563488\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"164.842922\" y=\"184.32883\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"165.045966\" y=\"182.357664\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"165.24901\" y=\"192.849877\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"165.452055\" y=\"178.81706\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"165.655099\" y=\"199.601662\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"165.858144\" y=\"185.092528\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"166.061188\" y=\"195.410897\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"166.264233\" y=\"190.289849\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"166.467277\" y=\"183.899718\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"166.670322\" y=\"192.06917\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"166.873366\" y=\"187.702437\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"167.076411\" y=\"175.045736\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"167.279455\" y=\"189.333454\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"167.482499\" y=\"176.479442\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"167.685544\" y=\"194.229619\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"167.888588\" y=\"179.138071\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"168.091633\" y=\"170.820882\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"168.294677\" y=\"206.217591\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"168.497722\" y=\"190.987405\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"168.700766\" y=\"178.482097\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"168.903811\" y=\"185.492512\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"169.106855\" y=\"180.232754\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"169.309899\" y=\"189.009597\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"169.512944\" y=\"182.695021\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"169.715988\" y=\"184.83176\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"169.919033\" y=\"172.782891\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"170.122077\" y=\"180.999328\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"170.325122\" y=\"180.186933\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"170.528166\" y=\"186.918222\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"170.731211\" y=\"187.545168\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"170.934255\" y=\"186.987084\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"171.1373\" y=\"179.434861\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"171.340344\" y=\"186.762943\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"171.543388\" y=\"180.263562\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"171.746433\" y=\"164.025742\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"171.949477\" y=\"174.876113\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"172.152522\" y=\"185.661712\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"172.355566\" y=\"171.7643\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"172.558611\" y=\"186.283493\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"172.761655\" y=\"200.990575\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"172.9647\" y=\"191.597186\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"173.167744\" y=\"199.351782\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"173.370789\" y=\"185.52551\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"173.573833\" y=\"182.112076\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"173.776877\" y=\"167.028434\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"173.979922\" y=\"179.192682\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"174.182966\" y=\"184.077224\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"174.386011\" y=\"174.515162\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"174.589055\" y=\"201.999498\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"174.7921\" y=\"179.769019\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"174.995144\" y=\"174.856449\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"175.198189\" y=\"195.172968\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"175.401233\" y=\"171.351067\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"175.604278\" y=\"178.582865\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"175.807322\" y=\"185.348122\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"176.010366\" y=\"175.788465\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"176.213411\" y=\"160.884678\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"176.416455\" y=\"179.744781\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"176.6195\" y=\"179.078843\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"176.822544\" y=\"185.424537\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"177.025589\" y=\"188.897143\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"177.228633\" y=\"173.609432\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"177.431678\" y=\"188.822777\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"177.634722\" y=\"180.352569\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"177.837767\" y=\"185.262581\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"178.040811\" y=\"176.529362\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"178.243855\" y=\"177.779616\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"178.4469\" y=\"171.336001\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"178.649944\" y=\"185.290089\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"178.852989\" y=\"183.047519\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"179.056033\" y=\"189.402928\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"179.259078\" y=\"184.493362\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"179.462122\" y=\"176.982278\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"179.665167\" y=\"173.474646\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"179.868211\" y=\"188.619842\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"180.071256\" y=\"172.31841\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"180.2743\" y=\"167.846728\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"180.477344\" y=\"176.314599\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"180.680389\" y=\"162.98797\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"180.883433\" y=\"186.933323\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"181.086478\" y=\"191.130316\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"181.289522\" y=\"195.899705\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"181.492567\" y=\"166.161063\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"181.695611\" y=\"173.717027\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"181.898656\" y=\"180.079344\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"182.1017\" y=\"176.969249\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"182.304745\" y=\"189.632447\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"182.507789\" y=\"157.206772\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"182.710833\" y=\"178.123866\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"182.913878\" y=\"178.232722\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"183.116922\" y=\"172.577456\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"183.319967\" y=\"174.72379\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"183.523011\" y=\"176.981983\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"183.726056\" y=\"186.100484\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"183.9291\" y=\"174.595598\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"184.132145\" y=\"161.744088\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"184.335189\" y=\"166.533577\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"184.538234\" y=\"164.216503\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"184.741278\" y=\"183.209787\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"184.944322\" y=\"187.471267\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"185.147367\" y=\"179.572214\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"185.350411\" y=\"177.854632\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"185.553456\" y=\"168.372883\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"185.7565\" y=\"193.54639\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"185.959545\" y=\"164.281398\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"186.162589\" y=\"179.496737\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"186.365634\" y=\"181.858657\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"186.568678\" y=\"187.086501\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"186.771723\" y=\"192.835362\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"186.974767\" y=\"170.3099\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"187.177811\" y=\"177.028698\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"187.380856\" y=\"189.304919\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"187.5839\" y=\"189.276065\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"187.786945\" y=\"180.509487\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"187.989989\" y=\"162.270419\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"188.193034\" y=\"179.667768\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"188.396078\" y=\"190.858297\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"188.599123\" y=\"179.390119\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"188.802167\" y=\"179.558178\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"189.005212\" y=\"201.444416\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"189.208256\" y=\"177.425878\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"189.4113\" y=\"178.949262\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"189.614345\" y=\"170.472248\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"189.817389\" y=\"159.951034\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"190.020434\" y=\"166.418323\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"190.223478\" y=\"178.983337\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"190.426523\" y=\"186.494364\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"190.629567\" y=\"153.076631\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"190.832612\" y=\"175.776327\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"191.035656\" y=\"176.108133\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"191.238701\" y=\"176.374199\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"191.441745\" y=\"174.282089\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"191.644789\" y=\"177.305535\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"191.847834\" y=\"181.115704\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"192.050878\" y=\"180.79339\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"192.253923\" y=\"176.055942\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"192.456967\" y=\"180.602737\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"192.660012\" y=\"182.057625\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"192.863056\" y=\"174.554766\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"193.066101\" y=\"177.748655\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"193.269145\" y=\"161.731819\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"193.47219\" y=\"199.294771\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"193.675234\" y=\"165.307064\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"193.878278\" y=\"163.82537\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"194.081323\" y=\"193.818262\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"194.284367\" y=\"178.056561\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"194.487412\" y=\"178.235263\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"194.690456\" y=\"187.540026\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"194.893501\" y=\"181.752827\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"195.096545\" y=\"184.685228\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"195.29959\" y=\"158.665387\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"195.502634\" y=\"165.980907\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"195.705679\" y=\"162.854915\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"195.908723\" y=\"167.753676\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"196.111767\" y=\"184.437805\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"196.314812\" y=\"178.877232\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"196.517856\" y=\"169.607651\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"196.720901\" y=\"185.029859\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"196.923945\" y=\"167.413573\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"197.12699\" y=\"175.966329\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"197.330034\" y=\"177.100341\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"197.533079\" y=\"167.178508\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"197.736123\" y=\"169.50987\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"197.939167\" y=\"176.720123\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"198.142212\" y=\"162.861021\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"198.345256\" y=\"183.073409\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"198.548301\" y=\"167.612998\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"198.751345\" y=\"167.734011\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"198.95439\" y=\"175.825901\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"199.157434\" y=\"169.980419\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"199.360479\" y=\"184.183759\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"199.563523\" y=\"164.390438\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"199.766568\" y=\"174.350455\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"199.969612\" y=\"177.324071\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"200.172656\" y=\"162.997023\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"200.375701\" y=\"178.794912\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"200.578745\" y=\"185.086579\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"200.78179\" y=\"186.341173\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"200.984834\" y=\"166.65976\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"201.187879\" y=\"183.662631\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"201.390923\" y=\"156.075253\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"201.593968\" y=\"190.74723\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"201.797012\" y=\"156.426447\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"202.000057\" y=\"169.795497\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"202.203101\" y=\"172.494367\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"202.406145\" y=\"176.465745\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"202.60919\" y=\"167.823102\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"202.812234\" y=\"171.69049\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"203.015279\" y=\"161.263723\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"203.218323\" y=\"170.13457\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"203.421368\" y=\"169.717422\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"203.624412\" y=\"174.28295\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"203.827457\" y=\"171.41386\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"204.030501\" y=\"168.018366\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"204.233546\" y=\"186.209998\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"204.43659\" y=\"182.839163\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"204.639634\" y=\"163.799241\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"204.842679\" y=\"168.893476\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"205.045723\" y=\"172.016525\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"205.248768\" y=\"170.090574\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"205.451812\" y=\"167.016257\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"205.654857\" y=\"174.963086\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"205.857901\" y=\"177.031654\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"206.060946\" y=\"168.113063\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"206.26399\" y=\"178.658402\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"206.467035\" y=\"166.002413\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"206.670079\" y=\"185.033087\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"206.873123\" y=\"160.190038\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"207.076168\" y=\"165.138631\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"207.279212\" y=\"167.006731\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"207.482257\" y=\"160.329023\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"207.685301\" y=\"154.048652\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"207.888346\" y=\"159.853055\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"208.09139\" y=\"185.626678\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"208.294435\" y=\"180.446387\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"208.497479\" y=\"174.419148\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"208.700524\" y=\"168.426585\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"208.903568\" y=\"163.877457\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"209.106612\" y=\"175.046898\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"209.309657\" y=\"166.683661\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"209.512701\" y=\"175.123374\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"209.715746\" y=\"173.723645\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"209.91879\" y=\"180.831099\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"210.121835\" y=\"176.354559\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"210.324879\" y=\"180.139412\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"210.527924\" y=\"176.637486\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"210.730968\" y=\"158.152882\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"210.934013\" y=\"176.202867\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"211.137057\" y=\"143.654412\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"211.340101\" y=\"162.936377\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"211.543146\" y=\"165.63315\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"211.74619\" y=\"174.98619\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"211.949235\" y=\"160.766282\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"212.152279\" y=\"172.227674\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"212.355324\" y=\"165.808184\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"212.558368\" y=\"143.620304\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"212.761413\" y=\"167.585639\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"212.964457\" y=\"156.20356\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"213.167502\" y=\"172.887069\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"213.370546\" y=\"166.733514\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"213.57359\" y=\"150.273147\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"213.776635\" y=\"171.896633\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"213.979679\" y=\"149.69525\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"214.182724\" y=\"159.603179\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"214.385768\" y=\"171.010539\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"214.588813\" y=\"160.084064\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"214.791857\" y=\"156.901194\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"214.994902\" y=\"159.977576\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"215.197946\" y=\"179.735774\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"215.400991\" y=\"171.995701\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"215.604035\" y=\"167.548448\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"215.807079\" y=\"165.87818\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"216.010124\" y=\"159.478237\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"216.213168\" y=\"163.389026\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"216.416213\" y=\"176.994449\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"216.619257\" y=\"161.348812\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"216.822302\" y=\"159.158417\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"217.025346\" y=\"159.515336\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"217.228391\" y=\"154.691709\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"217.431435\" y=\"156.824565\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"217.63448\" y=\"160.115848\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"217.837524\" y=\"164.80764\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"218.040568\" y=\"179.115925\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"218.243613\" y=\"160.070921\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"218.446657\" y=\"161.976963\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"218.649702\" y=\"161.29328\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"218.852746\" y=\"175.216034\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"219.055791\" y=\"173.337853\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"219.258835\" y=\"153.896593\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"219.46188\" y=\"163.690875\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"219.664924\" y=\"157.052339\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"219.867969\" y=\"162.864149\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"220.071013\" y=\"162.744936\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"220.274057\" y=\"154.407333\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"220.477102\" y=\"167.476913\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"220.680146\" y=\"161.823952\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"220.883191\" y=\"166.776035\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"221.086235\" y=\"166.417203\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"221.28928\" y=\"165.174423\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"221.492324\" y=\"160.253272\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"221.695369\" y=\"166.495501\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"221.898413\" y=\"150.673033\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"222.101458\" y=\"170.047111\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"222.304502\" y=\"163.52674\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"222.507546\" y=\"165.709126\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"222.710591\" y=\"148.50692\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"222.913635\" y=\"159.726803\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"223.11668\" y=\"152.050023\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"223.319724\" y=\"174.748321\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"223.522769\" y=\"158.760265\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"223.725813\" y=\"153.010041\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"223.928858\" y=\"160.214704\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"224.131902\" y=\"151.196929\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"224.334946\" y=\"165.426496\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"224.537991\" y=\"147.860811\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"224.741035\" y=\"139.690881\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"224.94408\" y=\"163.69527\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"225.147124\" y=\"164.333176\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"225.350169\" y=\"147.018122\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"225.553213\" y=\"145.763454\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"225.756258\" y=\"164.699794\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"225.959302\" y=\"163.657779\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"226.162347\" y=\"162.291867\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"226.365391\" y=\"171.807388\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"226.568435\" y=\"167.837291\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"226.77148\" y=\"168.499242\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"226.974524\" y=\"166.245215\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"227.177569\" y=\"159.490284\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"227.380613\" y=\"156.94091\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"227.583658\" y=\"144.902069\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"227.786702\" y=\"167.881041\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"227.989747\" y=\"149.804341\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"228.192791\" y=\"160.547061\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"228.395836\" y=\"158.942348\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"228.59888\" y=\"152.266058\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"228.801924\" y=\"168.437198\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"229.004969\" y=\"154.686065\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"229.208013\" y=\"156.527735\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"229.411058\" y=\"153.459107\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"229.614102\" y=\"155.185555\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"229.817147\" y=\"135.445019\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"230.020191\" y=\"163.35216\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"230.223236\" y=\"162.269209\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"230.42628\" y=\"162.987968\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"230.629325\" y=\"162.258689\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"230.832369\" y=\"162.884345\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"231.035413\" y=\"146.220568\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"231.238458\" y=\"144.006467\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"231.441502\" y=\"161.930087\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"231.644547\" y=\"164.183037\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"231.847591\" y=\"152.253513\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"232.050636\" y=\"161.410029\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"232.25368\" y=\"150.554777\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"232.456725\" y=\"154.332646\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"232.659769\" y=\"169.78551\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"232.862814\" y=\"141.914221\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"233.065858\" y=\"139.545404\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"233.268902\" y=\"161.249051\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"233.471947\" y=\"159.090811\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"233.674991\" y=\"152.869168\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"233.878036\" y=\"152.309585\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"234.08108\" y=\"149.253824\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"234.284125\" y=\"136.888105\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"234.487169\" y=\"156.583678\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"234.690214\" y=\"162.092961\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"234.893258\" y=\"167.23668\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"235.096303\" y=\"161.241792\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"235.299347\" y=\"154.799024\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"235.502391\" y=\"138.119381\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"235.705436\" y=\"158.946445\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"235.90848\" y=\"152.108116\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"236.111525\" y=\"154.16294\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"236.314569\" y=\"143.125686\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"236.517614\" y=\"130.876715\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"236.720658\" y=\"158.458206\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"236.923703\" y=\"157.960607\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"237.126747\" y=\"143.943809\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"237.329792\" y=\"147.103316\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"237.532836\" y=\"136.427303\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"237.73588\" y=\"147.745003\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"237.938925\" y=\"156.16732\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"238.141969\" y=\"147.437429\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"238.345014\" y=\"142.620324\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"238.548058\" y=\"145.107798\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"238.751103\" y=\"147.821458\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"238.954147\" y=\"142.629126\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"239.157192\" y=\"141.575005\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"239.360236\" y=\"139.521898\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"239.563281\" y=\"146.042149\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"239.766325\" y=\"153.308555\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"239.969369\" y=\"150.340099\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"240.172414\" y=\"140.613051\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"240.375458\" y=\"158.819832\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"240.578503\" y=\"147.952531\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"240.781547\" y=\"154.7304\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"240.984592\" y=\"150.780219\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"241.187636\" y=\"139.331611\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"241.390681\" y=\"149.056472\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"241.593725\" y=\"150.240406\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"241.79677\" y=\"162.854462\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"241.999814\" y=\"143.646109\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"242.202858\" y=\"144.431792\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"242.405903\" y=\"130.553379\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"242.608947\" y=\"152.813163\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"242.811992\" y=\"147.911349\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"243.015036\" y=\"147.509379\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"243.218081\" y=\"135.348875\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"243.421125\" y=\"150.375463\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"243.62417\" y=\"146.855529\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"243.827214\" y=\"143.747105\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"244.030259\" y=\"147.434926\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"244.233303\" y=\"153.041048\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"244.436347\" y=\"147.108519\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"244.639392\" y=\"139.010303\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"244.842436\" y=\"157.907747\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"245.045481\" y=\"147.27287\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"245.248525\" y=\"154.690449\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"245.45157\" y=\"137.389933\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"245.654614\" y=\"161.88644\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"245.857659\" y=\"153.019473\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"246.060703\" y=\"144.407181\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"246.263748\" y=\"133.50997\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"246.466792\" y=\"148.157899\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"246.669836\" y=\"152.460748\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"246.872881\" y=\"130.255726\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"247.075925\" y=\"160.285946\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"247.27897\" y=\"166.955969\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"247.482014\" y=\"142.916053\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"247.685059\" y=\"151.318647\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"247.888103\" y=\"155.889681\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"248.091148\" y=\"140.08678\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"248.294192\" y=\"144.162547\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"248.497237\" y=\"151.348617\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"248.700281\" y=\"157.704115\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"248.903325\" y=\"138.066516\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"249.10637\" y=\"139.946284\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"249.309414\" y=\"146.601552\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"249.512459\" y=\"128.83832\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"249.715503\" y=\"155.129251\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"249.918548\" y=\"159.120885\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"250.121592\" y=\"151.433518\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"250.324637\" y=\"145.442844\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"250.527681\" y=\"142.689973\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"250.730726\" y=\"146.944795\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"250.93377\" y=\"141.433995\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"251.136814\" y=\"155.826697\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"251.339859\" y=\"131.271366\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"251.542903\" y=\"144.959912\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"251.745948\" y=\"133.956594\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"251.948992\" y=\"140.837597\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"252.152037\" y=\"139.667743\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"252.355081\" y=\"138.506881\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"252.558126\" y=\"139.475575\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"252.76117\" y=\"137.571407\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"252.964214\" y=\"131.214843\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"253.167259\" y=\"141.338701\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"253.370303\" y=\"136.557703\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"253.573348\" y=\"143.656127\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"253.776392\" y=\"129.65741\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"253.979437\" y=\"148.694389\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"254.182481\" y=\"126.111158\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"254.385526\" y=\"142.652536\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"254.58857\" y=\"155.112379\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"254.791615\" y=\"140.849715\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"254.994659\" y=\"148.041159\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"255.197703\" y=\"134.114996\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"255.400748\" y=\"147.504073\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"255.603792\" y=\"145.493675\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"255.806837\" y=\"158.43018\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"256.009881\" y=\"145.268454\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"256.212926\" y=\"162.990185\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"256.41597\" y=\"155.239203\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"256.619015\" y=\"133.858763\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"256.822059\" y=\"133.487553\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"257.025104\" y=\"136.610831\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"257.228148\" y=\"149.084617\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"257.431192\" y=\"140.614319\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"257.634237\" y=\"140.072703\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"257.837281\" y=\"150.392614\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"258.040326\" y=\"126.134775\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"258.24337\" y=\"131.664063\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"258.446415\" y=\"141.472088\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"258.649459\" y=\"139.083618\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"258.852504\" y=\"137.29611\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"259.055548\" y=\"157.538734\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"259.258593\" y=\"141.13658\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"259.461637\" y=\"144.932178\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"259.664681\" y=\"147.684137\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"259.867726\" y=\"141.012139\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"260.07077\" y=\"122.034104\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"260.273815\" y=\"132.370551\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"260.476859\" y=\"143.206716\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"260.679904\" y=\"132.699389\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"260.882948\" y=\"125.063775\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"261.085993\" y=\"129.219452\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"261.289037\" y=\"136.91087\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"261.492082\" y=\"143.16667\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"261.695126\" y=\"130.833714\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"261.89817\" y=\"133.448571\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"262.101215\" y=\"128.75687\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"262.304259\" y=\"130.966209\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"262.507304\" y=\"127.065299\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"262.710348\" y=\"141.27658\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"262.913393\" y=\"124.344814\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"263.116437\" y=\"134.342887\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"263.319482\" y=\"117.183946\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"263.522526\" y=\"142.082129\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"263.725571\" y=\"119.96256\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"263.928615\" y=\"133.749264\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"264.131659\" y=\"141.295962\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"264.334704\" y=\"139.629749\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"264.537748\" y=\"137.999525\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"264.740793\" y=\"131.105501\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"264.943837\" y=\"130.0626\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"265.146882\" y=\"139.848013\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"265.349926\" y=\"134.72162\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"265.552971\" y=\"114.942551\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"265.756015\" y=\"118.550229\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"265.95906\" y=\"130.098696\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"266.162104\" y=\"133.557339\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"266.365148\" y=\"132.663857\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"266.568193\" y=\"128.042381\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"266.771237\" y=\"142.716584\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"266.974282\" y=\"135.631053\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"267.177326\" y=\"148.265446\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"267.380371\" y=\"129.379919\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"267.583415\" y=\"126.981821\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"267.78646\" y=\"137.071369\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"267.989504\" y=\"118.281605\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"268.192549\" y=\"143.495187\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"268.395593\" y=\"145.504727\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"268.598637\" y=\"130.051586\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"268.801682\" y=\"122.445808\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"269.004726\" y=\"116.523331\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"269.207771\" y=\"135.784093\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"269.410815\" y=\"121.700602\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"269.61386\" y=\"131.668879\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"269.816904\" y=\"132.730386\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"270.019949\" y=\"123.006671\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"270.222993\" y=\"124.948584\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"270.426038\" y=\"144.986463\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"270.629082\" y=\"117.172646\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"270.832126\" y=\"117.891898\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"271.035171\" y=\"135.908274\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"271.238215\" y=\"126.49978\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"271.44126\" y=\"125.454699\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"271.644304\" y=\"127.413552\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"271.847349\" y=\"134.605448\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"272.050393\" y=\"135.548853\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"272.253438\" y=\"129.539566\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"272.456482\" y=\"118.527052\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"272.659527\" y=\"124.07062\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"272.862571\" y=\"132.196857\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"273.065615\" y=\"121.690849\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"273.26866\" y=\"154.333187\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"273.471704\" y=\"117.960656\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"273.674749\" y=\"143.972876\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"273.877793\" y=\"131.337368\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"274.080838\" y=\"138.040162\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"274.283882\" y=\"139.467898\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"274.486927\" y=\"117.063043\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"274.689971\" y=\"131.659188\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"274.893016\" y=\"124.124082\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"275.09606\" y=\"127.529855\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"275.299104\" y=\"122.623958\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"275.502149\" y=\"126.090901\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"275.705193\" y=\"138.251543\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"275.908238\" y=\"117.442143\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"276.111282\" y=\"130.782088\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"276.314327\" y=\"140.251443\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"276.517371\" y=\"129.867592\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"276.720416\" y=\"112.231883\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"276.92346\" y=\"117.965352\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"277.126505\" y=\"128.666527\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"277.329549\" y=\"128.511249\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"277.532593\" y=\"128.10003\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"277.735638\" y=\"106.20963\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"277.938682\" y=\"121.403214\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"278.141727\" y=\"120.805835\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"278.344771\" y=\"115.205938\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"278.547816\" y=\"122.214916\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"278.75086\" y=\"126.563127\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"278.953905\" y=\"125.832824\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"279.156949\" y=\"124.540101\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"279.359993\" y=\"124.065928\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"279.563038\" y=\"116.97351\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"279.766082\" y=\"122.932088\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"279.969127\" y=\"116.601747\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"280.172171\" y=\"123.807249\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"280.375216\" y=\"122.199861\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"280.57826\" y=\"140.852044\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"280.781305\" y=\"114.282487\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"280.984349\" y=\"119.280957\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"281.187394\" y=\"113.213757\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"281.390438\" y=\"148.331001\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"281.593482\" y=\"103.005635\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"281.796527\" y=\"123.025875\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"281.999571\" y=\"111.555893\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"282.202616\" y=\"130.852076\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"282.40566\" y=\"115.713264\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"282.608705\" y=\"130.643073\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"282.811749\" y=\"126.584503\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"283.014794\" y=\"103.425956\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"283.217838\" y=\"122.328196\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"283.420883\" y=\"118.464118\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"283.623927\" y=\"112.38451\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"283.826971\" y=\"115.609471\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"284.030016\" y=\"118.570388\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"284.23306\" y=\"116.459301\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"284.436105\" y=\"97.82345\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"284.639149\" y=\"119.952585\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"284.842194\" y=\"117.440687\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"285.045238\" y=\"109.575632\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"285.248283\" y=\"108.910185\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"285.451327\" y=\"108.003253\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"285.654372\" y=\"112.802129\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"285.857416\" y=\"128.77568\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"286.06046\" y=\"103.452197\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"286.263505\" y=\"128.467577\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"286.466549\" y=\"115.170398\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"286.669594\" y=\"124.576302\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"286.872638\" y=\"118.153825\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"287.075683\" y=\"114.424106\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"287.278727\" y=\"114.320949\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"287.481772\" y=\"113.239406\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"287.684816\" y=\"102.271199\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"287.887861\" y=\"112.611525\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"288.090905\" y=\"118.761553\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"288.293949\" y=\"107.643699\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"288.496994\" y=\"105.430327\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"288.700038\" y=\"127.15735\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"288.903083\" y=\"110.45106\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"289.106127\" y=\"109.338894\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"289.309172\" y=\"118.215219\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"289.512216\" y=\"102.883084\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"289.715261\" y=\"116.533856\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"289.918305\" y=\"113.863877\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"290.12135\" y=\"116.39666\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"290.324394\" y=\"114.51434\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"290.527438\" y=\"124.414347\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"290.730483\" y=\"127.355403\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"290.933527\" y=\"99.688723\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"291.136572\" y=\"121.634379\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"291.339616\" y=\"122.768799\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"291.542661\" y=\"133.122137\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"291.745705\" y=\"119.226975\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"291.94875\" y=\"125.250446\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"292.151794\" y=\"98.211829\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"292.354839\" y=\"103.76443\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"292.557883\" y=\"118.972662\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"292.760927\" y=\"92.155603\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"292.963972\" y=\"103.492155\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"293.167016\" y=\"115.154007\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"293.370061\" y=\"134.679503\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"293.573105\" y=\"91.102904\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"293.77615\" y=\"124.271772\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"293.979194\" y=\"126.412913\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"294.182239\" y=\"102.064397\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"294.385283\" y=\"89.047767\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"294.588328\" y=\"98.433152\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"294.791372\" y=\"105.688203\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"294.994416\" y=\"105.231144\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"295.197461\" y=\"102.709888\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"295.400505\" y=\"103.387947\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"295.60355\" y=\"107.538042\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"295.806594\" y=\"108.96319\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"296.009639\" y=\"110.295768\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"296.212683\" y=\"116.380801\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"296.415728\" y=\"111.913861\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"296.618772\" y=\"124.529922\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"296.821817\" y=\"109.903414\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"297.024861\" y=\"117.789517\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"297.227905\" y=\"118.651664\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"297.43095\" y=\"106.843434\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"297.633994\" y=\"95.681667\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"297.837039\" y=\"99.792927\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"298.040083\" y=\"122.161\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"298.243128\" y=\"116.717621\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"298.446172\" y=\"99.047392\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"298.649217\" y=\"116.290947\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"298.852261\" y=\"109.24354\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"299.055306\" y=\"102.043451\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"299.25835\" y=\"115.618393\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"299.461394\" y=\"105.708675\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"299.664439\" y=\"118.567533\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"299.867483\" y=\"111.747437\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"300.070528\" y=\"103.21942\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"300.273572\" y=\"120.366452\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"300.476617\" y=\"101.760486\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"300.679661\" y=\"105.746064\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"300.882706\" y=\"100.379396\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"301.08575\" y=\"103.172871\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"301.288795\" y=\"92.658867\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"301.491839\" y=\"103.699597\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"301.694883\" y=\"108.540532\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"301.897928\" y=\"103.357943\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"302.100972\" y=\"99.35932\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"302.304017\" y=\"103.654337\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"302.507061\" y=\"103.544485\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"302.710106\" y=\"110.087302\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"302.91315\" y=\"109.54799\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"303.116195\" y=\"116.064336\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"303.319239\" y=\"87.320164\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"303.522284\" y=\"114.254872\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"303.725328\" y=\"109.077291\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"303.928372\" y=\"109.12222\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"304.131417\" y=\"94.319193\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"304.334461\" y=\"104.912896\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"304.537506\" y=\"90.749475\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"304.74055\" y=\"107.96887\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"304.943595\" y=\"99.152312\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"305.146639\" y=\"109.060917\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"305.349684\" y=\"81.870275\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"305.552728\" y=\"111.87716\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"305.755773\" y=\"98.122746\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"305.958817\" y=\"94.999664\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"306.161861\" y=\"96.804406\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"306.364906\" y=\"102.043666\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"306.56795\" y=\"101.352503\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"306.770995\" y=\"99.590576\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"306.974039\" y=\"101.130316\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"307.177084\" y=\"90.876566\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"307.380128\" y=\"79.392617\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"307.583173\" y=\"104.281112\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"307.786217\" y=\"111.450821\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"307.989261\" y=\"99.650307\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"308.192306\" y=\"75.288236\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"308.39535\" y=\"105.751175\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"308.598395\" y=\"83.429019\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"308.801439\" y=\"82.888687\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"309.004484\" y=\"102.913114\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"309.207528\" y=\"92.551516\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"309.410573\" y=\"82.76193\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"309.613617\" y=\"100.758478\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"309.816662\" y=\"98.976296\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"310.019706\" y=\"102.209947\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"310.22275\" y=\"105.941477\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"310.425795\" y=\"102.43794\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"310.628839\" y=\"107.451855\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"310.831884\" y=\"95.861515\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"311.034928\" y=\"102.953343\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"311.237973\" y=\"93.666242\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"311.441017\" y=\"109.687402\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"311.644062\" y=\"92.39982\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"311.847106\" y=\"87.652178\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"312.050151\" y=\"113.073215\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"312.253195\" y=\"91.427066\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"312.456239\" y=\"83.499127\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"312.659284\" y=\"105.386611\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"312.862328\" y=\"79.079247\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"313.065373\" y=\"90.24156\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"313.268417\" y=\"100.230211\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"313.471462\" y=\"94.152884\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"313.674506\" y=\"88.393793\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"313.877551\" y=\"92.568004\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"314.080595\" y=\"88.179708\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"314.28364\" y=\"101.20609\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"314.486684\" y=\"91.134242\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"314.689728\" y=\"105.280462\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"314.892773\" y=\"93.283403\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"315.095817\" y=\"100.268301\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"315.298862\" y=\"98.54585\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"315.501906\" y=\"80.485879\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"315.704951\" y=\"81.600264\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"315.907995\" y=\"85.771185\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"316.11104\" y=\"100.988527\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"316.314084\" y=\"93.760943\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"316.517129\" y=\"79.705565\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"316.720173\" y=\"89.213919\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"316.923217\" y=\"69.286336\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"317.126262\" y=\"86.537222\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"317.329306\" y=\"88.161817\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"317.532351\" y=\"92.503271\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"317.735395\" y=\"88.293535\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"317.93844\" y=\"90.685308\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"318.141484\" y=\"82.688838\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"318.344529\" y=\"80.236731\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"318.547573\" y=\"95.825391\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"318.750618\" y=\"100.565028\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"318.953662\" y=\"104.939616\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"319.156706\" y=\"83.500661\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"319.359751\" y=\"97.898668\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"319.562795\" y=\"107.20629\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"319.76584\" y=\"83.979473\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"319.968884\" y=\"64.712102\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"320.171929\" y=\"87.151972\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"320.374973\" y=\"79.298485\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"320.578018\" y=\"85.951817\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"320.781062\" y=\"87.386942\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"320.984107\" y=\"77.961837\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"321.187151\" y=\"88.715937\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"321.390195\" y=\"83.460736\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"321.59324\" y=\"82.765775\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"321.796284\" y=\"91.530065\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"321.999329\" y=\"76.28599\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"322.202373\" y=\"86.655443\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"322.405418\" y=\"91.713604\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"322.608462\" y=\"79.801905\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"322.811507\" y=\"92.598626\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"323.014551\" y=\"83.998913\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"323.217596\" y=\"84.132347\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"323.42064\" y=\"74.006864\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"323.623684\" y=\"79.339395\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"323.826729\" y=\"83.661799\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"324.029773\" y=\"75.820849\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"324.232818\" y=\"70.429084\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"324.435862\" y=\"77.764902\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"324.638907\" y=\"82.518987\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"324.841951\" y=\"94.291909\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"325.044996\" y=\"91.850367\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"325.24804\" y=\"84.759366\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"325.451085\" y=\"87.309565\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"325.654129\" y=\"83.274536\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"325.857173\" y=\"80.860317\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"326.060218\" y=\"76.367356\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"326.263262\" y=\"81.597658\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"326.466307\" y=\"76.343658\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"326.669351\" y=\"79.959412\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"326.872396\" y=\"98.233203\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"327.07544\" y=\"88.637717\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"327.278485\" y=\"81.224431\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"327.481529\" y=\"90.670218\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"327.684574\" y=\"74.066344\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"327.887618\" y=\"65.42418\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"328.090662\" y=\"68.041638\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"328.293707\" y=\"80.808009\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"328.496751\" y=\"65.158774\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"328.699796\" y=\"77.108039\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"328.90284\" y=\"81.299021\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"329.105885\" y=\"83.592322\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"329.308929\" y=\"80.564972\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"329.511974\" y=\"81.130972\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"329.715018\" y=\"75.859445\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"329.918063\" y=\"75.737724\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"330.121107\" y=\"76.953837\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"330.324151\" y=\"72.811514\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"330.527196\" y=\"65.771479\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"330.73024\" y=\"67.744099\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"330.933285\" y=\"89.588273\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"331.136329\" y=\"99.061525\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"331.339374\" y=\"67.245964\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"331.542418\" y=\"87.882286\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"331.745463\" y=\"77.322156\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"331.948507\" y=\"85.674139\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"332.151552\" y=\"91.185811\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"332.354596\" y=\"69.741102\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"332.55764\" y=\"67.555411\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"332.760685\" y=\"79.442884\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"332.963729\" y=\"97.480663\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"333.166774\" y=\"78.740894\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"333.369818\" y=\"70.028034\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"333.572863\" y=\"86.762263\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"333.775907\" y=\"71.487586\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"333.978952\" y=\"73.072764\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"334.181996\" y=\"67.470746\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"334.385041\" y=\"71.420561\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"334.588085\" y=\"81.104575\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"334.791129\" y=\"61.232189\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"334.994174\" y=\"73.293618\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"335.197218\" y=\"71.888801\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"335.400263\" y=\"79.880675\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"335.603307\" y=\"75.225116\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"335.806352\" y=\"79.008769\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"336.009396\" y=\"72.342681\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"336.212441\" y=\"55.0509\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"336.415485\" y=\"82.771188\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"336.618529\" y=\"84.743342\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"336.821574\" y=\"56.578333\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"337.024618\" y=\"71.585872\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"337.227663\" y=\"75.533321\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"337.430707\" y=\"59.832007\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"337.633752\" y=\"74.522105\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"337.836796\" y=\"52.273244\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"338.039841\" y=\"62.456203\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"338.242885\" y=\"72.799813\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"338.44593\" y=\"48.615216\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"338.648974\" y=\"73.428875\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"338.852018\" y=\"60.998365\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"339.055063\" y=\"64.790539\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"339.258107\" y=\"55.488603\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"339.461152\" y=\"52.915112\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"339.664196\" y=\"66.5522\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"339.867241\" y=\"73.447716\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"340.070285\" y=\"62.233886\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"340.27333\" y=\"72.320525\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"340.476374\" y=\"47.718295\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"340.679419\" y=\"64.501346\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"340.882463\" y=\"68.826806\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"341.085507\" y=\"63.622277\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"341.288552\" y=\"77.27865\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"341.491596\" y=\"73.654603\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"341.694641\" y=\"53.754006\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"341.897685\" y=\"70.35883\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"342.10073\" y=\"73.669861\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"342.303774\" y=\"59.100145\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"342.506819\" y=\"52.996876\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"342.709863\" y=\"57.002535\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"342.912908\" y=\"54.268795\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"343.115952\" y=\"69.926005\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"343.318996\" y=\"75.727354\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"343.522041\" y=\"49.019933\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"343.725085\" y=\"65.321366\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"343.92813\" y=\"64.446192\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"344.131174\" y=\"49.915834\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"344.334219\" y=\"56.685165\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"344.537263\" y=\"57.369435\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"344.740308\" y=\"41.659911\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"344.943352\" y=\"66.879775\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"345.146397\" y=\"52.417929\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"345.349441\" y=\"60.081985\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"345.552485\" y=\"57.939294\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"345.75553\" y=\"46.298883\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"345.958574\" y=\"55.319591\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"346.161619\" y=\"54.817248\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"346.364663\" y=\"49.750749\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"346.567708\" y=\"62.547315\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"346.770752\" y=\"66.617109\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"346.973797\" y=\"68.252684\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"347.176841\" y=\"76.374522\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"347.379886\" y=\"39.702731\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"347.58293\" y=\"68.099172\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"347.785974\" y=\"59.880778\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"347.989019\" y=\"60.156031\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"348.192063\" y=\"54.634713\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"348.395108\" y=\"49.800757\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"348.598152\" y=\"49.166752\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"348.801197\" y=\"62.016373\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"349.004241\" y=\"58.018748\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"349.207286\" y=\"53.715193\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"349.41033\" y=\"58.299016\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"349.613375\" y=\"41.253739\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"349.816419\" y=\"51.138151\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"350.019463\" y=\"48.698351\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"350.222508\" y=\"49.120392\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"350.425552\" y=\"44.264007\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"350.628597\" y=\"53.024951\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"350.831641\" y=\"66.183415\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"351.034686\" y=\"50.581998\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"351.23773\" y=\"59.873208\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"351.440775\" y=\"58.529781\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"351.643819\" y=\"48.196504\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"351.846864\" y=\"42.058352\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"352.049908\" y=\"52.852438\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"352.252952\" y=\"50.014964\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"352.455997\" y=\"37.158609\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"352.659041\" y=\"50.166823\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"352.862086\" y=\"28.544138\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"353.06513\" y=\"46.758829\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"353.268175\" y=\"67.60161\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"353.471219\" y=\"44.590591\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"353.674264\" y=\"47.72902\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"353.877308\" y=\"39.263466\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"354.080353\" y=\"44.615654\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"354.283397\" y=\"51.734939\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"354.486441\" y=\"61.338315\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"354.689486\" y=\"51.905464\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"354.89253\" y=\"57.482705\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"355.095575\" y=\"54.801655\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"355.298619\" y=\"43.974558\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"355.501664\" y=\"33.942513\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"355.704708\" y=\"45.2606\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"355.907753\" y=\"59.435293\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"356.110797\" y=\"44.336705\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"356.313842\" y=\"37.287305\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"356.516886\" y=\"53.417099\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"356.71993\" y=\"48.870244\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"356.922975\" y=\"47.286348\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"357.126019\" y=\"54.293743\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"357.329064\" y=\"41.072186\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"357.532108\" y=\"47.804152\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"357.735153\" y=\"42.670016\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"357.938197\" y=\"54.274004\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"358.141242\" y=\"49.958924\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"358.344286\" y=\"39.21284\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"358.547331\" y=\"48.897257\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"358.750375\" y=\"29.634812\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"358.953419\" y=\"48.663152\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"359.156464\" y=\"42.768071\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"359.359508\" y=\"36.115518\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"359.562553\" y=\"57.175937\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"359.765597\" y=\"60.039116\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"359.968642\" y=\"57.66911\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"360.171686\" y=\"32.168042\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"360.374731\" y=\"48.36689\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"360.577775\" y=\"19.949787\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"360.78082\" y=\"47.998715\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"360.983864\" y=\"40.974127\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"361.186908\" y=\"28.434007\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"361.389953\" y=\"23.989453\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"361.592997\" y=\"23.246351\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"361.796042\" y=\"30.734463\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"361.999086\" y=\"32.162777\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     <use xlink:href=\"#mdf0c0967a6\" x=\"362.202131\" y=\"35.830808\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <path d=\"M 57.838494 231.629787 \n",
       "L 57.838494 9.869787 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_2\">\n",
       "      <defs>\n",
       "       <path id=\"m718c890c86\" d=\"M 0 0 \n",
       "L 0 3.5 \n",
       "\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m718c890c86\" x=\"57.838494\" y=\"231.629787\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- −1 -->\n",
       "      <g transform=\"translate(50.467401 246.228225) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-2212\" d=\"M 678 2272 \n",
       "L 4684 2272 \n",
       "L 4684 1741 \n",
       "L 678 1741 \n",
       "L 678 2272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"DejaVuSans-31\" d=\"M 794 531 \n",
       "L 1825 531 \n",
       "L 1825 4091 \n",
       "L 703 3866 \n",
       "L 703 4441 \n",
       "L 1819 4666 \n",
       "L 2450 4666 \n",
       "L 2450 531 \n",
       "L 3481 531 \n",
       "L 3481 0 \n",
       "L 794 0 \n",
       "L 794 531 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-2212\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-31\" x=\"83.789062\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <path d=\"M 108.565767 231.629787 \n",
       "L 108.565767 9.869787 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m718c890c86\" x=\"108.565767\" y=\"231.629787\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(105.384517 246.228225) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-30\" d=\"M 2034 4250 \n",
       "Q 1547 4250 1301 3770 \n",
       "Q 1056 3291 1056 2328 \n",
       "Q 1056 1369 1301 889 \n",
       "Q 1547 409 2034 409 \n",
       "Q 2525 409 2770 889 \n",
       "Q 3016 1369 3016 2328 \n",
       "Q 3016 3291 2770 3770 \n",
       "Q 2525 4250 2034 4250 \n",
       "z\n",
       "M 2034 4750 \n",
       "Q 2819 4750 3233 4129 \n",
       "Q 3647 3509 3647 2328 \n",
       "Q 3647 1150 3233 529 \n",
       "Q 2819 -91 2034 -91 \n",
       "Q 1250 -91 836 529 \n",
       "Q 422 1150 422 2328 \n",
       "Q 422 3509 836 4129 \n",
       "Q 1250 4750 2034 4750 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <path d=\"M 159.29304 231.629787 \n",
       "L 159.29304 9.869787 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m718c890c86\" x=\"159.29304\" y=\"231.629787\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 1 -->\n",
       "      <g transform=\"translate(156.11179 246.228225) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <path d=\"M 210.020313 231.629787 \n",
       "L 210.020313 9.869787 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m718c890c86\" x=\"210.020313\" y=\"231.629787\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 2 -->\n",
       "      <g transform=\"translate(206.839063 246.228225) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-32\" d=\"M 1228 531 \n",
       "L 3431 531 \n",
       "L 3431 0 \n",
       "L 469 0 \n",
       "L 469 531 \n",
       "Q 828 903 1448 1529 \n",
       "Q 2069 2156 2228 2338 \n",
       "Q 2531 2678 2651 2914 \n",
       "Q 2772 3150 2772 3378 \n",
       "Q 2772 3750 2511 3984 \n",
       "Q 2250 4219 1831 4219 \n",
       "Q 1534 4219 1204 4116 \n",
       "Q 875 4013 500 3803 \n",
       "L 500 4441 \n",
       "Q 881 4594 1212 4672 \n",
       "Q 1544 4750 1819 4750 \n",
       "Q 2544 4750 2975 4387 \n",
       "Q 3406 4025 3406 3419 \n",
       "Q 3406 3131 3298 2873 \n",
       "Q 3191 2616 2906 2266 \n",
       "Q 2828 2175 2409 1742 \n",
       "Q 1991 1309 1228 531 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <path d=\"M 260.747585 231.629787 \n",
       "L 260.747585 9.869787 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m718c890c86\" x=\"260.747585\" y=\"231.629787\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 3 -->\n",
       "      <g transform=\"translate(257.566335 246.228225) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-33\" d=\"M 2597 2516 \n",
       "Q 3050 2419 3304 2112 \n",
       "Q 3559 1806 3559 1356 \n",
       "Q 3559 666 3084 287 \n",
       "Q 2609 -91 1734 -91 \n",
       "Q 1441 -91 1130 -33 \n",
       "Q 819 25 488 141 \n",
       "L 488 750 \n",
       "Q 750 597 1062 519 \n",
       "Q 1375 441 1716 441 \n",
       "Q 2309 441 2620 675 \n",
       "Q 2931 909 2931 1356 \n",
       "Q 2931 1769 2642 2001 \n",
       "Q 2353 2234 1838 2234 \n",
       "L 1294 2234 \n",
       "L 1294 2753 \n",
       "L 1863 2753 \n",
       "Q 2328 2753 2575 2939 \n",
       "Q 2822 3125 2822 3475 \n",
       "Q 2822 3834 2567 4026 \n",
       "Q 2313 4219 1838 4219 \n",
       "Q 1578 4219 1281 4162 \n",
       "Q 984 4106 628 3988 \n",
       "L 628 4550 \n",
       "Q 988 4650 1302 4700 \n",
       "Q 1616 4750 1894 4750 \n",
       "Q 2613 4750 3031 4423 \n",
       "Q 3450 4097 3450 3541 \n",
       "Q 3450 3153 3228 2886 \n",
       "Q 3006 2619 2597 2516 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-33\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <path d=\"M 311.474858 231.629787 \n",
       "L 311.474858 9.869787 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m718c890c86\" x=\"311.474858\" y=\"231.629787\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 4 -->\n",
       "      <g transform=\"translate(308.293608 246.228225) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-34\" d=\"M 2419 4116 \n",
       "L 825 1625 \n",
       "L 2419 1625 \n",
       "L 2419 4116 \n",
       "z\n",
       "M 2253 4666 \n",
       "L 3047 4666 \n",
       "L 3047 1625 \n",
       "L 3713 1625 \n",
       "L 3713 1100 \n",
       "L 3047 1100 \n",
       "L 3047 0 \n",
       "L 2419 0 \n",
       "L 2419 1100 \n",
       "L 313 1100 \n",
       "L 313 1709 \n",
       "L 2253 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-34\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <path d=\"M 362.202131 231.629787 \n",
       "L 362.202131 9.869787 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m718c890c86\" x=\"362.202131\" y=\"231.629787\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 5 -->\n",
       "      <g transform=\"translate(359.020881 246.228225) scale(0.1 -0.1)\">\n",
       "       <defs>\n",
       "        <path id=\"DejaVuSans-35\" d=\"M 691 4666 \n",
       "L 3169 4666 \n",
       "L 3169 4134 \n",
       "L 1269 4134 \n",
       "L 1269 2991 \n",
       "Q 1406 3038 1543 3061 \n",
       "Q 1681 3084 1819 3084 \n",
       "Q 2600 3084 3056 2656 \n",
       "Q 3513 2228 3513 1497 \n",
       "Q 3513 744 3044 326 \n",
       "Q 2575 -91 1722 -91 \n",
       "Q 1428 -91 1123 -41 \n",
       "Q 819 9 494 109 \n",
       "L 494 744 \n",
       "Q 775 591 1075 516 \n",
       "Q 1375 441 1709 441 \n",
       "Q 2250 441 2565 725 \n",
       "Q 2881 1009 2881 1497 \n",
       "Q 2881 1984 2565 2268 \n",
       "Q 2250 2553 1709 2553 \n",
       "Q 1456 2553 1204 2497 \n",
       "Q 953 2441 691 2322 \n",
       "L 691 4666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#DejaVuSans-35\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_8\">\n",
       "     <!-- x -->\n",
       "     <g transform=\"translate(207.060938 259.90635) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-78\" d=\"M 3513 3500 \n",
       "L 2247 1797 \n",
       "L 3578 0 \n",
       "L 2900 0 \n",
       "L 1881 1375 \n",
       "L 863 0 \n",
       "L 184 0 \n",
       "L 1544 1831 \n",
       "L 300 3500 \n",
       "L 978 3500 \n",
       "L 1906 2253 \n",
       "L 2834 3500 \n",
       "L 3513 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-78\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <path d=\"M 42.620313 222.398226 \n",
       "L 377.420313 222.398226 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_16\">\n",
       "      <defs>\n",
       "       <path id=\"md6a938e82c\" d=\"M 0 0 \n",
       "L -3.5 0 \n",
       "\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#md6a938e82c\" x=\"42.620313\" y=\"222.398226\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −5 -->\n",
       "      <g transform=\"translate(20.878125 226.197445) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-2212\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"83.789062\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <path d=\"M 42.620313 192.198368 \n",
       "L 377.420313 192.198368 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md6a938e82c\" x=\"42.620313\" y=\"192.198368\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 0 -->\n",
       "      <g transform=\"translate(29.257813 195.997586) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <path d=\"M 42.620313 161.998509 \n",
       "L 377.420313 161.998509 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md6a938e82c\" x=\"42.620313\" y=\"161.998509\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 5 -->\n",
       "      <g transform=\"translate(29.257813 165.797728) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-35\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <path d=\"M 42.620313 131.798651 \n",
       "L 377.420313 131.798651 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md6a938e82c\" x=\"42.620313\" y=\"131.798651\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 10 -->\n",
       "      <g transform=\"translate(22.895313 135.59787) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <path d=\"M 42.620313 101.598793 \n",
       "L 377.420313 101.598793 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md6a938e82c\" x=\"42.620313\" y=\"101.598793\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 15 -->\n",
       "      <g transform=\"translate(22.895313 105.398012) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-31\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"63.623047\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <path d=\"M 42.620313 71.398935 \n",
       "L 377.420313 71.398935 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md6a938e82c\" x=\"42.620313\" y=\"71.398935\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 20 -->\n",
       "      <g transform=\"translate(22.895313 75.198154) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <path d=\"M 42.620313 41.199077 \n",
       "L 377.420313 41.199077 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md6a938e82c\" x=\"42.620313\" y=\"41.199077\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 25 -->\n",
       "      <g transform=\"translate(22.895313 44.998296) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-32\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-35\" x=\"63.623047\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <path d=\"M 42.620313 10.999219 \n",
       "L 377.420313 10.999219 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke-dasharray: 0.8,1.32; stroke-dashoffset: 0; stroke: #b0b0b0; stroke-width: 0.8\"/>\n",
       "     </g>\n",
       "     <g id=\"line2d_30\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md6a938e82c\" x=\"42.620313\" y=\"10.999219\" style=\"stroke: #000000; stroke-width: 0.8\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 30 -->\n",
       "      <g transform=\"translate(22.895313 14.798437) scale(0.1 -0.1)\">\n",
       "       <use xlink:href=\"#DejaVuSans-33\"/>\n",
       "       <use xlink:href=\"#DejaVuSans-30\" x=\"63.623047\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- y -->\n",
       "     <g transform=\"translate(14.798438 123.709162) rotate(-90) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-79\" d=\"M 2059 -325 \n",
       "Q 1816 -950 1584 -1140 \n",
       "Q 1353 -1331 966 -1331 \n",
       "L 506 -1331 \n",
       "L 506 -850 \n",
       "L 844 -850 \n",
       "Q 1081 -850 1212 -737 \n",
       "Q 1344 -625 1503 -206 \n",
       "L 1606 56 \n",
       "L 191 3500 \n",
       "L 800 3500 \n",
       "L 1894 763 \n",
       "L 2988 3500 \n",
       "L 3597 3500 \n",
       "L 2059 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-79\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_31\">\n",
       "    <path d=\"M 57.838494 188.40062 \n",
       "L 124.030986 187.954272 \n",
       "L 138.853231 187.597348 \n",
       "L 151.645032 187.066742 \n",
       "L 163.827699 186.345055 \n",
       "L 170.934255 185.727705 \n",
       "L 175.807322 185.091332 \n",
       "L 179.665167 184.372905 \n",
       "L 183.116922 183.508093 \n",
       "L 186.365634 182.464785 \n",
       "L 189.614345 181.18305 \n",
       "L 193.066101 179.571096 \n",
       "L 196.923945 177.517572 \n",
       "L 202.406145 174.318002 \n",
       "L 227.583658 159.095659 \n",
       "L 231.847591 156.110517 \n",
       "L 235.705436 153.139243 \n",
       "L 239.766325 149.725181 \n",
       "L 245.248525 144.782577 \n",
       "L 251.745948 138.963297 \n",
       "L 255.603792 135.8204 \n",
       "L 259.461637 132.970158 \n",
       "L 269.61386 125.671658 \n",
       "L 272.456482 123.249853 \n",
       "L 275.299104 120.534726 \n",
       "L 278.344771 117.302292 \n",
       "L 282.202616 112.853718 \n",
       "L 288.496994 105.572713 \n",
       "L 291.339616 102.65454 \n",
       "L 293.77615 100.461825 \n",
       "L 296.009639 98.729624 \n",
       "L 298.243128 97.263089 \n",
       "L 300.476617 96.044694 \n",
       "L 302.91315 94.963354 \n",
       "L 305.755773 93.961074 \n",
       "L 310.22275 92.681499 \n",
       "L 313.065373 91.771866 \n",
       "L 314.892773 90.983268 \n",
       "L 316.517129 90.047932 \n",
       "L 317.93844 88.985478 \n",
       "L 319.359751 87.650037 \n",
       "L 320.781062 86.017641 \n",
       "L 322.405418 83.795472 \n",
       "L 324.435862 80.577018 \n",
       "L 331.745463 68.463372 \n",
       "L 333.572863 66.036288 \n",
       "L 335.400263 63.957061 \n",
       "L 337.227663 62.206166 \n",
       "L 339.055063 60.747072 \n",
       "L 341.085507 59.416878 \n",
       "L 343.318996 58.243206 \n",
       "L 345.75553 57.235474 \n",
       "L 348.395108 56.389079 \n",
       "L 351.440775 55.647368 \n",
       "L 355.095575 54.994439 \n",
       "L 359.562553 54.435095 \n",
       "L 362.202131 54.190505 \n",
       "L 362.202131 54.190505 \n",
       "\" clip-path=\"url(#p88b5a78c04)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 2; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 42.620313 231.629787 \n",
       "L 42.620313 9.869787 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 377.420313 231.629787 \n",
       "L 377.420313 9.869787 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 42.620312 231.629787 \n",
       "L 377.420313 231.629787 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 42.620312 9.869787 \n",
       "L 377.420313 9.869787 \n",
       "\" style=\"fill: none; stroke: #000000; stroke-width: 0.8; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"patch_7\">\n",
       "     <path d=\"M 49.620313 47.226037 \n",
       "L 112.759375 47.226037 \n",
       "Q 114.759375 47.226037 114.759375 45.226037 \n",
       "L 114.759375 16.869787 \n",
       "Q 114.759375 14.869787 112.759375 14.869787 \n",
       "L 49.620313 14.869787 \n",
       "Q 47.620313 14.869787 47.620313 16.869787 \n",
       "L 47.620313 45.226037 \n",
       "Q 47.620313 47.226037 49.620313 47.226037 \n",
       "z\n",
       "\" style=\"fill: #ffffff; opacity: 0.8; stroke: #cccccc; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"PathCollection_2\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mdf0c0967a6\" x=\"61.620313\" y=\"23.843225\" style=\"fill-opacity: 0.7; stroke: #000000; stroke-opacity: 0.7\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- data -->\n",
       "     <g transform=\"translate(79.620313 26.468225) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-64\" d=\"M 2906 2969 \n",
       "L 2906 4863 \n",
       "L 3481 4863 \n",
       "L 3481 0 \n",
       "L 2906 0 \n",
       "L 2906 525 \n",
       "Q 2725 213 2448 61 \n",
       "Q 2172 -91 1784 -91 \n",
       "Q 1150 -91 751 415 \n",
       "Q 353 922 353 1747 \n",
       "Q 353 2572 751 3078 \n",
       "Q 1150 3584 1784 3584 \n",
       "Q 2172 3584 2448 3432 \n",
       "Q 2725 3281 2906 2969 \n",
       "z\n",
       "M 947 1747 \n",
       "Q 947 1113 1208 752 \n",
       "Q 1469 391 1925 391 \n",
       "Q 2381 391 2643 752 \n",
       "Q 2906 1113 2906 1747 \n",
       "Q 2906 2381 2643 2742 \n",
       "Q 2381 3103 1925 3103 \n",
       "Q 1469 3103 1208 2742 \n",
       "Q 947 2381 947 1747 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-61\" d=\"M 2194 1759 \n",
       "Q 1497 1759 1228 1600 \n",
       "Q 959 1441 959 1056 \n",
       "Q 959 750 1161 570 \n",
       "Q 1363 391 1709 391 \n",
       "Q 2188 391 2477 730 \n",
       "Q 2766 1069 2766 1631 \n",
       "L 2766 1759 \n",
       "L 2194 1759 \n",
       "z\n",
       "M 3341 1997 \n",
       "L 3341 0 \n",
       "L 2766 0 \n",
       "L 2766 531 \n",
       "Q 2569 213 2275 61 \n",
       "Q 1981 -91 1556 -91 \n",
       "Q 1019 -91 701 211 \n",
       "Q 384 513 384 1019 \n",
       "Q 384 1609 779 1909 \n",
       "Q 1175 2209 1959 2209 \n",
       "L 2766 2209 \n",
       "L 2766 2266 \n",
       "Q 2766 2663 2505 2880 \n",
       "Q 2244 3097 1772 3097 \n",
       "Q 1472 3097 1187 3025 \n",
       "Q 903 2953 641 2809 \n",
       "L 641 3341 \n",
       "Q 956 3463 1253 3523 \n",
       "Q 1550 3584 1831 3584 \n",
       "Q 2591 3584 2966 3190 \n",
       "Q 3341 2797 3341 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-74\" d=\"M 1172 4494 \n",
       "L 1172 3500 \n",
       "L 2356 3500 \n",
       "L 2356 3053 \n",
       "L 1172 3053 \n",
       "L 1172 1153 \n",
       "Q 1172 725 1289 603 \n",
       "Q 1406 481 1766 481 \n",
       "L 2356 481 \n",
       "L 2356 0 \n",
       "L 1766 0 \n",
       "Q 1100 0 847 248 \n",
       "Q 594 497 594 1153 \n",
       "L 594 3053 \n",
       "L 172 3053 \n",
       "L 172 3500 \n",
       "L 594 3500 \n",
       "L 594 4494 \n",
       "L 1172 4494 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-64\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"63.476562\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-74\" x=\"124.755859\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-61\" x=\"163.964844\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_32\">\n",
       "     <path d=\"M 51.620313 37.64635 \n",
       "L 61.620313 37.64635 \n",
       "L 71.620313 37.64635 \n",
       "\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 2; stroke-linecap: square\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- model -->\n",
       "     <g transform=\"translate(79.620313 41.14635) scale(0.1 -0.1)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-6d\" d=\"M 3328 2828 \n",
       "Q 3544 3216 3844 3400 \n",
       "Q 4144 3584 4550 3584 \n",
       "Q 5097 3584 5394 3201 \n",
       "Q 5691 2819 5691 2113 \n",
       "L 5691 0 \n",
       "L 5113 0 \n",
       "L 5113 2094 \n",
       "Q 5113 2597 4934 2840 \n",
       "Q 4756 3084 4391 3084 \n",
       "Q 3944 3084 3684 2787 \n",
       "Q 3425 2491 3425 1978 \n",
       "L 3425 0 \n",
       "L 2847 0 \n",
       "L 2847 2094 \n",
       "Q 2847 2600 2669 2842 \n",
       "Q 2491 3084 2119 3084 \n",
       "Q 1678 3084 1418 2786 \n",
       "Q 1159 2488 1159 1978 \n",
       "L 1159 0 \n",
       "L 581 0 \n",
       "L 581 3500 \n",
       "L 1159 3500 \n",
       "L 1159 2956 \n",
       "Q 1356 3278 1631 3431 \n",
       "Q 1906 3584 2284 3584 \n",
       "Q 2666 3584 2933 3390 \n",
       "Q 3200 3197 3328 2828 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6f\" d=\"M 1959 3097 \n",
       "Q 1497 3097 1228 2736 \n",
       "Q 959 2375 959 1747 \n",
       "Q 959 1119 1226 758 \n",
       "Q 1494 397 1959 397 \n",
       "Q 2419 397 2687 759 \n",
       "Q 2956 1122 2956 1747 \n",
       "Q 2956 2369 2687 2733 \n",
       "Q 2419 3097 1959 3097 \n",
       "z\n",
       "M 1959 3584 \n",
       "Q 2709 3584 3137 3096 \n",
       "Q 3566 2609 3566 1747 \n",
       "Q 3566 888 3137 398 \n",
       "Q 2709 -91 1959 -91 \n",
       "Q 1206 -91 779 398 \n",
       "Q 353 888 353 1747 \n",
       "Q 353 2609 779 3096 \n",
       "Q 1206 3584 1959 3584 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-65\" d=\"M 3597 1894 \n",
       "L 3597 1613 \n",
       "L 953 1613 \n",
       "Q 991 1019 1311 708 \n",
       "Q 1631 397 2203 397 \n",
       "Q 2534 397 2845 478 \n",
       "Q 3156 559 3463 722 \n",
       "L 3463 178 \n",
       "Q 3153 47 2828 -22 \n",
       "Q 2503 -91 2169 -91 \n",
       "Q 1331 -91 842 396 \n",
       "Q 353 884 353 1716 \n",
       "Q 353 2575 817 3079 \n",
       "Q 1281 3584 2069 3584 \n",
       "Q 2775 3584 3186 3129 \n",
       "Q 3597 2675 3597 1894 \n",
       "z\n",
       "M 3022 2063 \n",
       "Q 3016 2534 2758 2815 \n",
       "Q 2500 3097 2075 3097 \n",
       "Q 1594 3097 1305 2825 \n",
       "Q 1016 2553 972 2059 \n",
       "L 3022 2063 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-6c\" d=\"M 603 4863 \n",
       "L 1178 4863 \n",
       "L 1178 0 \n",
       "L 603 0 \n",
       "L 603 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-6d\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6f\" x=\"97.412109\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-64\" x=\"158.59375\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-65\" x=\"222.070312\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-6c\" x=\"283.59375\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p88b5a78c04\">\n",
       "   <rect x=\"42.620313\" y=\"9.869787\" width=\"334.8\" height=\"221.76\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 600x400 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "plt.figure(figsize=(6, 4))\n",
    "plt.scatter(X, Y, label=\"data\", s=2, alpha=0.7, color=\"black\")\n",
    "plt.plot(X, [model([Node(x)]).data for x in X], label=\"model\", color=\"C1\", linewidth=2)\n",
    "\n",
    "plt.ylabel(\"y\")\n",
    "plt.xlabel(\"x\")\n",
    "plt.grid(linestyle=\"dotted\")\n",
    "plt.legend();"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "7fdbd2b5",
   "metadata": {
    "papermill": {
     "duration": 0.023211,
     "end_time": "2024-09-05T18:33:17.695522",
     "exception": false,
     "start_time": "2024-09-05T18:33:17.672311",
     "status": "completed"
    },
    "tags": []
   },
   "source": [
    "Model graph visualization:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "id": "18d1cb02",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2024-09-05T18:33:17.744022Z",
     "iopub.status.busy": "2024-09-05T18:33:17.743608Z",
     "iopub.status.idle": "2024-09-05T18:33:18.022342Z",
     "shell.execute_reply": "2024-09-05T18:33:18.021806Z"
    },
    "papermill": {
     "duration": 0.305647,
     "end_time": "2024-09-05T18:33:18.025043",
     "exception": false,
     "start_time": "2024-09-05T18:33:17.719396",
     "status": "completed"
    },
    "tags": []
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       " \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<!-- Generated by graphviz version 12.1.0 (20240811.2233)\n",
       " -->\n",
       "<!-- Pages: 1 -->\n",
       "<svg width=\"4010pt\" height=\"1381pt\"\n",
       " viewBox=\"0.00 0.00 4009.50 1381.00\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">\n",
       "<g id=\"graph0\" class=\"graph\" transform=\"scale(1 1) rotate(0) translate(4 1377)\">\n",
       "<polygon fill=\"white\" stroke=\"none\" points=\"-4,4 -4,-1377 4005.5,-1377 4005.5,4 -4,4\"/>\n",
       "<!-- 4690042912 -->\n",
       "<g id=\"node1\" class=\"node\">\n",
       "<title>4690042912</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-129.5 1937.5,-178.5 2023.25,-178.5 2023.25,-129.5 1937.5,-129.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-161.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.032</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-154 2023.25,-154\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-136.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226064* -->\n",
       "<g id=\"node175\" class=\"node\">\n",
       "<title>4694226064*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2086.25\" cy=\"-222\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2086.25\" y=\"-216.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690042912&#45;&gt;4694226064* -->\n",
       "<g id=\"edge258\" class=\"edge\">\n",
       "<title>4690042912&#45;&gt;4694226064*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2019.46,-178.93C2031.74,-186.97 2045.12,-195.73 2056.59,-203.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2054.56,-206.09 2064.84,-208.64 2058.39,-200.23 2054.56,-206.09\"/>\n",
       "</g>\n",
       "<!-- 4694212672 -->\n",
       "<g id=\"node2\" class=\"node\">\n",
       "<title>4694212672</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"667,-845.5 667,-894.5 752.75,-894.5 752.75,-845.5 667,-845.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-877.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.999</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"667,-870 752.75,-870\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-852.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694262640* -->\n",
       "<g id=\"node30\" class=\"node\">\n",
       "<title>4694262640*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"815.75\" cy=\"-374\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"815.75\" y=\"-368.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694212672&#45;&gt;4694262640* -->\n",
       "<g id=\"edge194\" class=\"edge\">\n",
       "<title>4694212672&#45;&gt;4694262640*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M739.61,-845.1C744.74,-839.33 749.48,-832.85 752.75,-826 806.02,-714.35 771.71,-672.53 788.75,-550 795.92,-498.41 804.93,-438.43 810.24,-403.49\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"813.68,-404.14 811.73,-393.72 806.76,-403.08 813.68,-404.14\"/>\n",
       "</g>\n",
       "<!-- 4694224912* -->\n",
       "<g id=\"node147\" class=\"node\">\n",
       "<title>4694224912*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"815.75\" cy=\"-650\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"815.75\" y=\"-644.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694212672&#45;&gt;4694224912* -->\n",
       "<g id=\"edge277\" class=\"edge\">\n",
       "<title>4694212672&#45;&gt;4694224912*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M737.66,-845.47C743.17,-839.49 748.56,-832.83 752.75,-826 781.92,-778.39 799.91,-715.12 808.56,-678.85\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"811.87,-680.08 810.7,-669.55 805.05,-678.51 811.87,-680.08\"/>\n",
       "</g>\n",
       "<!-- 4694226544* -->\n",
       "<g id=\"node185\" class=\"node\">\n",
       "<title>4694226544*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"815.75\" cy=\"-917\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"815.75\" y=\"-911.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694212672&#45;&gt;4694226544* -->\n",
       "<g id=\"edge160\" class=\"edge\">\n",
       "<title>4694212672&#45;&gt;4694226544*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M753.12,-889.12C762.89,-893.54 773.14,-898.17 782.41,-902.37\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"780.82,-905.49 791.37,-906.42 783.71,-899.11 780.82,-905.49\"/>\n",
       "</g>\n",
       "<!-- 4694228176* -->\n",
       "<g id=\"node233\" class=\"node\">\n",
       "<title>4694228176*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"815.75\" cy=\"-1030\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"815.75\" y=\"-1024.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694212672&#45;&gt;4694228176* -->\n",
       "<g id=\"edge234\" class=\"edge\">\n",
       "<title>4694212672&#45;&gt;4694228176*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M744.18,-894.7C747.26,-897.66 750.18,-900.78 752.75,-904 776.69,-934.02 794.64,-974.8 804.91,-1001.73\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"801.56,-1002.77 808.31,-1010.93 808.13,-1000.34 801.56,-1002.77\"/>\n",
       "</g>\n",
       "<!-- 4694212672tanh -->\n",
       "<g id=\"node3\" class=\"node\">\n",
       "<title>4694212672tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"604\" cy=\"-889\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"604\" y=\"-883.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694212672tanh&#45;&gt;4694212672 -->\n",
       "<g id=\"edge1\" class=\"edge\">\n",
       "<title>4694212672tanh&#45;&gt;4694212672</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M630.41,-884.35C638.1,-882.95 646.84,-881.35 655.64,-879.74\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"656.03,-883.22 665.24,-877.98 654.77,-876.34 656.03,-883.22\"/>\n",
       "</g>\n",
       "<!-- 4694261872 -->\n",
       "<g id=\"node4\" class=\"node\">\n",
       "<title>4694261872</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-877.5 1937.5,-926.5 2023.25,-926.5 2023.25,-877.5 1937.5,-877.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-909.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;2.183</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-902 2023.25,-902\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-884.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694262064+ -->\n",
       "<g id=\"node10\" class=\"node\">\n",
       "<title>4694262064+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2086.25\" cy=\"-630\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2086.25\" y=\"-624.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694261872&#45;&gt;4694262064+ -->\n",
       "<g id=\"edge268\" class=\"edge\">\n",
       "<title>4694261872&#45;&gt;4694262064+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2015.78,-877.38C2018.56,-874.44 2021.12,-871.31 2023.25,-868 2065.98,-801.61 2079.33,-706.96 2083.45,-659.51\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2086.92,-659.99 2084.21,-649.75 2079.94,-659.45 2086.92,-659.99\"/>\n",
       "</g>\n",
       "<!-- 4694261872+ -->\n",
       "<g id=\"node5\" class=\"node\">\n",
       "<title>4694261872+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1874.5\" cy=\"-902\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1874.5\" y=\"-896.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694261872+&#45;&gt;4694261872 -->\n",
       "<g id=\"edge2\" class=\"edge\">\n",
       "<title>4694261872+&#45;&gt;4694261872</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1901.98,-902C1909.34,-902 1917.6,-902 1925.91,-902\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1925.69,-905.5 1935.69,-902 1925.69,-898.5 1925.69,-905.5\"/>\n",
       "</g>\n",
       "<!-- 4690043008 -->\n",
       "<g id=\"node6\" class=\"node\">\n",
       "<title>4690043008</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-741.5 2150.75,-790.5 2236.5,-790.5 2236.5,-741.5 2150.75,-741.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-773.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.265</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-766 2236.5,-766\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-748.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226256* -->\n",
       "<g id=\"node179\" class=\"node\">\n",
       "<title>4694226256*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2301\" cy=\"-766\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2301\" y=\"-760.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690043008&#45;&gt;4694226256* -->\n",
       "<g id=\"edge190\" class=\"edge\">\n",
       "<title>4690043008&#45;&gt;4694226256*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2236.88,-766C2245.19,-766 2253.86,-766 2262.02,-766\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2261.99,-769.5 2271.99,-766 2261.99,-762.5 2261.99,-769.5\"/>\n",
       "</g>\n",
       "<!-- 4694261968 -->\n",
       "<g id=\"node7\" class=\"node\">\n",
       "<title>4694261968</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-537.5 1937.5,-586.5 2023.25,-586.5 2023.25,-537.5 1937.5,-537.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-569.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.288</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-562 2023.25,-562\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-544.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694261968&#45;&gt;4694262064+ -->\n",
       "<g id=\"edge224\" class=\"edge\">\n",
       "<title>4694261968&#45;&gt;4694262064+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2019.46,-586.93C2031.74,-594.97 2045.12,-603.73 2056.59,-611.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2054.56,-614.09 2064.84,-616.64 2058.39,-608.23 2054.56,-614.09\"/>\n",
       "</g>\n",
       "<!-- 4694261968* -->\n",
       "<g id=\"node8\" class=\"node\">\n",
       "<title>4694261968*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1874.5\" cy=\"-562\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1874.5\" y=\"-556.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694261968*&#45;&gt;4694261968 -->\n",
       "<g id=\"edge3\" class=\"edge\">\n",
       "<title>4694261968*&#45;&gt;4694261968</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1901.98,-562C1909.34,-562 1917.6,-562 1925.91,-562\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1925.69,-565.5 1935.69,-562 1925.69,-558.5 1925.69,-565.5\"/>\n",
       "</g>\n",
       "<!-- 4694262064 -->\n",
       "<g id=\"node9\" class=\"node\">\n",
       "<title>4694262064</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-605.5 2150.75,-654.5 2236.5,-654.5 2236.5,-605.5 2150.75,-605.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-637.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;2.471</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-630 2236.5,-630\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-612.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694262256+ -->\n",
       "<g id=\"node18\" class=\"node\">\n",
       "<title>4694262256+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2301\" cy=\"-630\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2301\" y=\"-624.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694262064&#45;&gt;4694262256+ -->\n",
       "<g id=\"edge155\" class=\"edge\">\n",
       "<title>4694262064&#45;&gt;4694262256+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2236.88,-630C2245.19,-630 2253.86,-630 2262.02,-630\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2261.99,-633.5 2271.99,-630 2261.99,-626.5 2261.99,-633.5\"/>\n",
       "</g>\n",
       "<!-- 4694262064+&#45;&gt;4694262064 -->\n",
       "<g id=\"edge4\" class=\"edge\">\n",
       "<title>4694262064+&#45;&gt;4694262064</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2113.57,-630C2121.28,-630 2130.01,-630 2138.79,-630\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2138.75,-633.5 2148.75,-630 2138.75,-626.5 2138.75,-633.5\"/>\n",
       "</g>\n",
       "<!-- 4690043248 -->\n",
       "<g id=\"node11\" class=\"node\">\n",
       "<title>4690043248</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"667,-913.5 667,-962.5 752.75,-962.5 752.75,-913.5 667,-913.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-945.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.150</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"667,-938 752.75,-938\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-920.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690043248&#45;&gt;4694226544* -->\n",
       "<g id=\"edge242\" class=\"edge\">\n",
       "<title>4690043248&#45;&gt;4694226544*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M753.12,-929.46C761.52,-927.76 770.27,-925.99 778.45,-924.34\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"778.95,-927.81 788.05,-922.4 777.56,-920.95 778.95,-927.81\"/>\n",
       "</g>\n",
       "<!-- 4694262160 -->\n",
       "<g id=\"node12\" class=\"node\">\n",
       "<title>4694262160</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-401.5 2150.75,-450.5 2236.5,-450.5 2236.5,-401.5 2150.75,-401.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-433.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.298</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-426 2236.5,-426\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-408.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694262160&#45;&gt;4694262256+ -->\n",
       "<g id=\"edge136\" class=\"edge\">\n",
       "<title>4694262160&#45;&gt;4694262256+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2230.61,-450.97C2233.35,-453.8 2235.87,-456.82 2238,-460 2271.07,-509.49 2249.8,-534.62 2274,-589 2276.28,-594.12 2279.13,-599.35 2282.1,-604.28\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2279.07,-606.04 2287.4,-612.59 2284.97,-602.28 2279.07,-606.04\"/>\n",
       "</g>\n",
       "<!-- 4694262160* -->\n",
       "<g id=\"node13\" class=\"node\">\n",
       "<title>4694262160*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2086.25\" cy=\"-426\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2086.25\" y=\"-420.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694262160*&#45;&gt;4694262160 -->\n",
       "<g id=\"edge5\" class=\"edge\">\n",
       "<title>4694262160*&#45;&gt;4694262160</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2113.57,-426C2121.28,-426 2130.01,-426 2138.79,-426\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2138.75,-429.5 2148.75,-426 2138.75,-422.5 2138.75,-429.5\"/>\n",
       "</g>\n",
       "<!-- 4690043296 -->\n",
       "<g id=\"node14\" class=\"node\">\n",
       "<title>4690043296</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-960.5 878.75,-1009.5 964.5,-1009.5 964.5,-960.5 878.75,-960.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-992.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.930</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-985 964.5,-985\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-967.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226640+ -->\n",
       "<g id=\"node191\" class=\"node\">\n",
       "<title>4694226640+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1027.5\" cy=\"-985\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1027.5\" y=\"-979.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4690043296&#45;&gt;4694226640+ -->\n",
       "<g id=\"edge180\" class=\"edge\">\n",
       "<title>4690043296&#45;&gt;4694226640+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M964.87,-985C972.78,-985 981,-985 988.76,-985\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"988.57,-988.5 998.57,-985 988.57,-981.5 988.57,-988.5\"/>\n",
       "</g>\n",
       "<!-- 4694213056 -->\n",
       "<g id=\"node15\" class=\"node\">\n",
       "<title>4694213056</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"455.25,-902.5 455.25,-951.5 541,-951.5 541,-902.5 455.25,-902.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-934.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;3.818</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"455.25,-927 541,-927\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-909.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694213056&#45;&gt;4694212672tanh -->\n",
       "<g id=\"edge269\" class=\"edge\">\n",
       "<title>4694213056&#45;&gt;4694212672tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M541.37,-911.54C550.62,-908.16 560.28,-904.63 569.15,-901.38\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"570.24,-904.71 578.43,-897.99 567.83,-898.14 570.24,-904.71\"/>\n",
       "</g>\n",
       "<!-- 4694213056+ -->\n",
       "<g id=\"node16\" class=\"node\">\n",
       "<title>4694213056+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"376.38\" cy=\"-993\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"376.38\" y=\"-987.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694213056+&#45;&gt;4694213056 -->\n",
       "<g id=\"edge6\" class=\"edge\">\n",
       "<title>4694213056+&#45;&gt;4694213056</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M397.96,-981.65C411.04,-974.44 428.6,-964.77 445.31,-955.56\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"446.61,-958.84 453.68,-950.94 443.23,-952.71 446.61,-958.84\"/>\n",
       "</g>\n",
       "<!-- 4694262256 -->\n",
       "<g id=\"node17\" class=\"node\">\n",
       "<title>4694262256</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2365.5,-605.5 2365.5,-654.5 2451.25,-654.5 2451.25,-605.5 2365.5,-605.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-637.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;2.769</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2365.5,-630 2451.25,-630\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-612.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694262448+ -->\n",
       "<g id=\"node24\" class=\"node\">\n",
       "<title>4694262448+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2515.75\" cy=\"-834\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2515.75\" y=\"-828.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694262256&#45;&gt;4694262448+ -->\n",
       "<g id=\"edge226\" class=\"edge\">\n",
       "<title>4694262256&#45;&gt;4694262448+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2444.68,-654.74C2447.64,-657.65 2450.39,-660.75 2452.75,-664 2484.33,-707.51 2501.4,-768.83 2509.24,-804.7\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2505.78,-805.26 2511.25,-814.34 2512.64,-803.84 2505.78,-805.26\"/>\n",
       "</g>\n",
       "<!-- 4694262256+&#45;&gt;4694262256 -->\n",
       "<g id=\"edge7\" class=\"edge\">\n",
       "<title>4694262256+&#45;&gt;4694262256</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2328.32,-630C2336.03,-630 2344.76,-630 2353.54,-630\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2353.5,-633.5 2363.5,-630 2353.5,-626.5 2353.5,-633.5\"/>\n",
       "</g>\n",
       "<!-- 4690043392 -->\n",
       "<g id=\"node19\" class=\"node\">\n",
       "<title>4690043392</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-688.5 878.75,-737.5 964.5,-737.5 964.5,-688.5 878.75,-688.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-720.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.869</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-713 964.5,-713\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-695.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226736* -->\n",
       "<g id=\"node193\" class=\"node\">\n",
       "<title>4694226736*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1027.5\" cy=\"-713\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1027.5\" y=\"-707.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690043392&#45;&gt;4694226736* -->\n",
       "<g id=\"edge245\" class=\"edge\">\n",
       "<title>4690043392&#45;&gt;4694226736*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M964.87,-713C972.78,-713 981,-713 988.76,-713\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"988.57,-716.5 998.57,-713 988.57,-709.5 988.57,-716.5\"/>\n",
       "</g>\n",
       "<!-- 4694262352 -->\n",
       "<g id=\"node20\" class=\"node\">\n",
       "<title>4694262352</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2365.5,-877.5 2365.5,-926.5 2451.25,-926.5 2451.25,-877.5 2365.5,-877.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-909.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.283</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2365.5,-902 2451.25,-902\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-884.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694262352&#45;&gt;4694262448+ -->\n",
       "<g id=\"edge202\" class=\"edge\">\n",
       "<title>4694262352&#45;&gt;4694262448+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2448.01,-877.07C2460.68,-868.89 2474.51,-859.97 2486.29,-852.37\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2487.84,-855.53 2494.35,-847.17 2484.05,-849.65 2487.84,-855.53\"/>\n",
       "</g>\n",
       "<!-- 4694262352* -->\n",
       "<g id=\"node21\" class=\"node\">\n",
       "<title>4694262352*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2301\" cy=\"-902\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2301\" y=\"-896.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694262352*&#45;&gt;4694262352 -->\n",
       "<g id=\"edge8\" class=\"edge\">\n",
       "<title>4694262352*&#45;&gt;4694262352</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2328.32,-902C2336.03,-902 2344.76,-902 2353.54,-902\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2353.5,-905.5 2363.5,-902 2353.5,-898.5 2353.5,-905.5\"/>\n",
       "</g>\n",
       "<!-- 4690043488 -->\n",
       "<g id=\"node22\" class=\"node\">\n",
       "<title>4690043488</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-756.5 1090.5,-805.5 1176.25,-805.5 1176.25,-756.5 1090.5,-756.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-788.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.085</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-781 1176.25,-781\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-763.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226928* -->\n",
       "<g id=\"node199\" class=\"node\">\n",
       "<title>4694226928*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1239.25\" cy=\"-781\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1239.25\" y=\"-775.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690043488&#45;&gt;4694226928* -->\n",
       "<g id=\"edge120\" class=\"edge\">\n",
       "<title>4690043488&#45;&gt;4694226928*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1176.62,-781C1184.53,-781 1192.75,-781 1200.51,-781\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1200.32,-784.5 1210.32,-781 1200.32,-777.5 1200.32,-784.5\"/>\n",
       "</g>\n",
       "<!-- 4694262448 -->\n",
       "<g id=\"node23\" class=\"node\">\n",
       "<title>4694262448</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2580.25,-809.5 2580.25,-858.5 2666,-858.5 2666,-809.5 2580.25,-809.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2623.12\" y=\"-841.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;3.052</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2580.25,-834 2666,-834\"/>\n",
       "<text text-anchor=\"middle\" x=\"2623.12\" y=\"-816.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228224tanh -->\n",
       "<g id=\"node235\" class=\"node\">\n",
       "<title>4694228224tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2730.5\" cy=\"-834\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2730.5\" y=\"-828.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694262448&#45;&gt;4694228224tanh -->\n",
       "<g id=\"edge126\" class=\"edge\">\n",
       "<title>4694262448&#45;&gt;4694228224tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2666.38,-834C2674.69,-834 2683.36,-834 2691.52,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2691.49,-837.5 2701.49,-834 2691.49,-830.5 2691.49,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4694262448+&#45;&gt;4694262448 -->\n",
       "<g id=\"edge9\" class=\"edge\">\n",
       "<title>4694262448+&#45;&gt;4694262448</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2543.07,-834C2550.78,-834 2559.51,-834 2568.29,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2568.25,-837.5 2578.25,-834 2568.25,-830.5 2568.25,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4690043584 -->\n",
       "<g id=\"node25\" class=\"node\">\n",
       "<title>4690043584</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-605.5 1302.25,-654.5 1388,-654.5 1388,-605.5 1302.25,-605.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-637.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.512</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-630 1388,-630\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-612.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227120* -->\n",
       "<g id=\"node203\" class=\"node\">\n",
       "<title>4694227120*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1451\" cy=\"-630\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1451\" y=\"-624.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690043584&#45;&gt;4694227120* -->\n",
       "<g id=\"edge228\" class=\"edge\">\n",
       "<title>4690043584&#45;&gt;4694227120*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1388.37,-630C1396.28,-630 1404.5,-630 1412.26,-630\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1412.07,-633.5 1422.07,-630 1412.07,-626.5 1412.07,-633.5\"/>\n",
       "</g>\n",
       "<!-- 4694221552 -->\n",
       "<g id=\"node26\" class=\"node\">\n",
       "<title>4694221552</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"455.25,-609.5 455.25,-658.5 541,-658.5 541,-609.5 455.25,-609.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-641.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.350</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"455.25,-634 541,-634\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-616.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694222992+ -->\n",
       "<g id=\"node75\" class=\"node\">\n",
       "<title>4694222992+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"604\" cy=\"-577\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"604\" y=\"-571.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694221552&#45;&gt;4694222992+ -->\n",
       "<g id=\"edge189\" class=\"edge\">\n",
       "<title>4694221552&#45;&gt;4694222992+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M541.37,-610.82C551.77,-605.11 562.7,-599.11 572.42,-593.78\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"574.01,-596.9 581.09,-589.02 570.64,-590.77 574.01,-596.9\"/>\n",
       "</g>\n",
       "<!-- 4694221552* -->\n",
       "<g id=\"node27\" class=\"node\">\n",
       "<title>4694221552*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"376.38\" cy=\"-634\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"376.38\" y=\"-628.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694221552*&#45;&gt;4694221552 -->\n",
       "<g id=\"edge10\" class=\"edge\">\n",
       "<title>4694221552*&#45;&gt;4694221552</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M403.65,-634C415.38,-634 429.65,-634 443.47,-634\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"443.39,-637.5 453.39,-634 443.39,-630.5 443.39,-637.5\"/>\n",
       "</g>\n",
       "<!-- 4690043680 -->\n",
       "<g id=\"node28\" class=\"node\">\n",
       "<title>4690043680</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-1255.5 1514,-1304.5 1599.75,-1304.5 1599.75,-1255.5 1514,-1255.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-1287.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.402</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-1280 1599.75,-1280\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-1262.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227312* -->\n",
       "<g id=\"node209\" class=\"node\">\n",
       "<title>4694227312*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1662.75\" cy=\"-1205\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1662.75\" y=\"-1199.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690043680&#45;&gt;4694227312* -->\n",
       "<g id=\"edge201\" class=\"edge\">\n",
       "<title>4690043680&#45;&gt;4694227312*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1592.46,-1255.03C1606.1,-1245.18 1621.54,-1234.03 1634.38,-1224.76\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1636.34,-1227.67 1642.39,-1218.98 1632.24,-1221.99 1636.34,-1227.67\"/>\n",
       "</g>\n",
       "<!-- 4694262640 -->\n",
       "<g id=\"node29\" class=\"node\">\n",
       "<title>4694262640</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-212.5 878.75,-261.5 964.5,-261.5 964.5,-212.5 878.75,-212.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-244.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.527</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-237 964.5,-237\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-219.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694262736+ -->\n",
       "<g id=\"node35\" class=\"node\">\n",
       "<title>4694262736+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1027.5\" cy=\"-103\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1027.5\" y=\"-97.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694262640&#45;&gt;4694262736+ -->\n",
       "<g id=\"edge287\" class=\"edge\">\n",
       "<title>4694262640&#45;&gt;4694262736+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M941.92,-212.11C960.57,-188.06 988.65,-151.82 1007.28,-127.8\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1009.86,-130.18 1013.22,-120.13 1004.33,-125.89 1009.86,-130.18\"/>\n",
       "</g>\n",
       "<!-- 4694262640*&#45;&gt;4694262640 -->\n",
       "<g id=\"edge11\" class=\"edge\">\n",
       "<title>4694262640*&#45;&gt;4694262640</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M824.79,-356.76C835.31,-335.28 855.2,-298.1 878.75,-271 879,-270.71 879.26,-270.42 879.52,-270.13\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"882.01,-272.59 886.53,-263.01 877.02,-267.68 882.01,-272.59\"/>\n",
       "</g>\n",
       "<!-- 4690043776 -->\n",
       "<g id=\"node31\" class=\"node\">\n",
       "<title>4690043776</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-469.5 1725.75,-518.5 1811.5,-518.5 1811.5,-469.5 1725.75,-469.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-501.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.943</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-494 1811.5,-494\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-476.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227504* -->\n",
       "<g id=\"node215\" class=\"node\">\n",
       "<title>4694227504*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1874.5\" cy=\"-494\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1874.5\" y=\"-488.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690043776&#45;&gt;4694227504* -->\n",
       "<g id=\"edge257\" class=\"edge\">\n",
       "<title>4690043776&#45;&gt;4694227504*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1811.87,-494C1819.78,-494 1828,-494 1835.76,-494\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1835.57,-497.5 1845.57,-494 1835.57,-490.5 1835.57,-497.5\"/>\n",
       "</g>\n",
       "<!-- 4694262688 -->\n",
       "<g id=\"node32\" class=\"node\">\n",
       "<title>4694262688</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2793.5,-469.5 2793.5,-518.5 2879.25,-518.5 2879.25,-469.5 2793.5,-469.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-501.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.000</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2793.5,-494 2879.25,-494\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-476.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264848* -->\n",
       "<g id=\"node120\" class=\"node\">\n",
       "<title>4694264848*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2942.25\" cy=\"-494\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2942.25\" y=\"-488.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694262688&#45;&gt;4694264848* -->\n",
       "<g id=\"edge253\" class=\"edge\">\n",
       "<title>4694262688&#45;&gt;4694264848*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2879.62,-494C2887.53,-494 2895.75,-494 2903.51,-494\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2903.32,-497.5 2913.32,-494 2903.32,-490.5 2903.32,-497.5\"/>\n",
       "</g>\n",
       "<!-- 4694262688tanh -->\n",
       "<g id=\"node33\" class=\"node\">\n",
       "<title>4694262688tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2730.5\" cy=\"-494\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2730.5\" y=\"-488.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694262688tanh&#45;&gt;4694262688 -->\n",
       "<g id=\"edge12\" class=\"edge\">\n",
       "<title>4694262688tanh&#45;&gt;4694262688</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2757.98,-494C2765.34,-494 2773.6,-494 2781.91,-494\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2781.69,-497.5 2791.69,-494 2781.69,-490.5 2781.69,-497.5\"/>\n",
       "</g>\n",
       "<!-- 4694262736 -->\n",
       "<g id=\"node34\" class=\"node\">\n",
       "<title>4694262736</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-78.5 1090.5,-127.5 1176.25,-127.5 1176.25,-78.5 1090.5,-78.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-110.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;4.565</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-103 1176.25,-103\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-85.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694262928+ -->\n",
       "<g id=\"node42\" class=\"node\">\n",
       "<title>4694262928+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1239.25\" cy=\"-312\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1239.25\" y=\"-306.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694262736&#45;&gt;4694262928+ -->\n",
       "<g id=\"edge213\" class=\"edge\">\n",
       "<title>4694262736&#45;&gt;4694262928+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1168.48,-127.82C1171.33,-130.71 1173.98,-133.79 1176.25,-137 1176.8,-137.78 1210.92,-234.46 1228.3,-283.76\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1224.91,-284.66 1231.53,-292.93 1231.51,-282.33 1224.91,-284.66\"/>\n",
       "</g>\n",
       "<!-- 4694262736+&#45;&gt;4694262736 -->\n",
       "<g id=\"edge13\" class=\"edge\">\n",
       "<title>4694262736+&#45;&gt;4694262736</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1054.98,-103C1062.34,-103 1070.6,-103 1078.91,-103\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1078.69,-106.5 1088.69,-103 1078.69,-99.5 1078.69,-106.5\"/>\n",
       "</g>\n",
       "<!-- 4690043872 -->\n",
       "<g id=\"node36\" class=\"node\">\n",
       "<title>4690043872</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-265.5 1937.5,-314.5 2023.25,-314.5 2023.25,-265.5 1937.5,-265.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-297.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.872</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-290 2023.25,-290\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-272.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227696* -->\n",
       "<g id=\"node219\" class=\"node\">\n",
       "<title>4694227696*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2086.25\" cy=\"-290\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2086.25\" y=\"-284.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690043872&#45;&gt;4694227696* -->\n",
       "<g id=\"edge188\" class=\"edge\">\n",
       "<title>4690043872&#45;&gt;4694227696*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2023.62,-290C2031.53,-290 2039.75,-290 2047.51,-290\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2047.32,-293.5 2057.32,-290 2047.32,-286.5 2047.32,-293.5\"/>\n",
       "</g>\n",
       "<!-- 4694262832 -->\n",
       "<g id=\"node37\" class=\"node\">\n",
       "<title>4694262832</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-339.5 1090.5,-388.5 1176.25,-388.5 1176.25,-339.5 1090.5,-339.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-371.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;3.369</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-364 1176.25,-364\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-346.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694262832&#45;&gt;4694262928+ -->\n",
       "<g id=\"edge165\" class=\"edge\">\n",
       "<title>4694262832&#45;&gt;4694262928+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1176.62,-342.85C1186.75,-337.78 1197.38,-332.46 1206.9,-327.69\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1208.38,-330.87 1215.75,-323.26 1205.24,-324.61 1208.38,-330.87\"/>\n",
       "</g>\n",
       "<!-- 4694262832* -->\n",
       "<g id=\"node38\" class=\"node\">\n",
       "<title>4694262832*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1027.5\" cy=\"-373\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1027.5\" y=\"-367.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694262832*&#45;&gt;4694262832 -->\n",
       "<g id=\"edge14\" class=\"edge\">\n",
       "<title>4694262832*&#45;&gt;4694262832</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1054.71,-370.73C1062.07,-370.09 1070.34,-369.37 1078.68,-368.65\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1078.83,-372.15 1088.5,-367.8 1078.23,-365.18 1078.83,-372.15\"/>\n",
       "</g>\n",
       "<!-- 4690043968 -->\n",
       "<g id=\"node39\" class=\"node\">\n",
       "<title>4690043968</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-877.5 2150.75,-926.5 2236.5,-926.5 2236.5,-877.5 2150.75,-877.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-909.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.080</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-902 2236.5,-902\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-884.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227888* -->\n",
       "<g id=\"node227\" class=\"node\">\n",
       "<title>4694227888*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2301\" cy=\"-834\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2301\" y=\"-828.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690043968&#45;&gt;4694227888* -->\n",
       "<g id=\"edge108\" class=\"edge\">\n",
       "<title>4690043968&#45;&gt;4694227888*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2233.26,-877.07C2245.93,-868.89 2259.76,-859.97 2271.54,-852.37\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2273.09,-855.53 2279.6,-847.17 2269.3,-849.65 2273.09,-855.53\"/>\n",
       "</g>\n",
       "<!-- 4694221936 -->\n",
       "<g id=\"node40\" class=\"node\">\n",
       "<title>4694221936</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"0,-670.5 0,-719.5 85.75,-719.5 85.75,-670.5 0,-670.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"42.88\" y=\"-702.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.000</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"0,-695 85.75,-695\"/>\n",
       "<text text-anchor=\"middle\" x=\"42.88\" y=\"-677.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694221936&#45;&gt;4694221552* -->\n",
       "<g id=\"edge173\" class=\"edge\">\n",
       "<title>4694221936&#45;&gt;4694221552*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M85.94,-690.51C136.52,-684.69 223.82,-673.32 297.5,-657 311.91,-653.81 327.56,-649.38 341.02,-645.26\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"341.8,-648.69 350.29,-642.36 339.71,-642.01 341.8,-648.69\"/>\n",
       "</g>\n",
       "<!-- 4694223184* -->\n",
       "<g id=\"node83\" class=\"node\">\n",
       "<title>4694223184*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"604\" cy=\"-724\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"604\" y=\"-718.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694221936&#45;&gt;4694223184* -->\n",
       "<g id=\"edge246\" class=\"edge\">\n",
       "<title>4694221936&#45;&gt;4694223184*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M85.96,-701.06C128.24,-706.62 195.31,-714 253.62,-714 253.62,-714 253.62,-714 377.38,-714 443.64,-714 520.75,-718.36 565.5,-721.32\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"565.24,-724.81 575.45,-721.99 565.71,-717.83 565.24,-724.81\"/>\n",
       "</g>\n",
       "<!-- 4694223472* -->\n",
       "<g id=\"node96\" class=\"node\">\n",
       "<title>4694223472*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"148.75\" cy=\"-146\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"148.75\" y=\"-140.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694221936&#45;&gt;4694223472* -->\n",
       "<g id=\"edge250\" class=\"edge\">\n",
       "<title>4694221936&#45;&gt;4694223472*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M45.87,-670.19C53.41,-579.78 81.78,-268.5 121.75,-178 122.98,-175.21 124.52,-172.46 126.24,-169.82\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"128.87,-172.15 132.05,-162.04 123.26,-167.96 128.87,-172.15\"/>\n",
       "</g>\n",
       "<!-- 4694223760* -->\n",
       "<g id=\"node111\" class=\"node\">\n",
       "<title>4694223760*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"148.75\" cy=\"-1211\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"148.75\" y=\"-1205.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694221936&#45;&gt;4694223760* -->\n",
       "<g id=\"edge123\" class=\"edge\">\n",
       "<title>4694221936&#45;&gt;4694223760*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M47.01,-719.97C55.76,-787.31 82.37,-978.05 121.75,-1133 126.01,-1149.76 132.06,-1168.12 137.25,-1182.81\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"133.81,-1183.61 140.5,-1191.83 140.4,-1181.23 133.81,-1183.61\"/>\n",
       "</g>\n",
       "<!-- 4694224048* -->\n",
       "<g id=\"node124\" class=\"node\">\n",
       "<title>4694224048*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1239.25\" cy=\"-366\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1239.25\" y=\"-360.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694221936&#45;&gt;4694224048* -->\n",
       "<g id=\"edge128\" class=\"edge\">\n",
       "<title>4694221936&#45;&gt;4694224048*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M72.25,-670.22C173.08,-584.03 526.97,-297.45 878.75,-203 915.56,-193.12 927.75,-192.89 964.5,-203 991.27,-210.37 1144.41,-306.42 1209.25,-347.54\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1207.27,-350.42 1217.59,-352.83 1211.02,-344.51 1207.27,-350.42\"/>\n",
       "</g>\n",
       "<!-- 4694224336* -->\n",
       "<g id=\"node133\" class=\"node\">\n",
       "<title>4694224336*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"148.75\" cy=\"-52\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"148.75\" y=\"-46.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694221936&#45;&gt;4694224336* -->\n",
       "<g id=\"edge135\" class=\"edge\">\n",
       "<title>4694221936&#45;&gt;4694224336*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M45.14,-670.18C49.69,-589.51 67.91,-327.87 121.75,-119 125.15,-105.82 130.37,-91.7 135.25,-79.84\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"138.46,-81.23 139.16,-70.65 132.02,-78.49 138.46,-81.23\"/>\n",
       "</g>\n",
       "<!-- 4694224624* -->\n",
       "<g id=\"node141\" class=\"node\">\n",
       "<title>4694224624*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1662.75\" cy=\"-1038\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1662.75\" y=\"-1032.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694221936&#45;&gt;4694224624* -->\n",
       "<g id=\"edge178\" class=\"edge\">\n",
       "<title>4694221936&#45;&gt;4694224624*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M48.62,-719.79C61.98,-782.34 106.03,-947.28 211.75,-1027 384.38,-1157.18 961.05,-1175.89 1176.25,-1155 1367.16,-1136.47 1419.42,-1137.33 1599.75,-1072 1610.97,-1067.93 1622.61,-1062.05 1632.74,-1056.32\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1634.51,-1059.34 1641.35,-1051.25 1630.96,-1053.31 1634.51,-1059.34\"/>\n",
       "</g>\n",
       "<!-- 4694219632* -->\n",
       "<g id=\"node225\" class=\"node\">\n",
       "<title>4694219632*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"148.75\" cy=\"-1106\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"148.75\" y=\"-1100.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694221936&#45;&gt;4694219632* -->\n",
       "<g id=\"edge102\" class=\"edge\">\n",
       "<title>4694221936&#45;&gt;4694219632*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M45.32,-719.88C49.69,-781.83 66.1,-946.91 121.75,-1071 123.3,-1074.45 125.23,-1077.89 127.35,-1081.19\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"124.47,-1083.19 133.13,-1089.31 130.18,-1079.13 124.47,-1083.19\"/>\n",
       "</g>\n",
       "<!-- 4694262928 -->\n",
       "<g id=\"node41\" class=\"node\">\n",
       "<title>4694262928</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-333.5 1302.25,-382.5 1388,-382.5 1388,-333.5 1302.25,-333.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-365.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;7.934</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-358 1388,-358\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-340.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263120+ -->\n",
       "<g id=\"node47\" class=\"node\">\n",
       "<title>4694263120+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1451\" cy=\"-528\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1451\" y=\"-522.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694262928&#45;&gt;4694263120+ -->\n",
       "<g id=\"edge101\" class=\"edge\">\n",
       "<title>4694262928&#45;&gt;4694263120+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1379.53,-382.63C1382.59,-385.6 1385.48,-388.74 1388,-392 1413.65,-425.16 1431.61,-470.63 1441.38,-499.67\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1437.95,-500.43 1444.37,-508.85 1444.61,-498.26 1437.95,-500.43\"/>\n",
       "</g>\n",
       "<!-- 4694262928+&#45;&gt;4694262928 -->\n",
       "<g id=\"edge15\" class=\"edge\">\n",
       "<title>4694262928+&#45;&gt;4694262928</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1262.28,-321.76C1270.94,-325.59 1281.29,-330.18 1291.67,-334.77\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1290.05,-337.88 1300.61,-338.73 1292.89,-331.48 1290.05,-337.88\"/>\n",
       "</g>\n",
       "<!-- 4694263024 -->\n",
       "<g id=\"node43\" class=\"node\">\n",
       "<title>4694263024</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-537.5 1302.25,-586.5 1388,-586.5 1388,-537.5 1302.25,-537.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-569.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.453</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-562 1388,-562\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-544.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263024&#45;&gt;4694263120+ -->\n",
       "<g id=\"edge117\" class=\"edge\">\n",
       "<title>4694263024&#45;&gt;4694263120+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1388.37,-548.17C1397.36,-545.23 1406.74,-542.16 1415.4,-539.33\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1416.41,-542.68 1424.83,-536.24 1414.24,-536.02 1416.41,-542.68\"/>\n",
       "</g>\n",
       "<!-- 4694263024* -->\n",
       "<g id=\"node44\" class=\"node\">\n",
       "<title>4694263024*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1239.25\" cy=\"-577\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1239.25\" y=\"-571.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694263024*&#45;&gt;4694263024 -->\n",
       "<g id=\"edge16\" class=\"edge\">\n",
       "<title>4694263024*&#45;&gt;4694263024</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1265.93,-573.29C1273.45,-572.21 1281.96,-570.98 1290.54,-569.74\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1290.87,-573.23 1300.27,-568.33 1289.87,-566.3 1290.87,-573.23\"/>\n",
       "</g>\n",
       "<!-- 4690044208 -->\n",
       "<g id=\"node45\" class=\"node\">\n",
       "<title>4690044208</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"667,-1005.5 667,-1054.5 752.75,-1054.5 752.75,-1005.5 667,-1005.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-1037.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.280</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"667,-1030 752.75,-1030\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-1012.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690044208&#45;&gt;4694228176* -->\n",
       "<g id=\"edge162\" class=\"edge\">\n",
       "<title>4690044208&#45;&gt;4694228176*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M753.12,-1030C761.03,-1030 769.25,-1030 777.01,-1030\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"776.82,-1033.5 786.82,-1030 776.82,-1026.5 776.82,-1033.5\"/>\n",
       "</g>\n",
       "<!-- 4694263120 -->\n",
       "<g id=\"node46\" class=\"node\">\n",
       "<title>4694263120</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-503.5 1514,-552.5 1599.75,-552.5 1599.75,-503.5 1514,-503.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-535.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;9.387</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-528 1599.75,-528\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-510.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263312+ -->\n",
       "<g id=\"node53\" class=\"node\">\n",
       "<title>4694263312+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1662.75\" cy=\"-528\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1662.75\" y=\"-522.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694263120&#45;&gt;4694263312+ -->\n",
       "<g id=\"edge168\" class=\"edge\">\n",
       "<title>4694263120&#45;&gt;4694263312+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1600.12,-528C1608.03,-528 1616.25,-528 1624.01,-528\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1623.82,-531.5 1633.82,-528 1623.82,-524.5 1623.82,-531.5\"/>\n",
       "</g>\n",
       "<!-- 4694263120+&#45;&gt;4694263120 -->\n",
       "<g id=\"edge17\" class=\"edge\">\n",
       "<title>4694263120+&#45;&gt;4694263120</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1478.48,-528C1485.84,-528 1494.1,-528 1502.41,-528\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1502.19,-531.5 1512.19,-528 1502.19,-524.5 1502.19,-531.5\"/>\n",
       "</g>\n",
       "<!-- 4690044256 -->\n",
       "<g id=\"node48\" class=\"node\">\n",
       "<title>4690044256</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-1096.5 878.75,-1145.5 964.5,-1145.5 964.5,-1096.5 878.75,-1096.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-1128.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.348</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-1121 964.5,-1121\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-1103.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228272+ -->\n",
       "<g id=\"node237\" class=\"node\">\n",
       "<title>4694228272+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1027.5\" cy=\"-1121\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1027.5\" y=\"-1115.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4690044256&#45;&gt;4694228272+ -->\n",
       "<g id=\"edge112\" class=\"edge\">\n",
       "<title>4690044256&#45;&gt;4694228272+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M964.87,-1121C972.78,-1121 981,-1121 988.76,-1121\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"988.57,-1124.5 998.57,-1121 988.57,-1117.5 988.57,-1124.5\"/>\n",
       "</g>\n",
       "<!-- 4694263216 -->\n",
       "<g id=\"node49\" class=\"node\">\n",
       "<title>4694263216</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-194.5 1514,-243.5 1599.75,-243.5 1599.75,-194.5 1514,-194.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-226.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.310</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-219 1599.75,-219\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-201.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263216&#45;&gt;4694263312+ -->\n",
       "<g id=\"edge184\" class=\"edge\">\n",
       "<title>4694263216&#45;&gt;4694263312+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1579.36,-243.84C1586.83,-253.61 1594.61,-265.29 1599.75,-277 1631.84,-350.11 1614.63,-376 1635.75,-453 1640.07,-468.73 1645.95,-485.95 1651.03,-499.91\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1647.6,-500.74 1654.36,-508.91 1654.17,-498.31 1647.6,-500.74\"/>\n",
       "</g>\n",
       "<!-- 4694263216* -->\n",
       "<g id=\"node50\" class=\"node\">\n",
       "<title>4694263216*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1451\" cy=\"-195\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1451\" y=\"-189.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694263216*&#45;&gt;4694263216 -->\n",
       "<g id=\"edge18\" class=\"edge\">\n",
       "<title>4694263216*&#45;&gt;4694263216</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1476.88,-200.75C1484.73,-202.56 1493.73,-204.64 1502.77,-206.73\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1501.75,-210.09 1512.28,-208.93 1503.32,-203.27 1501.75,-210.09\"/>\n",
       "</g>\n",
       "<!-- 4690044352 -->\n",
       "<g id=\"node51\" class=\"node\">\n",
       "<title>4690044352</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-824.5 878.75,-873.5 964.5,-873.5 964.5,-824.5 878.75,-824.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-856.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.227</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-849 964.5,-849\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-831.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228368* -->\n",
       "<g id=\"node239\" class=\"node\">\n",
       "<title>4694228368*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1027.5\" cy=\"-849\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1027.5\" y=\"-843.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690044352&#45;&gt;4694228368* -->\n",
       "<g id=\"edge163\" class=\"edge\">\n",
       "<title>4690044352&#45;&gt;4694228368*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M964.87,-849C972.78,-849 981,-849 988.76,-849\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"988.57,-852.5 998.57,-849 988.57,-845.5 988.57,-852.5\"/>\n",
       "</g>\n",
       "<!-- 4694263312 -->\n",
       "<g id=\"node52\" class=\"node\">\n",
       "<title>4694263312</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-605.5 1725.75,-654.5 1811.5,-654.5 1811.5,-605.5 1725.75,-605.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-637.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;9.077</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-630 1811.5,-630\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-612.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263504+ -->\n",
       "<g id=\"node59\" class=\"node\">\n",
       "<title>4694263504+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1874.5\" cy=\"-630\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1874.5\" y=\"-624.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694263312&#45;&gt;4694263504+ -->\n",
       "<g id=\"edge244\" class=\"edge\">\n",
       "<title>4694263312&#45;&gt;4694263504+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1811.87,-630C1819.78,-630 1828,-630 1835.76,-630\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1835.57,-633.5 1845.57,-630 1835.57,-626.5 1835.57,-633.5\"/>\n",
       "</g>\n",
       "<!-- 4694263312+&#45;&gt;4694263312 -->\n",
       "<g id=\"edge19\" class=\"edge\">\n",
       "<title>4694263312+&#45;&gt;4694263312</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1676.92,-543.74C1689.06,-557.93 1707.86,-579.11 1725.75,-596 1726.36,-596.58 1726.98,-597.16 1727.61,-597.74\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1725.15,-600.23 1734.95,-604.25 1729.79,-594.99 1725.15,-600.23\"/>\n",
       "</g>\n",
       "<!-- 4690044448 -->\n",
       "<g id=\"node54\" class=\"node\">\n",
       "<title>4690044448</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-1028.5 1090.5,-1077.5 1176.25,-1077.5 1176.25,-1028.5 1090.5,-1028.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-1060.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.284</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-1053 1176.25,-1053\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-1035.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228560* -->\n",
       "<g id=\"node246\" class=\"node\">\n",
       "<title>4694228560*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1239.25\" cy=\"-970\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1239.25\" y=\"-964.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690044448&#45;&gt;4694228560* -->\n",
       "<g id=\"edge229\" class=\"edge\">\n",
       "<title>4690044448&#45;&gt;4694228560*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1165.54,-1028.1C1180.44,-1016.19 1198.08,-1002.1 1212.25,-990.78\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1214.19,-993.71 1219.81,-984.73 1209.82,-988.24 1214.19,-993.71\"/>\n",
       "</g>\n",
       "<!-- 4694263408 -->\n",
       "<g id=\"node55\" class=\"node\">\n",
       "<title>4694263408</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-945.5 1725.75,-994.5 1811.5,-994.5 1811.5,-945.5 1725.75,-945.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-977.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.878</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-970 1811.5,-970\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-952.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263408&#45;&gt;4694263504+ -->\n",
       "<g id=\"edge255\" class=\"edge\">\n",
       "<title>4694263408&#45;&gt;4694263504+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1804.68,-945.11C1807.26,-942.27 1809.59,-939.22 1811.5,-936 1856.86,-859.42 1829.17,-826.1 1847.5,-739 1853.24,-711.73 1860.7,-680.85 1866.15,-658.93\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1869.47,-660.08 1868.51,-649.53 1862.68,-658.38 1869.47,-660.08\"/>\n",
       "</g>\n",
       "<!-- 4694263408* -->\n",
       "<g id=\"node56\" class=\"node\">\n",
       "<title>4694263408*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1662.75\" cy=\"-970\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1662.75\" y=\"-964.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694263408*&#45;&gt;4694263408 -->\n",
       "<g id=\"edge20\" class=\"edge\">\n",
       "<title>4694263408*&#45;&gt;4694263408</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1690.23,-970C1697.59,-970 1705.85,-970 1714.16,-970\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1713.94,-973.5 1723.94,-970 1713.94,-966.5 1713.94,-973.5\"/>\n",
       "</g>\n",
       "<!-- 4690044544 -->\n",
       "<g id=\"node57\" class=\"node\">\n",
       "<title>4690044544</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-673.5 1302.25,-722.5 1388,-722.5 1388,-673.5 1302.25,-673.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-705.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.200</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-698 1388,-698\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-680.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228752* -->\n",
       "<g id=\"node252\" class=\"node\">\n",
       "<title>4694228752*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1451\" cy=\"-698\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1451\" y=\"-692.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690044544&#45;&gt;4694228752* -->\n",
       "<g id=\"edge200\" class=\"edge\">\n",
       "<title>4690044544&#45;&gt;4694228752*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1388.37,-698C1396.28,-698 1404.5,-698 1412.26,-698\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1412.07,-701.5 1422.07,-698 1412.07,-694.5 1412.07,-701.5\"/>\n",
       "</g>\n",
       "<!-- 4694263504 -->\n",
       "<g id=\"node58\" class=\"node\">\n",
       "<title>4694263504</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-605.5 1937.5,-654.5 2023.25,-654.5 2023.25,-605.5 1937.5,-605.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-637.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;9.955</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-630 2023.25,-630\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-612.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263696+ -->\n",
       "<g id=\"node67\" class=\"node\">\n",
       "<title>4694263696+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2086.25\" cy=\"-358\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2086.25\" y=\"-352.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694263504&#45;&gt;4694263696+ -->\n",
       "<g id=\"edge143\" class=\"edge\">\n",
       "<title>4694263504&#45;&gt;4694263696+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2016.43,-605.11C2019.01,-602.27 2021.34,-599.22 2023.25,-596 2068.61,-519.42 2026.82,-481.89 2059.25,-399 2061.29,-393.78 2064.03,-388.51 2066.96,-383.56\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2069.83,-385.56 2072.27,-375.25 2063.94,-381.79 2069.83,-385.56\"/>\n",
       "</g>\n",
       "<!-- 4694263504+&#45;&gt;4694263504 -->\n",
       "<g id=\"edge21\" class=\"edge\">\n",
       "<title>4694263504+&#45;&gt;4694263504</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1901.98,-630C1909.34,-630 1917.6,-630 1925.91,-630\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1925.69,-633.5 1935.69,-630 1925.69,-626.5 1925.69,-633.5\"/>\n",
       "</g>\n",
       "<!-- 4690044640 -->\n",
       "<g id=\"node60\" class=\"node\">\n",
       "<title>4690044640</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-1323.5 1514,-1372.5 1599.75,-1372.5 1599.75,-1323.5 1514,-1323.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-1355.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.391</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-1348 1599.75,-1348\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-1330.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228944* -->\n",
       "<g id=\"node258\" class=\"node\">\n",
       "<title>4694228944*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1662.75\" cy=\"-1259\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1662.75\" y=\"-1253.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4690044640&#45;&gt;4694228944* -->\n",
       "<g id=\"edge256\" class=\"edge\">\n",
       "<title>4690044640&#45;&gt;4694228944*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1588.65,-1323.27C1592.41,-1320.17 1596.18,-1317.03 1599.75,-1314 1612.3,-1303.35 1626.02,-1291.23 1637.35,-1281.09\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1639.64,-1283.74 1644.73,-1274.45 1634.96,-1278.53 1639.64,-1283.74\"/>\n",
       "</g>\n",
       "<!-- 4694263600 -->\n",
       "<g id=\"node61\" class=\"node\">\n",
       "<title>4694263600</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-333.5 1937.5,-382.5 2023.25,-382.5 2023.25,-333.5 1937.5,-333.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-365.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.541</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-358 2023.25,-358\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-340.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263600&#45;&gt;4694263696+ -->\n",
       "<g id=\"edge110\" class=\"edge\">\n",
       "<title>4694263600&#45;&gt;4694263696+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2023.62,-358C2031.53,-358 2039.75,-358 2047.51,-358\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2047.32,-361.5 2057.32,-358 2047.32,-354.5 2047.32,-361.5\"/>\n",
       "</g>\n",
       "<!-- 4694263600* -->\n",
       "<g id=\"node62\" class=\"node\">\n",
       "<title>4694263600*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1874.5\" cy=\"-358\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1874.5\" y=\"-352.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694263600*&#45;&gt;4694263600 -->\n",
       "<g id=\"edge22\" class=\"edge\">\n",
       "<title>4694263600*&#45;&gt;4694263600</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1901.98,-358C1909.34,-358 1917.6,-358 1925.91,-358\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1925.69,-361.5 1935.69,-358 1925.69,-354.5 1925.69,-361.5\"/>\n",
       "</g>\n",
       "<!-- 4690044736 -->\n",
       "<g id=\"node63\" class=\"node\">\n",
       "<title>4690044736</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-537.5 1725.75,-586.5 1811.5,-586.5 1811.5,-537.5 1725.75,-537.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-569.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.288</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-562 1811.5,-562\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-544.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690044736&#45;&gt;4694261968* -->\n",
       "<g id=\"edge115\" class=\"edge\">\n",
       "<title>4690044736&#45;&gt;4694261968*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1811.87,-562C1819.78,-562 1828,-562 1835.76,-562\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1835.57,-565.5 1845.57,-562 1835.57,-558.5 1835.57,-565.5\"/>\n",
       "</g>\n",
       "<!-- 4694222704 -->\n",
       "<g id=\"node64\" class=\"node\">\n",
       "<title>4694222704</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-552.5 878.75,-601.5 964.5,-601.5 964.5,-552.5 878.75,-552.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-584.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.966</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-577 964.5,-577\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-559.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694222704&#45;&gt;4694262832* -->\n",
       "<g id=\"edge105\" class=\"edge\">\n",
       "<title>4694222704&#45;&gt;4694262832*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M956.97,-552.34C959.77,-549.41 962.34,-546.29 964.5,-543 997.14,-493.23 976.3,-468.38 1000.5,-414 1002.78,-408.88 1005.63,-403.65 1008.6,-398.72\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1011.47,-400.72 1013.9,-390.41 1005.57,-396.96 1011.47,-400.72\"/>\n",
       "</g>\n",
       "<!-- 4694225104* -->\n",
       "<g id=\"node153\" class=\"node\">\n",
       "<title>4694225104*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1027.5\" cy=\"-441\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1027.5\" y=\"-435.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694222704&#45;&gt;4694225104* -->\n",
       "<g id=\"edge233\" class=\"edge\">\n",
       "<title>4694222704&#45;&gt;4694225104*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M955.68,-552.09C958.81,-549.18 961.81,-546.12 964.5,-543 985.04,-519.15 984.07,-508.85 1000.5,-482 1003.43,-477.22 1006.59,-472.16 1009.66,-467.28\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1012.54,-469.28 1014.94,-458.96 1006.63,-465.53 1012.54,-469.28\"/>\n",
       "</g>\n",
       "<!-- 4694222704&#45;&gt;4694226736* -->\n",
       "<g id=\"edge131\" class=\"edge\">\n",
       "<title>4694222704&#45;&gt;4694226736*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M955.64,-601.94C958.78,-604.85 961.79,-607.9 964.5,-611 984.55,-633.97 1002.03,-664.24 1013.28,-685.82\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1010.08,-687.26 1017.74,-694.59 1016.32,-684.09 1010.08,-687.26\"/>\n",
       "</g>\n",
       "<!-- 4694222704&#45;&gt;4694228368* -->\n",
       "<g id=\"edge197\" class=\"edge\">\n",
       "<title>4694222704&#45;&gt;4694228368*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M957.65,-601.9C960.24,-604.74 962.58,-607.78 964.5,-611 1008.54,-684.8 971.69,-720.03 1000.5,-801 1003.04,-808.15 1006.54,-815.52 1010.14,-822.28\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1007.07,-823.96 1015.03,-830.95 1013.17,-820.52 1007.07,-823.96\"/>\n",
       "</g>\n",
       "<!-- 4694222704tanh -->\n",
       "<g id=\"node65\" class=\"node\">\n",
       "<title>4694222704tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"815.75\" cy=\"-577\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"815.75\" y=\"-571.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694222704tanh&#45;&gt;4694222704 -->\n",
       "<g id=\"edge23\" class=\"edge\">\n",
       "<title>4694222704tanh&#45;&gt;4694222704</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M843.23,-577C850.59,-577 858.85,-577 867.16,-577\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"866.94,-580.5 876.94,-577 866.94,-573.5 866.94,-580.5\"/>\n",
       "</g>\n",
       "<!-- 4694263696 -->\n",
       "<g id=\"node66\" class=\"node\">\n",
       "<title>4694263696</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2149.25,-333.5 2149.25,-382.5 2238,-382.5 2238,-333.5 2149.25,-333.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-365.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;11.495</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2149.25,-358 2238,-358\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-340.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263888+ -->\n",
       "<g id=\"node73\" class=\"node\">\n",
       "<title>4694263888+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2301\" cy=\"-358\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2301\" y=\"-352.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694263696&#45;&gt;4694263888+ -->\n",
       "<g id=\"edge259\" class=\"edge\">\n",
       "<title>4694263696&#45;&gt;4694263888+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2238.4,-358C2246.36,-358 2254.6,-358 2262.36,-358\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2262.17,-361.5 2272.17,-358 2262.17,-354.5 2262.17,-361.5\"/>\n",
       "</g>\n",
       "<!-- 4694263696+&#45;&gt;4694263696 -->\n",
       "<g id=\"edge24\" class=\"edge\">\n",
       "<title>4694263696+&#45;&gt;4694263696</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2113.57,-358C2120.94,-358 2129.25,-358 2137.63,-358\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2137.52,-361.5 2147.52,-358 2137.52,-354.5 2137.52,-361.5\"/>\n",
       "</g>\n",
       "<!-- 4690044832 -->\n",
       "<g id=\"node68\" class=\"node\">\n",
       "<title>4690044832</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-673.5 1937.5,-722.5 2023.25,-722.5 2023.25,-673.5 1937.5,-673.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-705.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.298</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-698 2023.25,-698\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-680.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690044832&#45;&gt;4694262160* -->\n",
       "<g id=\"edge130\" class=\"edge\">\n",
       "<title>4690044832&#45;&gt;4694262160*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2016.43,-673.11C2019.01,-670.27 2021.34,-667.22 2023.25,-664 2068.61,-587.42 2026.82,-549.89 2059.25,-467 2061.29,-461.78 2064.03,-456.51 2066.96,-451.56\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2069.83,-453.56 2072.27,-443.25 2063.94,-449.79 2069.83,-453.56\"/>\n",
       "</g>\n",
       "<!-- 4694263792 -->\n",
       "<g id=\"node69\" class=\"node\">\n",
       "<title>4694263792</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-129.5 2150.75,-178.5 2236.5,-178.5 2236.5,-129.5 2150.75,-129.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-161.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.506</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-154 2236.5,-154\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-136.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263792&#45;&gt;4694263888+ -->\n",
       "<g id=\"edge181\" class=\"edge\">\n",
       "<title>4694263792&#45;&gt;4694263888+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2229.93,-178.74C2232.89,-181.65 2235.64,-184.75 2238,-188 2269.58,-231.51 2286.65,-292.83 2294.49,-328.7\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2291.03,-329.26 2296.5,-338.34 2297.89,-327.84 2291.03,-329.26\"/>\n",
       "</g>\n",
       "<!-- 4694263792* -->\n",
       "<g id=\"node70\" class=\"node\">\n",
       "<title>4694263792*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2086.25\" cy=\"-154\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2086.25\" y=\"-148.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694263792*&#45;&gt;4694263792 -->\n",
       "<g id=\"edge25\" class=\"edge\">\n",
       "<title>4694263792*&#45;&gt;4694263792</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2113.57,-154C2121.28,-154 2130.01,-154 2138.79,-154\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2138.75,-157.5 2148.75,-154 2138.75,-150.5 2138.75,-157.5\"/>\n",
       "</g>\n",
       "<!-- 4690044928 -->\n",
       "<g id=\"node71\" class=\"node\">\n",
       "<title>4690044928</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-945.5 2150.75,-994.5 2236.5,-994.5 2236.5,-945.5 2150.75,-945.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-977.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.284</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-970 2236.5,-970\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-952.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690044928&#45;&gt;4694262352* -->\n",
       "<g id=\"edge278\" class=\"edge\">\n",
       "<title>4690044928&#45;&gt;4694262352*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2233.26,-945.07C2245.93,-936.89 2259.76,-927.97 2271.54,-920.37\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2273.09,-923.53 2279.6,-915.17 2269.3,-917.65 2273.09,-923.53\"/>\n",
       "</g>\n",
       "<!-- 4694263888 -->\n",
       "<g id=\"node72\" class=\"node\">\n",
       "<title>4694263888</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2364,-367.5 2364,-416.5 2452.75,-416.5 2452.75,-367.5 2364,-367.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-399.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;13.002</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2364,-392 2452.75,-392\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-374.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264080+ -->\n",
       "<g id=\"node80\" class=\"node\">\n",
       "<title>4694264080+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2515.75\" cy=\"-494\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2515.75\" y=\"-488.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694263888&#45;&gt;4694264080+ -->\n",
       "<g id=\"edge152\" class=\"edge\">\n",
       "<title>4694263888&#45;&gt;4694264080+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2435.15,-416.95C2452.38,-433.63 2474.85,-455.38 2491.52,-471.52\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2488.95,-473.89 2498.57,-478.33 2493.82,-468.86 2488.95,-473.89\"/>\n",
       "</g>\n",
       "<!-- 4694263888+&#45;&gt;4694263888 -->\n",
       "<g id=\"edge26\" class=\"edge\">\n",
       "<title>4694263888+&#45;&gt;4694263888</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2325.91,-365.72C2334.03,-368.33 2343.46,-371.38 2352.97,-374.45\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2351.64,-377.69 2362.23,-377.43 2353.79,-371.03 2351.64,-377.69\"/>\n",
       "</g>\n",
       "<!-- 4694222992 -->\n",
       "<g id=\"node74\" class=\"node\">\n",
       "<title>4694222992</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"667,-552.5 667,-601.5 752.75,-601.5 752.75,-552.5 667,-552.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-584.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;2.026</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"667,-577 752.75,-577\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-559.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694222992&#45;&gt;4694222704tanh -->\n",
       "<g id=\"edge236\" class=\"edge\">\n",
       "<title>4694222992&#45;&gt;4694222704tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M753.12,-577C761.03,-577 769.25,-577 777.01,-577\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"776.82,-580.5 786.82,-577 776.82,-573.5 776.82,-580.5\"/>\n",
       "</g>\n",
       "<!-- 4694222992+&#45;&gt;4694222992 -->\n",
       "<g id=\"edge27\" class=\"edge\">\n",
       "<title>4694222992+&#45;&gt;4694222992</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M631.48,-577C638.84,-577 647.1,-577 655.41,-577\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"655.19,-580.5 665.19,-577 655.19,-573.5 655.19,-580.5\"/>\n",
       "</g>\n",
       "<!-- 4694263984 -->\n",
       "<g id=\"node76\" class=\"node\">\n",
       "<title>4694263984</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2365.5,-673.5 2365.5,-722.5 2451.25,-722.5 2451.25,-673.5 2365.5,-673.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-705.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.454</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2365.5,-698 2451.25,-698\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-680.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694263984&#45;&gt;4694264080+ -->\n",
       "<g id=\"edge206\" class=\"edge\">\n",
       "<title>4694263984&#45;&gt;4694264080+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2445.36,-673.03C2448.1,-670.2 2450.62,-667.18 2452.75,-664 2485.82,-614.51 2464.55,-589.38 2488.75,-535 2491.03,-529.88 2493.88,-524.65 2496.85,-519.72\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2499.72,-521.72 2502.15,-511.41 2493.82,-517.96 2499.72,-521.72\"/>\n",
       "</g>\n",
       "<!-- 4694263984* -->\n",
       "<g id=\"node77\" class=\"node\">\n",
       "<title>4694263984*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2301\" cy=\"-698\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2301\" y=\"-692.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694263984*&#45;&gt;4694263984 -->\n",
       "<g id=\"edge28\" class=\"edge\">\n",
       "<title>4694263984*&#45;&gt;4694263984</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2328.32,-698C2336.03,-698 2344.76,-698 2353.54,-698\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2353.5,-701.5 2363.5,-698 2353.5,-694.5 2353.5,-701.5\"/>\n",
       "</g>\n",
       "<!-- 4690045168 -->\n",
       "<g id=\"node78\" class=\"node\">\n",
       "<title>4690045168</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"667,-349.5 667,-398.5 752.75,-398.5 752.75,-349.5 667,-349.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-381.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.529</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"667,-374 752.75,-374\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-356.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690045168&#45;&gt;4694262640* -->\n",
       "<g id=\"edge111\" class=\"edge\">\n",
       "<title>4690045168&#45;&gt;4694262640*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M753.12,-374C761.03,-374 769.25,-374 777.01,-374\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"776.82,-377.5 786.82,-374 776.82,-370.5 776.82,-377.5\"/>\n",
       "</g>\n",
       "<!-- 4694264080 -->\n",
       "<g id=\"node79\" class=\"node\">\n",
       "<title>4694264080</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2578.75,-469.5 2578.75,-518.5 2667.5,-518.5 2667.5,-469.5 2578.75,-469.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2623.12\" y=\"-501.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;14.455</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2578.75,-494 2667.5,-494\"/>\n",
       "<text text-anchor=\"middle\" x=\"2623.12\" y=\"-476.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264080&#45;&gt;4694262688tanh -->\n",
       "<g id=\"edge237\" class=\"edge\">\n",
       "<title>4694264080&#45;&gt;4694262688tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2667.9,-494C2675.86,-494 2684.1,-494 2691.86,-494\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2691.67,-497.5 2701.67,-494 2691.67,-490.5 2691.67,-497.5\"/>\n",
       "</g>\n",
       "<!-- 4694264080+&#45;&gt;4694264080 -->\n",
       "<g id=\"edge29\" class=\"edge\">\n",
       "<title>4694264080+&#45;&gt;4694264080</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2543.07,-494C2550.44,-494 2558.75,-494 2567.13,-494\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2567.02,-497.5 2577.02,-494 2567.02,-490.5 2567.02,-497.5\"/>\n",
       "</g>\n",
       "<!-- 4690045216 -->\n",
       "<g id=\"node81\" class=\"node\">\n",
       "<title>4690045216</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-68.5 878.75,-117.5 964.5,-117.5 964.5,-68.5 878.75,-68.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-100.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;3.038</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-93 964.5,-93\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-75.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690045216&#45;&gt;4694262736+ -->\n",
       "<g id=\"edge285\" class=\"edge\">\n",
       "<title>4690045216&#45;&gt;4694262736+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M964.87,-97.07C972.86,-97.84 981.16,-98.63 988.98,-99.39\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"988.59,-102.87 998.88,-100.34 989.26,-95.9 988.59,-102.87\"/>\n",
       "</g>\n",
       "<!-- 4694223184 -->\n",
       "<g id=\"node82\" class=\"node\">\n",
       "<title>4694223184</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"667,-699.5 667,-748.5 752.75,-748.5 752.75,-699.5 667,-699.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-731.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.346</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"667,-724 752.75,-724\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-706.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694223280+ -->\n",
       "<g id=\"node88\" class=\"node\">\n",
       "<title>4694223280+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"815.75\" cy=\"-781\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"815.75\" y=\"-775.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694223184&#45;&gt;4694223280+ -->\n",
       "<g id=\"edge225\" class=\"edge\">\n",
       "<title>4694223184&#45;&gt;4694223280+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M753.12,-747.18C763.52,-752.89 774.45,-758.89 784.17,-764.22\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"782.39,-767.23 792.84,-768.98 785.76,-761.1 782.39,-767.23\"/>\n",
       "</g>\n",
       "<!-- 4694223184*&#45;&gt;4694223184 -->\n",
       "<g id=\"edge30\" class=\"edge\">\n",
       "<title>4694223184*&#45;&gt;4694223184</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M631.48,-724C638.84,-724 647.1,-724 655.41,-724\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"655.19,-727.5 665.19,-724 655.19,-720.5 655.19,-727.5\"/>\n",
       "</g>\n",
       "<!-- 4694223232 -->\n",
       "<g id=\"node84\" class=\"node\">\n",
       "<title>4694223232</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-688.5 1090.5,-737.5 1176.25,-737.5 1176.25,-688.5 1090.5,-688.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-720.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.997</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-713 1176.25,-713\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-695.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694223232&#45;&gt;4694263024* -->\n",
       "<g id=\"edge153\" class=\"edge\">\n",
       "<title>4694223232&#45;&gt;4694263024*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1167.39,-688.06C1170.53,-685.15 1173.54,-682.1 1176.25,-679 1196.3,-656.03 1213.78,-625.76 1225.03,-604.18\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1228.07,-605.91 1229.49,-595.41 1221.83,-602.74 1228.07,-605.91\"/>\n",
       "</g>\n",
       "<!-- 4694225296* -->\n",
       "<g id=\"node157\" class=\"node\">\n",
       "<title>4694225296*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1239.25\" cy=\"-713\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1239.25\" y=\"-707.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694223232&#45;&gt;4694225296* -->\n",
       "<g id=\"edge104\" class=\"edge\">\n",
       "<title>4694223232&#45;&gt;4694225296*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1176.62,-713C1184.53,-713 1192.75,-713 1200.51,-713\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1200.32,-716.5 1210.32,-713 1200.32,-709.5 1200.32,-716.5\"/>\n",
       "</g>\n",
       "<!-- 4694223232&#45;&gt;4694226928* -->\n",
       "<g id=\"edge170\" class=\"edge\">\n",
       "<title>4694223232&#45;&gt;4694226928*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1172.46,-737.93C1184.74,-745.97 1198.12,-754.73 1209.59,-762.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1207.56,-765.09 1217.84,-767.64 1211.39,-759.23 1207.56,-765.09\"/>\n",
       "</g>\n",
       "<!-- 4694223232&#45;&gt;4694228560* -->\n",
       "<g id=\"edge243\" class=\"edge\">\n",
       "<title>4694223232&#45;&gt;4694228560*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1169.38,-737.92C1171.97,-740.75 1174.32,-743.79 1176.25,-747 1218.79,-817.64 1181.65,-852.43 1212.25,-929 1214.33,-934.2 1217.08,-939.47 1220.02,-944.42\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1217,-946.19 1225.33,-952.72 1222.89,-942.41 1217,-946.19\"/>\n",
       "</g>\n",
       "<!-- 4694223232tanh -->\n",
       "<g id=\"node85\" class=\"node\">\n",
       "<title>4694223232tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1027.5\" cy=\"-774\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1027.5\" y=\"-768.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694223232tanh&#45;&gt;4694223232 -->\n",
       "<g id=\"edge31\" class=\"edge\">\n",
       "<title>4694223232tanh&#45;&gt;4694223232</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1048.53,-762.24C1057.65,-756.88 1068.91,-750.27 1080.19,-743.65\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1081.89,-746.7 1088.75,-738.62 1078.35,-740.67 1081.89,-746.7\"/>\n",
       "</g>\n",
       "<!-- 4690045312 -->\n",
       "<g id=\"node86\" class=\"node\">\n",
       "<title>4690045312</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-348.5 878.75,-397.5 964.5,-397.5 964.5,-348.5 878.75,-348.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-380.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=3.488</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-373 964.5,-373\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-355.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690045312&#45;&gt;4694262832* -->\n",
       "<g id=\"edge114\" class=\"edge\">\n",
       "<title>4690045312&#45;&gt;4694262832*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M964.87,-373C972.78,-373 981,-373 988.76,-373\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"988.57,-376.5 998.57,-373 988.57,-369.5 988.57,-376.5\"/>\n",
       "</g>\n",
       "<!-- 4694223280 -->\n",
       "<g id=\"node87\" class=\"node\">\n",
       "<title>4694223280</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-756.5 878.75,-805.5 964.5,-805.5 964.5,-756.5 878.75,-756.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-788.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;3.215</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-781 964.5,-781\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-763.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694223280&#45;&gt;4694223232tanh -->\n",
       "<g id=\"edge193\" class=\"edge\">\n",
       "<title>4694223280&#45;&gt;4694223232tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M964.87,-778.15C972.86,-777.61 981.16,-777.06 988.98,-776.53\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"989.14,-780.03 998.88,-775.86 988.67,-773.04 989.14,-780.03\"/>\n",
       "</g>\n",
       "<!-- 4694223280+&#45;&gt;4694223280 -->\n",
       "<g id=\"edge32\" class=\"edge\">\n",
       "<title>4694223280+&#45;&gt;4694223280</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M843.23,-781C850.59,-781 858.85,-781 867.16,-781\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"866.94,-784.5 876.94,-781 866.94,-777.5 866.94,-784.5\"/>\n",
       "</g>\n",
       "<!-- 4694264272 -->\n",
       "<g id=\"node89\" class=\"node\">\n",
       "<title>4694264272</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"3005.25,-584.5 3005.25,-633.5 3091,-633.5 3091,-584.5 3005.25,-584.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"3048.12\" y=\"-616.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=5.886</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"3005.25,-609 3091,-609\"/>\n",
       "<text text-anchor=\"middle\" x=\"3048.12\" y=\"-591.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264368+ -->\n",
       "<g id=\"node93\" class=\"node\">\n",
       "<title>4694264368+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"3169.88\" cy=\"-673\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"3169.88\" y=\"-667.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694264272&#45;&gt;4694264368+ -->\n",
       "<g id=\"edge203\" class=\"edge\">\n",
       "<title>4694264272&#45;&gt;4694264368+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3091.34,-631.56C3106.84,-639.85 3124.07,-649.05 3138.35,-656.68\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3136.35,-659.58 3146.81,-661.21 3139.65,-653.41 3136.35,-659.58\"/>\n",
       "</g>\n",
       "<!-- 4694264272* -->\n",
       "<g id=\"node90\" class=\"node\">\n",
       "<title>4694264272*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2942.25\" cy=\"-609\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2942.25\" y=\"-603.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694264272*&#45;&gt;4694264272 -->\n",
       "<g id=\"edge33\" class=\"edge\">\n",
       "<title>4694264272*&#45;&gt;4694264272</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2969.73,-609C2977.09,-609 2985.35,-609 2993.66,-609\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2993.44,-612.5 3003.44,-609 2993.44,-605.5 2993.44,-612.5\"/>\n",
       "</g>\n",
       "<!-- 4690045408 -->\n",
       "<g id=\"node91\" class=\"node\">\n",
       "<title>4690045408</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-552.5 1090.5,-601.5 1176.25,-601.5 1176.25,-552.5 1090.5,-552.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-584.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.458</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-577 1176.25,-577\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-559.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690045408&#45;&gt;4694263024* -->\n",
       "<g id=\"edge266\" class=\"edge\">\n",
       "<title>4690045408&#45;&gt;4694263024*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1176.62,-577C1184.53,-577 1192.75,-577 1200.51,-577\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1200.32,-580.5 1210.32,-577 1200.32,-573.5 1200.32,-580.5\"/>\n",
       "</g>\n",
       "<!-- 4694264368 -->\n",
       "<g id=\"node92\" class=\"node\">\n",
       "<title>4694264368</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"3248.75,-650.5 3248.75,-699.5 3334.5,-699.5 3334.5,-650.5 3248.75,-650.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"3291.62\" y=\"-682.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=12.178</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"3248.75,-675 3334.5,-675\"/>\n",
       "<text text-anchor=\"middle\" x=\"3291.62\" y=\"-657.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264560+ -->\n",
       "<g id=\"node105\" class=\"node\">\n",
       "<title>4694264560+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"3413.38\" cy=\"-688\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"3413.38\" y=\"-682.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694264368&#45;&gt;4694264560+ -->\n",
       "<g id=\"edge263\" class=\"edge\">\n",
       "<title>4694264368&#45;&gt;4694264560+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3334.84,-679.58C3348.04,-681.02 3362.5,-682.59 3375.31,-683.98\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3374.71,-687.43 3385.03,-685.03 3375.47,-680.47 3374.71,-687.43\"/>\n",
       "</g>\n",
       "<!-- 4694264368+&#45;&gt;4694264368 -->\n",
       "<g id=\"edge34\" class=\"edge\">\n",
       "<title>4694264368+&#45;&gt;4694264368</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3197.15,-673.44C3208.88,-673.63 3223.15,-673.87 3236.97,-674.1\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3236.84,-677.6 3246.89,-674.27 3236.95,-670.6 3236.84,-677.6\"/>\n",
       "</g>\n",
       "<!-- 4690045504 -->\n",
       "<g id=\"node94\" class=\"node\">\n",
       "<title>4690045504</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-61.5 1302.25,-110.5 1388,-110.5 1388,-61.5 1302.25,-61.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-93.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.562</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-86 1388,-86\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-68.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690045504&#45;&gt;4694263216* -->\n",
       "<g id=\"edge280\" class=\"edge\">\n",
       "<title>4690045504&#45;&gt;4694263216*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1378.25,-110.98C1381.63,-113.93 1384.94,-116.97 1388,-120 1403.7,-135.56 1419.55,-154.81 1431.29,-169.91\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1428.25,-171.7 1437.11,-177.5 1433.81,-167.44 1428.25,-171.7\"/>\n",
       "</g>\n",
       "<!-- 4694223472 -->\n",
       "<g id=\"node95\" class=\"node\">\n",
       "<title>4694223472</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"333.5,-114.5 333.5,-163.5 419.25,-163.5 419.25,-114.5 333.5,-114.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"376.38\" y=\"-146.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.720</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"333.5,-139 419.25,-139\"/>\n",
       "<text text-anchor=\"middle\" x=\"376.38\" y=\"-121.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694223568+ -->\n",
       "<g id=\"node103\" class=\"node\">\n",
       "<title>4694223568+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1027.5\" cy=\"-171\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1027.5\" y=\"-165.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694223472&#45;&gt;4694223568+ -->\n",
       "<g id=\"edge182\" class=\"edge\">\n",
       "<title>4694223472&#45;&gt;4694223568+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M419.36,-141.08C464.66,-143.14 538.92,-146 603,-146 603,-146 603,-146 816.75,-146 877.8,-146 948.14,-156.57 989.87,-163.96\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"989.16,-167.39 999.62,-165.73 990.4,-160.5 989.16,-167.39\"/>\n",
       "</g>\n",
       "<!-- 4694223472*&#45;&gt;4694223472 -->\n",
       "<g id=\"edge35\" class=\"edge\">\n",
       "<title>4694223472*&#45;&gt;4694223472</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M176.07,-145.18C211.65,-144.08 275.91,-142.09 321.85,-140.66\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"321.71,-144.17 331.59,-140.36 321.49,-137.17 321.71,-144.17\"/>\n",
       "</g>\n",
       "<!-- 4694264464 -->\n",
       "<g id=\"node97\" class=\"node\">\n",
       "<title>4694264464</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"3127,-709.5 3127,-758.5 3212.75,-758.5 3212.75,-709.5 3127,-709.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"3169.88\" y=\"-741.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;3.739</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"3127,-734 3212.75,-734\"/>\n",
       "<text text-anchor=\"middle\" x=\"3169.88\" y=\"-716.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264464&#45;&gt;4694264560+ -->\n",
       "<g id=\"edge275\" class=\"edge\">\n",
       "<title>4694264464&#45;&gt;4694264560+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3213.14,-728.86C3246.32,-724.51 3293.58,-717.61 3334.5,-709 3348.74,-706 3364.25,-701.98 3377.65,-698.26\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3378.22,-701.73 3386.88,-695.64 3376.31,-695 3378.22,-701.73\"/>\n",
       "</g>\n",
       "<!-- 4694264464* -->\n",
       "<g id=\"node98\" class=\"node\">\n",
       "<title>4694264464*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2942.25\" cy=\"-734\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2942.25\" y=\"-728.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694264464*&#45;&gt;4694264464 -->\n",
       "<g id=\"edge36\" class=\"edge\">\n",
       "<title>4694264464*&#45;&gt;4694264464</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2969.57,-734C3005.15,-734 3069.41,-734 3115.35,-734\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3115.09,-737.5 3125.09,-734 3115.09,-730.5 3115.09,-737.5\"/>\n",
       "</g>\n",
       "<!-- 4694223520 -->\n",
       "<g id=\"node99\" class=\"node\">\n",
       "<title>4694223520</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-197.5 1302.25,-246.5 1388,-246.5 1388,-197.5 1302.25,-197.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-229.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.552</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-222 1388,-222\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-204.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694223520&#45;&gt;4694263216* -->\n",
       "<g id=\"edge199\" class=\"edge\">\n",
       "<title>4694223520&#45;&gt;4694263216*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1388.37,-211.02C1397.02,-208.77 1406.05,-206.42 1414.43,-204.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1415.12,-207.68 1423.92,-201.78 1413.36,-200.91 1415.12,-207.68\"/>\n",
       "</g>\n",
       "<!-- 4694225488* -->\n",
       "<g id=\"node161\" class=\"node\">\n",
       "<title>4694225488*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1451\" cy=\"-249\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1451\" y=\"-243.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694223520&#45;&gt;4694225488* -->\n",
       "<g id=\"edge149\" class=\"edge\">\n",
       "<title>4694223520&#45;&gt;4694225488*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1388.37,-232.98C1397.02,-235.23 1406.05,-237.58 1414.43,-239.76\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1413.36,-243.09 1423.92,-242.22 1415.12,-236.32 1413.36,-243.09\"/>\n",
       "</g>\n",
       "<!-- 4694223520&#45;&gt;4694227120* -->\n",
       "<g id=\"edge216\" class=\"edge\">\n",
       "<title>4694223520&#45;&gt;4694227120*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1381.39,-246.77C1383.92,-249.64 1386.19,-252.72 1388,-256 1452.68,-373.18 1393.91,-424.58 1424,-555 1427.67,-570.89 1433.5,-588.12 1438.71,-602.05\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1435.31,-602.95 1442.17,-611.02 1441.84,-600.43 1435.31,-602.95\"/>\n",
       "</g>\n",
       "<!-- 4694223520&#45;&gt;4694228752* -->\n",
       "<g id=\"edge109\" class=\"edge\">\n",
       "<title>4694223520&#45;&gt;4694228752*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1381.49,-246.71C1384.01,-249.59 1386.24,-252.69 1388,-256 1472.08,-413.95 1366.47,-487.56 1424,-657 1425.8,-662.31 1428.42,-667.62 1431.31,-672.59\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1428.29,-674.36 1436.64,-680.89 1434.19,-670.58 1428.29,-674.36\"/>\n",
       "</g>\n",
       "<!-- 4694223520tanh -->\n",
       "<g id=\"node100\" class=\"node\">\n",
       "<title>4694223520tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1239.25\" cy=\"-211\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1239.25\" y=\"-205.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694223520tanh&#45;&gt;4694223520 -->\n",
       "<g id=\"edge37\" class=\"edge\">\n",
       "<title>4694223520tanh&#45;&gt;4694223520</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1266.19,-213.75C1273.71,-214.54 1282.22,-215.44 1290.77,-216.35\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1290.14,-219.8 1300.46,-217.38 1290.88,-212.84 1290.14,-219.8\"/>\n",
       "</g>\n",
       "<!-- 4690045600 -->\n",
       "<g id=\"node101\" class=\"node\">\n",
       "<title>4690045600</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-945.5 1514,-994.5 1599.75,-994.5 1599.75,-945.5 1514,-945.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-977.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.878</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-970 1599.75,-970\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-952.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690045600&#45;&gt;4694263408* -->\n",
       "<g id=\"edge241\" class=\"edge\">\n",
       "<title>4690045600&#45;&gt;4694263408*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1600.12,-970C1608.03,-970 1616.25,-970 1624.01,-970\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1623.82,-973.5 1633.82,-970 1623.82,-966.5 1623.82,-973.5\"/>\n",
       "</g>\n",
       "<!-- 4694223568 -->\n",
       "<g id=\"node102\" class=\"node\">\n",
       "<title>4694223568</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-146.5 1090.5,-195.5 1176.25,-195.5 1176.25,-146.5 1090.5,-146.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-178.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.621</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-171 1176.25,-171\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-153.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694223568&#45;&gt;4694223520tanh -->\n",
       "<g id=\"edge185\" class=\"edge\">\n",
       "<title>4694223568&#45;&gt;4694223520tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1176.62,-187.27C1186.05,-190.9 1195.91,-194.7 1204.92,-198.17\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1203.39,-201.33 1213.98,-201.65 1205.9,-194.79 1203.39,-201.33\"/>\n",
       "</g>\n",
       "<!-- 4694223568+&#45;&gt;4694223568 -->\n",
       "<g id=\"edge38\" class=\"edge\">\n",
       "<title>4694223568+&#45;&gt;4694223568</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1054.98,-171C1062.34,-171 1070.6,-171 1078.91,-171\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1078.69,-174.5 1088.69,-171 1078.69,-167.5 1078.69,-174.5\"/>\n",
       "</g>\n",
       "<!-- 4694264560 -->\n",
       "<g id=\"node104\" class=\"node\">\n",
       "<title>4694264560</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"3492.25,-663.5 3492.25,-712.5 3578,-712.5 3578,-663.5 3492.25,-663.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"3535.12\" y=\"-695.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=8.439</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"3492.25,-688 3578,-688\"/>\n",
       "<text text-anchor=\"middle\" x=\"3535.12\" y=\"-670.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264752+ -->\n",
       "<g id=\"node113\" class=\"node\">\n",
       "<title>4694264752+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"3641\" cy=\"-688\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"3641\" y=\"-682.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694264560&#45;&gt;4694264752+ -->\n",
       "<g id=\"edge205\" class=\"edge\">\n",
       "<title>4694264560&#45;&gt;4694264752+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3578.37,-688C3586.28,-688 3594.5,-688 3602.26,-688\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3602.07,-691.5 3612.07,-688 3602.07,-684.5 3602.07,-691.5\"/>\n",
       "</g>\n",
       "<!-- 4694264560+&#45;&gt;4694264560 -->\n",
       "<g id=\"edge39\" class=\"edge\">\n",
       "<title>4694264560+&#45;&gt;4694264560</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3440.65,-688C3452.38,-688 3466.65,-688 3480.47,-688\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3480.39,-691.5 3490.39,-688 3480.39,-684.5 3480.39,-691.5\"/>\n",
       "</g>\n",
       "<!-- 4690045696 -->\n",
       "<g id=\"node106\" class=\"node\">\n",
       "<title>4690045696</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-265.5 1725.75,-314.5 1811.5,-314.5 1811.5,-265.5 1725.75,-265.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-297.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.541</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-290 1811.5,-290\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-272.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690045696&#45;&gt;4694263600* -->\n",
       "<g id=\"edge127\" class=\"edge\">\n",
       "<title>4690045696&#45;&gt;4694263600*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1807.71,-314.93C1819.99,-322.97 1833.37,-331.73 1844.84,-339.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1842.81,-342.09 1853.09,-344.64 1846.64,-336.23 1842.81,-342.09\"/>\n",
       "</g>\n",
       "<!-- 4694264656 -->\n",
       "<g id=\"node107\" class=\"node\">\n",
       "<title>4694264656</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"3248.75,-762.5 3248.75,-811.5 3334.5,-811.5 3334.5,-762.5 3248.75,-762.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"3291.62\" y=\"-794.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;4.125</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"3248.75,-787 3334.5,-787\"/>\n",
       "<text text-anchor=\"middle\" x=\"3291.62\" y=\"-769.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264656&#45;&gt;4694264752+ -->\n",
       "<g id=\"edge121\" class=\"edge\">\n",
       "<title>4694264656&#45;&gt;4694264752+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3334.8,-781.15C3391.45,-772.45 3494.63,-753.65 3578,-722 3589.16,-717.76 3600.78,-711.84 3610.91,-706.12\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3612.67,-709.15 3619.54,-701.08 3609.14,-703.11 3612.67,-709.15\"/>\n",
       "</g>\n",
       "<!-- 4694264656* -->\n",
       "<g id=\"node108\" class=\"node\">\n",
       "<title>4694264656*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2942.25\" cy=\"-834\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2942.25\" y=\"-828.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694264656*&#45;&gt;4694264656 -->\n",
       "<g id=\"edge40\" class=\"edge\">\n",
       "<title>4694264656*&#45;&gt;4694264656</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2969.08,-830.51C3025.61,-822.86 3161.31,-804.5 3237.11,-794.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3237.35,-797.74 3246.79,-792.93 3236.41,-790.8 3237.35,-797.74\"/>\n",
       "</g>\n",
       "<!-- 4690045792 -->\n",
       "<g id=\"node109\" class=\"node\">\n",
       "<title>4690045792</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-61.5 1937.5,-110.5 2023.25,-110.5 2023.25,-61.5 1937.5,-61.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-93.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.506</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-86 2023.25,-86\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-68.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690045792&#45;&gt;4694263792* -->\n",
       "<g id=\"edge281\" class=\"edge\">\n",
       "<title>4690045792&#45;&gt;4694263792*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2019.46,-110.93C2031.74,-118.97 2045.12,-127.73 2056.59,-135.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2054.56,-138.09 2064.84,-140.64 2058.39,-132.23 2054.56,-138.09\"/>\n",
       "</g>\n",
       "<!-- 4694223760 -->\n",
       "<g id=\"node110\" class=\"node\">\n",
       "<title>4694223760</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"211.75,-1221.5 211.75,-1270.5 297.5,-1270.5 297.5,-1221.5 211.75,-1221.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-1253.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.909</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"211.75,-1246 297.5,-1246\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-1228.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694223856+ -->\n",
       "<g id=\"node118\" class=\"node\">\n",
       "<title>4694223856+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"376.38\" cy=\"-1212\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"376.38\" y=\"-1206.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694223760&#45;&gt;4694223856+ -->\n",
       "<g id=\"edge262\" class=\"edge\">\n",
       "<title>4694223760&#45;&gt;4694223856+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M297.84,-1234.01C311.59,-1230.11 326.71,-1225.82 339.91,-1222.07\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"340.82,-1225.45 349.48,-1219.35 338.91,-1218.72 340.82,-1225.45\"/>\n",
       "</g>\n",
       "<!-- 4694223760*&#45;&gt;4694223760 -->\n",
       "<g id=\"edge41\" class=\"edge\">\n",
       "<title>4694223760*&#45;&gt;4694223760</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M173.32,-1218.94C181.5,-1221.7 191.03,-1224.91 200.6,-1228.14\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"199.34,-1231.4 209.94,-1231.28 201.58,-1224.77 199.34,-1231.4\"/>\n",
       "</g>\n",
       "<!-- 4694264752 -->\n",
       "<g id=\"node112\" class=\"node\">\n",
       "<title>4694264752</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"3704,-661.5 3704,-710.5 3789.75,-710.5 3789.75,-661.5 3704,-661.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"3746.88\" y=\"-693.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=4.315</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"3704,-686 3789.75,-686\"/>\n",
       "<text text-anchor=\"middle\" x=\"3746.88\" y=\"-668.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264944+ -->\n",
       "<g id=\"node122\" class=\"node\">\n",
       "<title>4694264944+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"3852.75\" cy=\"-655\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"3852.75\" y=\"-649.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694264752&#45;&gt;4694264944+ -->\n",
       "<g id=\"edge282\" class=\"edge\">\n",
       "<title>4694264752&#45;&gt;4694264944+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3790.12,-673.39C3799.03,-670.73 3808.33,-667.96 3816.92,-665.39\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3817.69,-668.82 3826.27,-662.6 3815.69,-662.11 3817.69,-668.82\"/>\n",
       "</g>\n",
       "<!-- 4694264752+&#45;&gt;4694264752 -->\n",
       "<g id=\"edge42\" class=\"edge\">\n",
       "<title>4694264752+&#45;&gt;4694264752</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3668.48,-687.49C3675.84,-687.35 3684.1,-687.19 3692.41,-687.03\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3692.25,-690.53 3702.19,-686.84 3692.12,-683.53 3692.25,-690.53\"/>\n",
       "</g>\n",
       "<!-- 4694223808 -->\n",
       "<g id=\"node114\" class=\"node\">\n",
       "<title>4694223808</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-1187.5 1514,-1236.5 1599.75,-1236.5 1599.75,-1187.5 1514,-1187.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-1219.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.000</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-1212 1599.75,-1212\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-1194.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694223808&#45;&gt;4694263408* -->\n",
       "<g id=\"edge238\" class=\"edge\">\n",
       "<title>4694223808&#45;&gt;4694263408*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1592.82,-1187.05C1595.42,-1184.22 1597.79,-1181.19 1599.75,-1178 1639.47,-1113.29 1606.97,-1081.26 1635.75,-1011 1637.87,-1005.81 1640.65,-1000.55 1643.59,-995.61\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1646.47,-997.62 1648.91,-987.31 1640.57,-993.84 1646.47,-997.62\"/>\n",
       "</g>\n",
       "<!-- 4694225680* -->\n",
       "<g id=\"node165\" class=\"node\">\n",
       "<title>4694225680*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1662.75\" cy=\"-1144\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1662.75\" y=\"-1138.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694223808&#45;&gt;4694225680* -->\n",
       "<g id=\"edge195\" class=\"edge\">\n",
       "<title>4694223808&#45;&gt;4694225680*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1595.96,-1187.07C1608.24,-1179.03 1621.62,-1170.27 1633.09,-1162.76\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1634.89,-1165.77 1641.34,-1157.36 1631.06,-1159.91 1634.89,-1165.77\"/>\n",
       "</g>\n",
       "<!-- 4694223808&#45;&gt;4694227312* -->\n",
       "<g id=\"edge267\" class=\"edge\">\n",
       "<title>4694223808&#45;&gt;4694227312*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1600.12,-1209.15C1608.11,-1208.61 1616.41,-1208.06 1624.23,-1207.53\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1624.39,-1211.03 1634.13,-1206.86 1623.92,-1204.04 1624.39,-1211.03\"/>\n",
       "</g>\n",
       "<!-- 4694223808&#45;&gt;4694228944* -->\n",
       "<g id=\"edge154\" class=\"edge\">\n",
       "<title>4694223808&#45;&gt;4694228944*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1600.12,-1231.12C1609.89,-1235.54 1620.14,-1240.17 1629.41,-1244.37\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1627.82,-1247.49 1638.37,-1248.42 1630.71,-1241.11 1627.82,-1247.49\"/>\n",
       "</g>\n",
       "<!-- 4694223808tanh -->\n",
       "<g id=\"node115\" class=\"node\">\n",
       "<title>4694223808tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"604\" cy=\"-1212\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"604\" y=\"-1206.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694223808tanh&#45;&gt;4694223808 -->\n",
       "<g id=\"edge43\" class=\"edge\">\n",
       "<title>4694223808tanh&#45;&gt;4694223808</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M631.49,-1212C671.28,-1212 748.84,-1212 814.75,-1212 814.75,-1212 814.75,-1212 1346.12,-1212 1399.22,-1212 1459.86,-1212 1502.24,-1212\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1502.18,-1215.5 1512.18,-1212 1502.18,-1208.5 1502.18,-1215.5\"/>\n",
       "</g>\n",
       "<!-- 4690045888 -->\n",
       "<g id=\"node116\" class=\"node\">\n",
       "<title>4690045888</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-673.5 2150.75,-722.5 2236.5,-722.5 2236.5,-673.5 2150.75,-673.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-705.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.458</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-698 2236.5,-698\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-680.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690045888&#45;&gt;4694263984* -->\n",
       "<g id=\"edge207\" class=\"edge\">\n",
       "<title>4690045888&#45;&gt;4694263984*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2236.88,-698C2245.19,-698 2253.86,-698 2262.02,-698\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2261.99,-701.5 2271.99,-698 2261.99,-694.5 2261.99,-701.5\"/>\n",
       "</g>\n",
       "<!-- 4694223856 -->\n",
       "<g id=\"node117\" class=\"node\">\n",
       "<title>4694223856</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"455.25,-1187.5 455.25,-1236.5 541,-1236.5 541,-1187.5 455.25,-1187.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-1219.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;5.590</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"455.25,-1212 541,-1212\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-1194.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694223856&#45;&gt;4694223808tanh -->\n",
       "<g id=\"edge286\" class=\"edge\">\n",
       "<title>4694223856&#45;&gt;4694223808tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M541.37,-1212C549.28,-1212 557.5,-1212 565.26,-1212\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"565.07,-1215.5 575.07,-1212 565.07,-1208.5 565.07,-1215.5\"/>\n",
       "</g>\n",
       "<!-- 4694223856+&#45;&gt;4694223856 -->\n",
       "<g id=\"edge44\" class=\"edge\">\n",
       "<title>4694223856+&#45;&gt;4694223856</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M403.65,-1212C415.38,-1212 429.65,-1212 443.47,-1212\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"443.39,-1215.5 453.39,-1212 443.39,-1208.5 443.39,-1215.5\"/>\n",
       "</g>\n",
       "<!-- 4694264848 -->\n",
       "<g id=\"node119\" class=\"node\">\n",
       "<title>4694264848</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"3370.5,-572.5 3370.5,-621.5 3456.25,-621.5 3456.25,-572.5 3370.5,-572.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"3413.38\" y=\"-604.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;3.395</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"3370.5,-597 3456.25,-597\"/>\n",
       "<text text-anchor=\"middle\" x=\"3413.38\" y=\"-579.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264848&#45;&gt;4694264944+ -->\n",
       "<g id=\"edge192\" class=\"edge\">\n",
       "<title>4694264848&#45;&gt;4694264944+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3456.71,-602.61C3542.03,-613.93 3733.41,-639.31 3814.41,-650.05\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3813.88,-653.51 3824.25,-651.35 3814.8,-646.57 3813.88,-653.51\"/>\n",
       "</g>\n",
       "<!-- 4694264848*&#45;&gt;4694264848 -->\n",
       "<g id=\"edge45\" class=\"edge\">\n",
       "<title>4694264848*&#45;&gt;4694264848</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2968.47,-499.54C3042.14,-515.71 3258.14,-563.14 3359.15,-585.31\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3358.31,-588.71 3368.83,-587.44 3359.81,-581.88 3358.31,-588.71\"/>\n",
       "</g>\n",
       "<!-- 4694264944 -->\n",
       "<g id=\"node121\" class=\"node\">\n",
       "<title>4694264944</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"3915.75,-630.5 3915.75,-679.5 4001.5,-679.5 4001.5,-630.5 3915.75,-630.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"3958.62\" y=\"-662.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.920</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"3915.75,-655 4001.5,-655\"/>\n",
       "<text text-anchor=\"middle\" x=\"3958.62\" y=\"-637.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694264944+&#45;&gt;4694264944 -->\n",
       "<g id=\"edge46\" class=\"edge\">\n",
       "<title>4694264944+&#45;&gt;4694264944</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3880.23,-655C3887.59,-655 3895.85,-655 3904.16,-655\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3903.94,-658.5 3913.94,-655 3903.94,-651.5 3903.94,-658.5\"/>\n",
       "</g>\n",
       "<!-- 4694224048 -->\n",
       "<g id=\"node123\" class=\"node\">\n",
       "<title>4694224048</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-401.5 1302.25,-450.5 1388,-450.5 1388,-401.5 1302.25,-401.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-433.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.748</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-426 1388,-426\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-408.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694224144+ -->\n",
       "<g id=\"node128\" class=\"node\">\n",
       "<title>4694224144+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1451\" cy=\"-426\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1451\" y=\"-420.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694224048&#45;&gt;4694224144+ -->\n",
       "<g id=\"edge167\" class=\"edge\">\n",
       "<title>4694224048&#45;&gt;4694224144+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1388.37,-426C1396.28,-426 1404.5,-426 1412.26,-426\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1412.07,-429.5 1422.07,-426 1412.07,-422.5 1412.07,-429.5\"/>\n",
       "</g>\n",
       "<!-- 4694224048*&#45;&gt;4694224048 -->\n",
       "<g id=\"edge47\" class=\"edge\">\n",
       "<title>4694224048*&#45;&gt;4694224048</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1260.28,-377.57C1269.4,-382.84 1280.66,-389.34 1291.94,-395.86\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1290.08,-398.82 1300.49,-400.8 1293.58,-392.76 1290.08,-398.82\"/>\n",
       "</g>\n",
       "<!-- 4694224096 -->\n",
       "<g id=\"node125\" class=\"node\">\n",
       "<title>4694224096</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-401.5 1725.75,-450.5 1811.5,-450.5 1811.5,-401.5 1725.75,-401.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-433.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.000</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-426 1811.5,-426\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-408.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694224096&#45;&gt;4694261968* -->\n",
       "<g id=\"edge204\" class=\"edge\">\n",
       "<title>4694224096&#45;&gt;4694261968*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1802.68,-450.91C1805.81,-453.82 1808.81,-456.88 1811.5,-460 1832.04,-483.85 1831.07,-494.15 1847.5,-521 1850.43,-525.78 1853.59,-530.84 1856.66,-535.72\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1853.63,-537.47 1861.94,-544.04 1859.54,-533.72 1853.63,-537.47\"/>\n",
       "</g>\n",
       "<!-- 4694224096&#45;&gt;4694263600* -->\n",
       "<g id=\"edge276\" class=\"edge\">\n",
       "<title>4694224096&#45;&gt;4694263600*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1807.71,-401.07C1819.99,-393.03 1833.37,-384.27 1844.84,-376.76\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1846.64,-379.77 1853.09,-371.36 1842.81,-373.91 1846.64,-379.77\"/>\n",
       "</g>\n",
       "<!-- 4694225872* -->\n",
       "<g id=\"node169\" class=\"node\">\n",
       "<title>4694225872*</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1874.5\" cy=\"-426\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1874.5\" y=\"-420.95\" font-family=\"Times,serif\" font-size=\"14.00\">*</text>\n",
       "</g>\n",
       "<!-- 4694224096&#45;&gt;4694225872* -->\n",
       "<g id=\"edge176\" class=\"edge\">\n",
       "<title>4694224096&#45;&gt;4694225872*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1811.87,-426C1819.78,-426 1828,-426 1835.76,-426\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1835.57,-429.5 1845.57,-426 1835.57,-422.5 1835.57,-429.5\"/>\n",
       "</g>\n",
       "<!-- 4694224096&#45;&gt;4694227504* -->\n",
       "<g id=\"edge249\" class=\"edge\">\n",
       "<title>4694224096&#45;&gt;4694227504*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1807.71,-450.93C1819.99,-458.97 1833.37,-467.73 1844.84,-475.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1842.81,-478.09 1853.09,-480.64 1846.64,-472.23 1842.81,-478.09\"/>\n",
       "</g>\n",
       "<!-- 4694224096tanh -->\n",
       "<g id=\"node126\" class=\"node\">\n",
       "<title>4694224096tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1662.75\" cy=\"-426\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1662.75\" y=\"-420.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694224096tanh&#45;&gt;4694224096 -->\n",
       "<g id=\"edge48\" class=\"edge\">\n",
       "<title>4694224096tanh&#45;&gt;4694224096</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1690.23,-426C1697.59,-426 1705.85,-426 1714.16,-426\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1713.94,-429.5 1723.94,-426 1713.94,-422.5 1713.94,-429.5\"/>\n",
       "</g>\n",
       "<!-- 4694224144 -->\n",
       "<g id=\"node127\" class=\"node\">\n",
       "<title>4694224144</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-401.5 1514,-450.5 1599.75,-450.5 1599.75,-401.5 1514,-401.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-433.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;4.591</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-426 1599.75,-426\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-408.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694224144&#45;&gt;4694224096tanh -->\n",
       "<g id=\"edge172\" class=\"edge\">\n",
       "<title>4694224144&#45;&gt;4694224096tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1600.12,-426C1608.03,-426 1616.25,-426 1624.01,-426\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1623.82,-429.5 1633.82,-426 1623.82,-422.5 1623.82,-429.5\"/>\n",
       "</g>\n",
       "<!-- 4694224144+&#45;&gt;4694224144 -->\n",
       "<g id=\"edge49\" class=\"edge\">\n",
       "<title>4694224144+&#45;&gt;4694224144</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1478.48,-426C1485.84,-426 1494.1,-426 1502.41,-426\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1502.19,-429.5 1512.19,-426 1502.19,-422.5 1502.19,-429.5\"/>\n",
       "</g>\n",
       "<!-- 4690046224 -->\n",
       "<g id=\"node129\" class=\"node\">\n",
       "<title>4690046224</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2793.5,-605.5 2793.5,-654.5 2879.25,-654.5 2879.25,-605.5 2793.5,-605.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-637.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=5.994</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2793.5,-630 2879.25,-630\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-612.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690046224&#45;&gt;4694264272* -->\n",
       "<g id=\"edge231\" class=\"edge\">\n",
       "<title>4690046224&#45;&gt;4694264272*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2879.62,-621.46C2888.02,-619.76 2896.77,-617.99 2904.95,-616.34\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2905.45,-619.81 2914.55,-614.4 2904.06,-612.95 2905.45,-619.81\"/>\n",
       "</g>\n",
       "<!-- 4690046272 -->\n",
       "<g id=\"node130\" class=\"node\">\n",
       "<title>4690046272</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"3005.25,-652.5 3005.25,-701.5 3091,-701.5 3091,-652.5 3005.25,-652.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"3048.12\" y=\"-684.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=6.293</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"3005.25,-677 3091,-677\"/>\n",
       "<text text-anchor=\"middle\" x=\"3048.12\" y=\"-659.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690046272&#45;&gt;4694264368+ -->\n",
       "<g id=\"edge164\" class=\"edge\">\n",
       "<title>4690046272&#45;&gt;4694264368+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M3091.34,-675.59C3104.44,-675.15 3118.77,-674.67 3131.51,-674.25\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"3131.29,-677.76 3141.17,-673.93 3131.06,-670.76 3131.29,-677.76\"/>\n",
       "</g>\n",
       "<!-- 4690046368 -->\n",
       "<g id=\"node131\" class=\"node\">\n",
       "<title>4690046368</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2793.5,-741.5 2793.5,-790.5 2879.25,-790.5 2879.25,-741.5 2793.5,-741.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-773.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=3.779</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2793.5,-766 2879.25,-766\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-748.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690046368&#45;&gt;4694264464* -->\n",
       "<g id=\"edge171\" class=\"edge\">\n",
       "<title>4690046368&#45;&gt;4694264464*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2879.62,-752.98C2888.53,-750.24 2897.83,-747.38 2906.42,-744.73\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2907.25,-748.14 2915.78,-741.85 2905.19,-741.45 2907.25,-748.14\"/>\n",
       "</g>\n",
       "<!-- 4694224336 -->\n",
       "<g id=\"node132\" class=\"node\">\n",
       "<title>4694224336</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"211.75,-0.5 211.75,-49.5 297.5,-49.5 297.5,-0.5 211.75,-0.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-32.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.798</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"211.75,-25 297.5,-25\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-7.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694224432+ -->\n",
       "<g id=\"node138\" class=\"node\">\n",
       "<title>4694224432+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"376.38\" cy=\"-33\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"376.38\" y=\"-27.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694224336&#45;&gt;4694224432+ -->\n",
       "<g id=\"edge122\" class=\"edge\">\n",
       "<title>4694224336&#45;&gt;4694224432+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M297.84,-27.82C310.94,-28.7 325.27,-29.65 338.01,-30.5\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"337.46,-33.97 347.67,-31.15 337.93,-26.99 337.46,-33.97\"/>\n",
       "</g>\n",
       "<!-- 4694224336*&#45;&gt;4694224336 -->\n",
       "<g id=\"edge50\" class=\"edge\">\n",
       "<title>4694224336*&#45;&gt;4694224336</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M174.37,-45.6C182.21,-43.56 191.23,-41.22 200.29,-38.86\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"201.05,-42.28 209.84,-36.38 199.29,-35.51 201.05,-42.28\"/>\n",
       "</g>\n",
       "<!-- 4694224384 -->\n",
       "<g id=\"node134\" class=\"node\">\n",
       "<title>4694224384</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-197.5 1937.5,-246.5 2023.25,-246.5 2023.25,-197.5 1937.5,-197.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-229.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.000</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-222 2023.25,-222\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-204.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694224384&#45;&gt;4694262160* -->\n",
       "<g id=\"edge248\" class=\"edge\">\n",
       "<title>4694224384&#45;&gt;4694262160*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2015.72,-246.66C2018.52,-249.59 2021.09,-252.71 2023.25,-256 2055.89,-305.77 2035.05,-330.62 2059.25,-385 2061.53,-390.12 2064.38,-395.35 2067.35,-400.28\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2064.32,-402.04 2072.65,-408.59 2070.22,-398.28 2064.32,-402.04\"/>\n",
       "</g>\n",
       "<!-- 4694224384&#45;&gt;4694263792* -->\n",
       "<g id=\"edge145\" class=\"edge\">\n",
       "<title>4694224384&#45;&gt;4694263792*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2019.46,-197.07C2031.74,-189.03 2045.12,-180.27 2056.59,-172.76\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2058.39,-175.77 2064.84,-167.36 2054.56,-169.91 2058.39,-175.77\"/>\n",
       "</g>\n",
       "<!-- 4694224384&#45;&gt;4694226064* -->\n",
       "<g id=\"edge220\" class=\"edge\">\n",
       "<title>4694224384&#45;&gt;4694226064*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2023.62,-222C2031.53,-222 2039.75,-222 2047.51,-222\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2047.32,-225.5 2057.32,-222 2047.32,-218.5 2047.32,-225.5\"/>\n",
       "</g>\n",
       "<!-- 4694224384&#45;&gt;4694227696* -->\n",
       "<g id=\"edge116\" class=\"edge\">\n",
       "<title>4694224384&#45;&gt;4694227696*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2019.46,-246.93C2031.74,-254.97 2045.12,-263.73 2056.59,-271.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2054.56,-274.09 2064.84,-276.64 2058.39,-268.23 2054.56,-274.09\"/>\n",
       "</g>\n",
       "<!-- 4694224384tanh -->\n",
       "<g id=\"node135\" class=\"node\">\n",
       "<title>4694224384tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"604\" cy=\"-33\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"604\" y=\"-27.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694224384tanh&#45;&gt;4694224384 -->\n",
       "<g id=\"edge51\" class=\"edge\">\n",
       "<title>4694224384tanh&#45;&gt;4694224384</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M631.49,-33C671.28,-33 748.84,-33 814.75,-33 814.75,-33 814.75,-33 1769.62,-33 1871.18,-33 1860.74,-121.52 1937.5,-188 1938.27,-188.67 1939.06,-189.35 1939.85,-190.02\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1937.48,-192.6 1947.39,-196.36 1941.99,-187.25 1937.48,-192.6\"/>\n",
       "</g>\n",
       "<!-- 4690046464 -->\n",
       "<g id=\"node136\" class=\"node\">\n",
       "<title>4690046464</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2793.5,-877.5 2793.5,-926.5 2879.25,-926.5 2879.25,-877.5 2793.5,-877.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-909.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=4.143</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2793.5,-902 2879.25,-902\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-884.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690046464&#45;&gt;4694264656* -->\n",
       "<g id=\"edge106\" class=\"edge\">\n",
       "<title>4690046464&#45;&gt;4694264656*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2875.46,-877.07C2887.74,-869.03 2901.12,-860.27 2912.59,-852.76\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2914.39,-855.77 2920.84,-847.36 2910.56,-849.91 2914.39,-855.77\"/>\n",
       "</g>\n",
       "<!-- 4694224432 -->\n",
       "<g id=\"node137\" class=\"node\">\n",
       "<title>4694224432</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"455.25,-8.5 455.25,-57.5 541,-57.5 541,-8.5 455.25,-8.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-40.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;4.768</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"455.25,-33 541,-33\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-15.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694224432&#45;&gt;4694224384tanh -->\n",
       "<g id=\"edge140\" class=\"edge\">\n",
       "<title>4694224432&#45;&gt;4694224384tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M541.37,-33C549.28,-33 557.5,-33 565.26,-33\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"565.07,-36.5 575.07,-33 565.07,-29.5 565.07,-36.5\"/>\n",
       "</g>\n",
       "<!-- 4694224432+&#45;&gt;4694224432 -->\n",
       "<g id=\"edge52\" class=\"edge\">\n",
       "<title>4694224432+&#45;&gt;4694224432</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M403.65,-33C415.38,-33 429.65,-33 443.47,-33\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"443.39,-36.5 453.39,-33 443.39,-29.5 443.39,-36.5\"/>\n",
       "</g>\n",
       "<!-- 4690046560 -->\n",
       "<g id=\"node139\" class=\"node\">\n",
       "<title>4690046560</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2793.5,-401.5 2793.5,-450.5 2879.25,-450.5 2879.25,-401.5 2793.5,-401.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-433.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=3.395</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2793.5,-426 2879.25,-426\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-408.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690046560&#45;&gt;4694264848* -->\n",
       "<g id=\"edge254\" class=\"edge\">\n",
       "<title>4690046560&#45;&gt;4694264848*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2875.46,-450.93C2887.74,-458.97 2901.12,-467.73 2912.59,-475.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2910.56,-478.09 2920.84,-480.64 2914.39,-472.23 2910.56,-478.09\"/>\n",
       "</g>\n",
       "<!-- 4694224624 -->\n",
       "<g id=\"node140\" class=\"node\">\n",
       "<title>4694224624</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-1013.5 1725.75,-1062.5 1811.5,-1062.5 1811.5,-1013.5 1725.75,-1013.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-1045.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.352</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-1038 1811.5,-1038\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-1020.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694224720+ -->\n",
       "<g id=\"node145\" class=\"node\">\n",
       "<title>4694224720+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1874.5\" cy=\"-1038\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1874.5\" y=\"-1032.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694224624&#45;&gt;4694224720+ -->\n",
       "<g id=\"edge208\" class=\"edge\">\n",
       "<title>4694224624&#45;&gt;4694224720+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1811.87,-1038C1819.78,-1038 1828,-1038 1835.76,-1038\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1835.57,-1041.5 1845.57,-1038 1835.57,-1034.5 1835.57,-1041.5\"/>\n",
       "</g>\n",
       "<!-- 4694224624*&#45;&gt;4694224624 -->\n",
       "<g id=\"edge53\" class=\"edge\">\n",
       "<title>4694224624*&#45;&gt;4694224624</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1690.23,-1038C1697.59,-1038 1705.85,-1038 1714.16,-1038\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1713.94,-1041.5 1723.94,-1038 1713.94,-1034.5 1713.94,-1041.5\"/>\n",
       "</g>\n",
       "<!-- 4694224672 -->\n",
       "<g id=\"node142\" class=\"node\">\n",
       "<title>4694224672</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-809.5 2150.75,-858.5 2236.5,-858.5 2236.5,-809.5 2150.75,-809.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-841.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.997</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-834 2236.5,-834\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-816.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694224672&#45;&gt;4694262352* -->\n",
       "<g id=\"edge150\" class=\"edge\">\n",
       "<title>4694224672&#45;&gt;4694262352*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2233.26,-858.93C2245.93,-867.11 2259.76,-876.03 2271.54,-883.63\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2269.3,-886.35 2279.6,-888.83 2273.09,-880.47 2269.3,-886.35\"/>\n",
       "</g>\n",
       "<!-- 4694224672&#45;&gt;4694263984* -->\n",
       "<g id=\"edge219\" class=\"edge\">\n",
       "<title>4694224672&#45;&gt;4694263984*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2228.89,-809.18C2232.12,-806.25 2235.23,-803.17 2238,-800 2258.75,-776.32 2257.57,-765.85 2274,-739 2276.93,-734.22 2280.09,-729.16 2283.16,-724.28\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2286.04,-726.28 2288.44,-715.96 2280.13,-722.53 2286.04,-726.28\"/>\n",
       "</g>\n",
       "<!-- 4694224672&#45;&gt;4694226256* -->\n",
       "<g id=\"edge132\" class=\"edge\">\n",
       "<title>4694224672&#45;&gt;4694226256*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2233.26,-809.07C2245.93,-800.89 2259.76,-791.97 2271.54,-784.37\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2273.09,-787.53 2279.6,-779.17 2269.3,-781.65 2273.09,-787.53\"/>\n",
       "</g>\n",
       "<!-- 4694224672&#45;&gt;4694227888* -->\n",
       "<g id=\"edge198\" class=\"edge\">\n",
       "<title>4694224672&#45;&gt;4694227888*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2236.88,-834C2245.19,-834 2253.86,-834 2262.02,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2261.99,-837.5 2271.99,-834 2261.99,-830.5 2261.99,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4694224672tanh -->\n",
       "<g id=\"node143\" class=\"node\">\n",
       "<title>4694224672tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2086.25\" cy=\"-919\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2086.25\" y=\"-913.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694224672tanh&#45;&gt;4694224672 -->\n",
       "<g id=\"edge54\" class=\"edge\">\n",
       "<title>4694224672tanh&#45;&gt;4694224672</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2104,-905.04C2116.43,-894.73 2133.82,-880.39 2149.25,-868 2150.18,-867.25 2151.13,-866.49 2152.08,-865.73\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2153.97,-868.7 2159.63,-859.74 2149.62,-863.22 2153.97,-868.7\"/>\n",
       "</g>\n",
       "<!-- 4694224720 -->\n",
       "<g id=\"node144\" class=\"node\">\n",
       "<title>4694224720</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-979.5 1937.5,-1028.5 2023.25,-1028.5 2023.25,-979.5 1937.5,-979.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-1011.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;3.230</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-1004 2023.25,-1004\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-986.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694224720&#45;&gt;4694224672tanh -->\n",
       "<g id=\"edge221\" class=\"edge\">\n",
       "<title>4694224720&#45;&gt;4694224672tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2011.7,-979.19C2026.83,-966.81 2044.94,-951.99 2059.4,-940.15\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2061.62,-942.86 2067.14,-933.82 2057.18,-937.44 2061.62,-942.86\"/>\n",
       "</g>\n",
       "<!-- 4694224720+&#45;&gt;4694224720 -->\n",
       "<g id=\"edge55\" class=\"edge\">\n",
       "<title>4694224720+&#45;&gt;4694224720</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1899.33,-1030.2C1907.51,-1027.52 1917.03,-1024.41 1926.58,-1021.28\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1927.46,-1024.68 1935.87,-1018.24 1925.28,-1018.02 1927.46,-1024.68\"/>\n",
       "</g>\n",
       "<!-- 4694224912 -->\n",
       "<g id=\"node146\" class=\"node\">\n",
       "<title>4694224912</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-620.5 878.75,-669.5 964.5,-669.5 964.5,-620.5 878.75,-620.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-652.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.062</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-645 964.5,-645\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-627.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225008+ -->\n",
       "<g id=\"node151\" class=\"node\">\n",
       "<title>4694225008+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1027.5\" cy=\"-509\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1027.5\" y=\"-503.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694224912&#45;&gt;4694225008+ -->\n",
       "<g id=\"edge119\" class=\"edge\">\n",
       "<title>4694224912&#45;&gt;4694225008+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M955.64,-620.06C958.78,-617.15 961.79,-614.1 964.5,-611 984.55,-588.03 1002.03,-557.76 1013.28,-536.18\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1016.32,-537.91 1017.74,-527.41 1010.08,-534.74 1016.32,-537.91\"/>\n",
       "</g>\n",
       "<!-- 4694224912*&#45;&gt;4694224912 -->\n",
       "<g id=\"edge56\" class=\"edge\">\n",
       "<title>4694224912*&#45;&gt;4694224912</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M842.96,-648.74C850.32,-648.38 858.59,-647.99 866.93,-647.58\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"866.92,-651.09 876.74,-647.11 866.58,-644.1 866.92,-651.09\"/>\n",
       "</g>\n",
       "<!-- 4694224960 -->\n",
       "<g id=\"node148\" class=\"node\">\n",
       "<title>4694224960</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2793.5,-537.5 2793.5,-586.5 2879.25,-586.5 2879.25,-537.5 2793.5,-537.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-569.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.982</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2793.5,-562 2879.25,-562\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-544.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694224960&#45;&gt;4694264272* -->\n",
       "<g id=\"edge261\" class=\"edge\">\n",
       "<title>4694224960&#45;&gt;4694264272*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2879.62,-581.12C2889.39,-585.54 2899.64,-590.17 2908.91,-594.37\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2907.32,-597.49 2917.87,-598.42 2910.21,-591.11 2907.32,-597.49\"/>\n",
       "</g>\n",
       "<!-- 4694224960tanh -->\n",
       "<g id=\"node149\" class=\"node\">\n",
       "<title>4694224960tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2730.5\" cy=\"-562\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2730.5\" y=\"-556.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694224960tanh&#45;&gt;4694224960 -->\n",
       "<g id=\"edge57\" class=\"edge\">\n",
       "<title>4694224960tanh&#45;&gt;4694224960</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2757.98,-562C2765.34,-562 2773.6,-562 2781.91,-562\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2781.69,-565.5 2791.69,-562 2781.69,-558.5 2781.69,-565.5\"/>\n",
       "</g>\n",
       "<!-- 4694225008 -->\n",
       "<g id=\"node150\" class=\"node\">\n",
       "<title>4694225008</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-484.5 1090.5,-533.5 1176.25,-533.5 1176.25,-484.5 1090.5,-484.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-516.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.944</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-509 1176.25,-509\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-491.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225200+ -->\n",
       "<g id=\"node155\" class=\"node\">\n",
       "<title>4694225200+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1239.25\" cy=\"-494\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1239.25\" y=\"-488.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694225008&#45;&gt;4694225200+ -->\n",
       "<g id=\"edge271\" class=\"edge\">\n",
       "<title>4694225008&#45;&gt;4694225200+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1176.62,-502.9C1184.78,-501.72 1193.26,-500.5 1201.23,-499.35\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1201.54,-502.84 1210.94,-497.94 1200.54,-495.91 1201.54,-502.84\"/>\n",
       "</g>\n",
       "<!-- 4694225008+&#45;&gt;4694225008 -->\n",
       "<g id=\"edge58\" class=\"edge\">\n",
       "<title>4694225008+&#45;&gt;4694225008</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1054.98,-509C1062.34,-509 1070.6,-509 1078.91,-509\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1078.69,-512.5 1088.69,-509 1078.69,-505.5 1078.69,-512.5\"/>\n",
       "</g>\n",
       "<!-- 4694225104 -->\n",
       "<g id=\"node152\" class=\"node\">\n",
       "<title>4694225104</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-416.5 1090.5,-465.5 1176.25,-465.5 1176.25,-416.5 1090.5,-416.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-448.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.633</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-441 1176.25,-441\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-423.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225104&#45;&gt;4694225200+ -->\n",
       "<g id=\"edge186\" class=\"edge\">\n",
       "<title>4694225104&#45;&gt;4694225200+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1176.62,-462.56C1186.75,-467.72 1197.38,-473.14 1206.9,-478.01\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1205.26,-481.1 1215.76,-482.52 1208.44,-474.86 1205.26,-481.1\"/>\n",
       "</g>\n",
       "<!-- 4694225104*&#45;&gt;4694225104 -->\n",
       "<g id=\"edge59\" class=\"edge\">\n",
       "<title>4694225104*&#45;&gt;4694225104</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1054.98,-441C1062.34,-441 1070.6,-441 1078.91,-441\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1078.69,-444.5 1088.69,-441 1078.69,-437.5 1078.69,-444.5\"/>\n",
       "</g>\n",
       "<!-- 4694225200 -->\n",
       "<g id=\"node154\" class=\"node\">\n",
       "<title>4694225200</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-469.5 1302.25,-518.5 1388,-518.5 1388,-469.5 1302.25,-469.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-501.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=2.578</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-494 1388,-494\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-476.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225392+ -->\n",
       "<g id=\"node159\" class=\"node\">\n",
       "<title>4694225392+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1451\" cy=\"-766\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1451\" y=\"-760.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694225200&#45;&gt;4694225392+ -->\n",
       "<g id=\"edge157\" class=\"edge\">\n",
       "<title>4694225200&#45;&gt;4694225392+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1381.18,-518.89C1383.76,-521.73 1386.09,-524.78 1388,-528 1433.36,-604.58 1391.57,-642.11 1424,-725 1426.04,-730.22 1428.78,-735.49 1431.71,-740.44\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1428.69,-742.21 1437.02,-748.75 1434.58,-738.44 1428.69,-742.21\"/>\n",
       "</g>\n",
       "<!-- 4694225200+&#45;&gt;4694225200 -->\n",
       "<g id=\"edge60\" class=\"edge\">\n",
       "<title>4694225200+&#45;&gt;4694225200</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1266.73,-494C1274.09,-494 1282.35,-494 1290.66,-494\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1290.44,-497.5 1300.44,-494 1290.44,-490.5 1290.44,-497.5\"/>\n",
       "</g>\n",
       "<!-- 4694225296 -->\n",
       "<g id=\"node156\" class=\"node\">\n",
       "<title>4694225296</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-741.5 1302.25,-790.5 1388,-790.5 1388,-741.5 1302.25,-741.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-773.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.044</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-766 1388,-766\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-748.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225296&#45;&gt;4694225392+ -->\n",
       "<g id=\"edge260\" class=\"edge\">\n",
       "<title>4694225296&#45;&gt;4694225392+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1388.37,-766C1396.28,-766 1404.5,-766 1412.26,-766\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1412.07,-769.5 1422.07,-766 1412.07,-762.5 1412.07,-769.5\"/>\n",
       "</g>\n",
       "<!-- 4694225296*&#45;&gt;4694225296 -->\n",
       "<g id=\"edge61\" class=\"edge\">\n",
       "<title>4694225296*&#45;&gt;4694225296</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1261.27,-723.73C1270.26,-728.31 1281.19,-733.89 1292.12,-739.46\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1290.26,-742.44 1300.76,-743.87 1293.44,-736.21 1290.26,-742.44\"/>\n",
       "</g>\n",
       "<!-- 4694225392 -->\n",
       "<g id=\"node158\" class=\"node\">\n",
       "<title>4694225392</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-741.5 1514,-790.5 1599.75,-790.5 1599.75,-741.5 1514,-741.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-773.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=2.622</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-766 1599.75,-766\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-748.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225584+ -->\n",
       "<g id=\"node163\" class=\"node\">\n",
       "<title>4694225584+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1662.75\" cy=\"-766\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1662.75\" y=\"-760.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694225392&#45;&gt;4694225584+ -->\n",
       "<g id=\"edge230\" class=\"edge\">\n",
       "<title>4694225392&#45;&gt;4694225584+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1600.12,-766C1608.03,-766 1616.25,-766 1624.01,-766\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1623.82,-769.5 1633.82,-766 1623.82,-762.5 1623.82,-769.5\"/>\n",
       "</g>\n",
       "<!-- 4694225392+&#45;&gt;4694225392 -->\n",
       "<g id=\"edge62\" class=\"edge\">\n",
       "<title>4694225392+&#45;&gt;4694225392</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1478.48,-766C1485.84,-766 1494.1,-766 1502.41,-766\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1502.19,-769.5 1512.19,-766 1502.19,-762.5 1502.19,-769.5\"/>\n",
       "</g>\n",
       "<!-- 4694225488 -->\n",
       "<g id=\"node160\" class=\"node\">\n",
       "<title>4694225488</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-286.5 1514,-335.5 1599.75,-335.5 1599.75,-286.5 1514,-286.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-318.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.666</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-311 1599.75,-311\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-293.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225488&#45;&gt;4694225584+ -->\n",
       "<g id=\"edge151\" class=\"edge\">\n",
       "<title>4694225488&#45;&gt;4694225584+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1573.4,-336C1582.4,-351.57 1593.21,-372.32 1599.75,-392 1621.17,-456.48 1648.36,-660.2 1658.09,-736.64\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1654.58,-736.79 1659.31,-746.27 1661.52,-735.91 1654.58,-736.79\"/>\n",
       "</g>\n",
       "<!-- 4694225488*&#45;&gt;4694225488 -->\n",
       "<g id=\"edge63\" class=\"edge\">\n",
       "<title>4694225488*&#45;&gt;4694225488</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1471.54,-260.66C1480.9,-266.25 1492.61,-273.24 1504.29,-280.21\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1502.37,-283.14 1512.75,-285.26 1505.96,-277.13 1502.37,-283.14\"/>\n",
       "</g>\n",
       "<!-- 4694225584 -->\n",
       "<g id=\"node162\" class=\"node\">\n",
       "<title>4694225584</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-741.5 1725.75,-790.5 1811.5,-790.5 1811.5,-741.5 1725.75,-741.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-773.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.956</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-766 1811.5,-766\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-748.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225776+ -->\n",
       "<g id=\"node167\" class=\"node\">\n",
       "<title>4694225776+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1874.5\" cy=\"-766\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1874.5\" y=\"-760.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694225584&#45;&gt;4694225776+ -->\n",
       "<g id=\"edge125\" class=\"edge\">\n",
       "<title>4694225584&#45;&gt;4694225776+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1811.87,-766C1819.78,-766 1828,-766 1835.76,-766\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1835.57,-769.5 1845.57,-766 1835.57,-762.5 1835.57,-769.5\"/>\n",
       "</g>\n",
       "<!-- 4694225584+&#45;&gt;4694225584 -->\n",
       "<g id=\"edge64\" class=\"edge\">\n",
       "<title>4694225584+&#45;&gt;4694225584</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1690.23,-766C1697.59,-766 1705.85,-766 1714.16,-766\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1713.94,-769.5 1723.94,-766 1713.94,-762.5 1713.94,-769.5\"/>\n",
       "</g>\n",
       "<!-- 4694225680 -->\n",
       "<g id=\"node164\" class=\"node\">\n",
       "<title>4694225680</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-1081.5 1725.75,-1130.5 1811.5,-1130.5 1811.5,-1081.5 1725.75,-1081.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-1113.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.469</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-1106 1811.5,-1106\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-1088.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225680&#45;&gt;4694225776+ -->\n",
       "<g id=\"edge175\" class=\"edge\">\n",
       "<title>4694225680&#45;&gt;4694225776+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1804.83,-1081.21C1807.38,-1078.34 1809.67,-1075.27 1811.5,-1072 1869.72,-968.38 1806.73,-918.65 1847.5,-807 1849.42,-801.73 1852.1,-796.44 1855.01,-791.48\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1857.88,-793.49 1860.33,-783.18 1851.99,-789.71 1857.88,-793.49\"/>\n",
       "</g>\n",
       "<!-- 4694225680*&#45;&gt;4694225680 -->\n",
       "<g id=\"edge65\" class=\"edge\">\n",
       "<title>4694225680*&#45;&gt;4694225680</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1687.06,-1135.47C1695.41,-1132.42 1705.19,-1128.84 1715,-1125.25\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1715.99,-1128.62 1724.17,-1121.9 1713.58,-1122.04 1715.99,-1128.62\"/>\n",
       "</g>\n",
       "<!-- 4694225776 -->\n",
       "<g id=\"node166\" class=\"node\">\n",
       "<title>4694225776</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-741.5 1937.5,-790.5 2023.25,-790.5 2023.25,-741.5 1937.5,-741.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-773.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=2.426</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-766 2023.25,-766\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-748.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225968+ -->\n",
       "<g id=\"node171\" class=\"node\">\n",
       "<title>4694225968+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2086.25\" cy=\"-494\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2086.25\" y=\"-488.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694225776&#45;&gt;4694225968+ -->\n",
       "<g id=\"edge148\" class=\"edge\">\n",
       "<title>4694225776&#45;&gt;4694225968+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2016.43,-741.11C2019.01,-738.27 2021.34,-735.22 2023.25,-732 2068.61,-655.42 2026.82,-617.89 2059.25,-535 2061.29,-529.78 2064.03,-524.51 2066.96,-519.56\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2069.83,-521.56 2072.27,-511.25 2063.94,-517.79 2069.83,-521.56\"/>\n",
       "</g>\n",
       "<!-- 4694225776+&#45;&gt;4694225776 -->\n",
       "<g id=\"edge66\" class=\"edge\">\n",
       "<title>4694225776+&#45;&gt;4694225776</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1901.98,-766C1909.34,-766 1917.6,-766 1925.91,-766\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1925.69,-769.5 1935.69,-766 1925.69,-762.5 1925.69,-769.5\"/>\n",
       "</g>\n",
       "<!-- 4694225872 -->\n",
       "<g id=\"node168\" class=\"node\">\n",
       "<title>4694225872</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-401.5 1937.5,-450.5 2023.25,-450.5 2023.25,-401.5 1937.5,-401.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-433.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.220</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-426 2023.25,-426\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-408.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694225872&#45;&gt;4694225968+ -->\n",
       "<g id=\"edge161\" class=\"edge\">\n",
       "<title>4694225872&#45;&gt;4694225968+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2019.46,-450.93C2031.74,-458.97 2045.12,-467.73 2056.59,-475.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2054.56,-478.09 2064.84,-480.64 2058.39,-472.23 2054.56,-478.09\"/>\n",
       "</g>\n",
       "<!-- 4694225872*&#45;&gt;4694225872 -->\n",
       "<g id=\"edge67\" class=\"edge\">\n",
       "<title>4694225872*&#45;&gt;4694225872</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1901.98,-426C1909.34,-426 1917.6,-426 1925.91,-426\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1925.69,-429.5 1935.69,-426 1925.69,-422.5 1925.69,-429.5\"/>\n",
       "</g>\n",
       "<!-- 4694225968 -->\n",
       "<g id=\"node170\" class=\"node\">\n",
       "<title>4694225968</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-469.5 2150.75,-518.5 2236.5,-518.5 2236.5,-469.5 2150.75,-469.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-501.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=2.646</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-494 2236.5,-494\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-476.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226160+ -->\n",
       "<g id=\"node177\" class=\"node\">\n",
       "<title>4694226160+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2301\" cy=\"-494\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2301\" y=\"-488.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694225968&#45;&gt;4694226160+ -->\n",
       "<g id=\"edge177\" class=\"edge\">\n",
       "<title>4694225968&#45;&gt;4694226160+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2236.88,-494C2245.19,-494 2253.86,-494 2262.02,-494\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2261.99,-497.5 2271.99,-494 2261.99,-490.5 2261.99,-497.5\"/>\n",
       "</g>\n",
       "<!-- 4694225968+&#45;&gt;4694225968 -->\n",
       "<g id=\"edge68\" class=\"edge\">\n",
       "<title>4694225968+&#45;&gt;4694225968</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2113.57,-494C2121.28,-494 2130.01,-494 2138.79,-494\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2138.75,-497.5 2148.75,-494 2138.75,-490.5 2138.75,-497.5\"/>\n",
       "</g>\n",
       "<!-- 4690039888 -->\n",
       "<g id=\"node172\" class=\"node\">\n",
       "<title>4690039888</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"0,-1081.5 0,-1130.5 85.75,-1130.5 85.75,-1081.5 0,-1081.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"42.88\" y=\"-1113.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.529</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"0,-1106 85.75,-1106\"/>\n",
       "<text text-anchor=\"middle\" x=\"42.88\" y=\"-1088.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690039888&#45;&gt;4694219632* -->\n",
       "<g id=\"edge107\" class=\"edge\">\n",
       "<title>4690039888&#45;&gt;4694219632*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M86.12,-1106C94.03,-1106 102.25,-1106 110.01,-1106\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"109.82,-1109.5 119.82,-1106 109.82,-1102.5 109.82,-1109.5\"/>\n",
       "</g>\n",
       "<!-- 4690039936 -->\n",
       "<g id=\"node173\" class=\"node\">\n",
       "<title>4690039936</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"211.75,-968.5 211.75,-1017.5 297.5,-1017.5 297.5,-968.5 211.75,-968.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-1000.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;5.348</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"211.75,-993 297.5,-993\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-975.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690039936&#45;&gt;4694213056+ -->\n",
       "<g id=\"edge137\" class=\"edge\">\n",
       "<title>4690039936&#45;&gt;4694213056+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M297.84,-993C310.94,-993 325.27,-993 338.01,-993\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"337.67,-996.5 347.67,-993 337.67,-989.5 337.67,-996.5\"/>\n",
       "</g>\n",
       "<!-- 4694226064 -->\n",
       "<g id=\"node174\" class=\"node\">\n",
       "<title>4694226064</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-197.5 2150.75,-246.5 2236.5,-246.5 2236.5,-197.5 2150.75,-197.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-229.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.032</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-222 2236.5,-222\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-204.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226064&#45;&gt;4694226160+ -->\n",
       "<g id=\"edge191\" class=\"edge\">\n",
       "<title>4694226064&#45;&gt;4694226160+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2230.67,-246.93C2233.4,-249.77 2235.9,-252.8 2238,-256 2243.83,-264.89 2278.11,-404 2293.05,-465.33\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2289.56,-465.8 2295.33,-474.69 2296.37,-464.15 2289.56,-465.8\"/>\n",
       "</g>\n",
       "<!-- 4694226064*&#45;&gt;4694226064 -->\n",
       "<g id=\"edge69\" class=\"edge\">\n",
       "<title>4694226064*&#45;&gt;4694226064</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2113.57,-222C2121.28,-222 2130.01,-222 2138.79,-222\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2138.75,-225.5 2148.75,-222 2138.75,-218.5 2138.75,-225.5\"/>\n",
       "</g>\n",
       "<!-- 4694226160 -->\n",
       "<g id=\"node176\" class=\"node\">\n",
       "<title>4694226160</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2365.5,-469.5 2365.5,-518.5 2451.25,-518.5 2451.25,-469.5 2365.5,-469.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-501.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=2.614</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2365.5,-494 2451.25,-494\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-476.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226352+ -->\n",
       "<g id=\"node183\" class=\"node\">\n",
       "<title>4694226352+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2515.75\" cy=\"-562\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2515.75\" y=\"-556.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694226160&#45;&gt;4694226352+ -->\n",
       "<g id=\"edge251\" class=\"edge\">\n",
       "<title>4694226160&#45;&gt;4694226352+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2448.01,-518.93C2460.68,-527.11 2474.51,-536.03 2486.29,-543.63\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2484.05,-546.35 2494.35,-548.83 2487.84,-540.47 2484.05,-546.35\"/>\n",
       "</g>\n",
       "<!-- 4694226160+&#45;&gt;4694226160 -->\n",
       "<g id=\"edge70\" class=\"edge\">\n",
       "<title>4694226160+&#45;&gt;4694226160</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2328.32,-494C2336.03,-494 2344.76,-494 2353.54,-494\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2353.5,-497.5 2363.5,-494 2353.5,-490.5 2353.5,-497.5\"/>\n",
       "</g>\n",
       "<!-- 4694226256 -->\n",
       "<g id=\"node178\" class=\"node\">\n",
       "<title>4694226256</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2365.5,-741.5 2365.5,-790.5 2451.25,-790.5 2451.25,-741.5 2365.5,-741.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-773.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.264</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2365.5,-766 2451.25,-766\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-748.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226256&#45;&gt;4694226352+ -->\n",
       "<g id=\"edge265\" class=\"edge\">\n",
       "<title>4694226256&#45;&gt;4694226352+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2444.68,-741.26C2447.64,-738.35 2450.39,-735.25 2452.75,-732 2484.33,-688.49 2501.4,-627.17 2509.24,-591.3\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2512.64,-592.16 2511.25,-581.66 2505.78,-590.74 2512.64,-592.16\"/>\n",
       "</g>\n",
       "<!-- 4694226256*&#45;&gt;4694226256 -->\n",
       "<g id=\"edge71\" class=\"edge\">\n",
       "<title>4694226256*&#45;&gt;4694226256</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2328.32,-766C2336.03,-766 2344.76,-766 2353.54,-766\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2353.5,-769.5 2363.5,-766 2353.5,-762.5 2353.5,-769.5\"/>\n",
       "</g>\n",
       "<!-- 4690040176 -->\n",
       "<g id=\"node180\" class=\"node\">\n",
       "<title>4690040176</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"211.75,-598.5 211.75,-647.5 297.5,-647.5 297.5,-598.5 211.75,-598.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-630.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.350</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"211.75,-623 297.5,-623\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-605.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690040176&#45;&gt;4694221552* -->\n",
       "<g id=\"edge272\" class=\"edge\">\n",
       "<title>4690040176&#45;&gt;4694221552*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M297.84,-626.88C310.94,-628.08 325.27,-629.4 338.01,-630.57\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"337.4,-634.03 347.68,-631.46 338.04,-627.06 337.4,-634.03\"/>\n",
       "</g>\n",
       "<!-- 4690040224 -->\n",
       "<g id=\"node181\" class=\"node\">\n",
       "<title>4690040224</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"455.25,-541.5 455.25,-590.5 541,-590.5 541,-541.5 455.25,-541.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-573.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.676</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"455.25,-566 541,-566\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-548.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690040224&#45;&gt;4694222992+ -->\n",
       "<g id=\"edge273\" class=\"edge\">\n",
       "<title>4690040224&#45;&gt;4694222992+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M541.37,-570.47C549.36,-571.32 557.66,-572.2 565.48,-573.03\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"565.07,-576.5 575.38,-574.08 565.81,-569.54 565.07,-576.5\"/>\n",
       "</g>\n",
       "<!-- 4694226352 -->\n",
       "<g id=\"node182\" class=\"node\">\n",
       "<title>4694226352</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2580.25,-537.5 2580.25,-586.5 2666,-586.5 2666,-537.5 2580.25,-537.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2623.12\" y=\"-569.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=2.350</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2580.25,-562 2666,-562\"/>\n",
       "<text text-anchor=\"middle\" x=\"2623.12\" y=\"-544.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226352&#45;&gt;4694224960tanh -->\n",
       "<g id=\"edge211\" class=\"edge\">\n",
       "<title>4694226352&#45;&gt;4694224960tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2666.38,-562C2674.69,-562 2683.36,-562 2691.52,-562\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2691.49,-565.5 2701.49,-562 2691.49,-558.5 2691.49,-565.5\"/>\n",
       "</g>\n",
       "<!-- 4694226352+&#45;&gt;4694226352 -->\n",
       "<g id=\"edge72\" class=\"edge\">\n",
       "<title>4694226352+&#45;&gt;4694226352</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2543.07,-562C2550.78,-562 2559.51,-562 2568.29,-562\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2568.25,-565.5 2578.25,-562 2568.25,-558.5 2568.25,-565.5\"/>\n",
       "</g>\n",
       "<!-- 4694226544 -->\n",
       "<g id=\"node184\" class=\"node\">\n",
       "<title>4694226544</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-892.5 878.75,-941.5 964.5,-941.5 964.5,-892.5 878.75,-892.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-924.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.149</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-917 964.5,-917\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-899.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226544&#45;&gt;4694226640+ -->\n",
       "<g id=\"edge218\" class=\"edge\">\n",
       "<title>4694226544&#45;&gt;4694226640+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M960.71,-941.93C972.99,-949.97 986.37,-958.73 997.84,-966.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"995.81,-969.09 1006.09,-971.64 999.64,-963.23 995.81,-969.09\"/>\n",
       "</g>\n",
       "<!-- 4694226544*&#45;&gt;4694226544 -->\n",
       "<g id=\"edge73\" class=\"edge\">\n",
       "<title>4694226544*&#45;&gt;4694226544</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M843.23,-917C850.59,-917 858.85,-917 867.16,-917\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"866.94,-920.5 876.94,-917 866.94,-913.5 866.94,-920.5\"/>\n",
       "</g>\n",
       "<!-- 4690040464 -->\n",
       "<g id=\"node186\" class=\"node\">\n",
       "<title>4690040464</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"455.25,-742.5 455.25,-791.5 541,-791.5 541,-742.5 455.25,-742.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-774.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.346</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"455.25,-767 541,-767\"/>\n",
       "<text text-anchor=\"middle\" x=\"498.12\" y=\"-749.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690040464&#45;&gt;4694223184* -->\n",
       "<g id=\"edge240\" class=\"edge\">\n",
       "<title>4690040464&#45;&gt;4694223184*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M541.37,-749.51C550.88,-745.58 560.83,-741.46 569.9,-737.7\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"571.13,-740.98 579.03,-733.92 568.45,-734.51 571.13,-740.98\"/>\n",
       "</g>\n",
       "<!-- 4694226592 -->\n",
       "<g id=\"node187\" class=\"node\">\n",
       "<title>4694226592</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2793.5,-673.5 2793.5,-722.5 2879.25,-722.5 2879.25,-673.5 2793.5,-673.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-705.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.990</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2793.5,-698 2879.25,-698\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-680.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226592&#45;&gt;4694264464* -->\n",
       "<g id=\"edge252\" class=\"edge\">\n",
       "<title>4694226592&#45;&gt;4694264464*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2879.62,-712.64C2888.79,-715.82 2898.37,-719.14 2907.17,-722.19\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2905.78,-725.41 2916.38,-725.38 2908.08,-718.8 2905.78,-725.41\"/>\n",
       "</g>\n",
       "<!-- 4694226592tanh -->\n",
       "<g id=\"node188\" class=\"node\">\n",
       "<title>4694226592tanh</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2730.5\" cy=\"-698\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2730.5\" y=\"-692.95\" font-family=\"Times,serif\" font-size=\"14.00\">tanh</text>\n",
       "</g>\n",
       "<!-- 4694226592tanh&#45;&gt;4694226592 -->\n",
       "<g id=\"edge74\" class=\"edge\">\n",
       "<title>4694226592tanh&#45;&gt;4694226592</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2757.98,-698C2765.34,-698 2773.6,-698 2781.91,-698\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2781.69,-701.5 2791.69,-698 2781.69,-694.5 2781.69,-701.5\"/>\n",
       "</g>\n",
       "<!-- 4690040512 -->\n",
       "<g id=\"node189\" class=\"node\">\n",
       "<title>4690040512</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"667,-767.5 667,-816.5 752.75,-816.5 752.75,-767.5 667,-767.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-799.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;4.562</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"667,-792 752.75,-792\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-774.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690040512&#45;&gt;4694223280+ -->\n",
       "<g id=\"edge179\" class=\"edge\">\n",
       "<title>4690040512&#45;&gt;4694223280+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M753.12,-787.53C761.11,-786.68 769.41,-785.8 777.23,-784.97\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"777.56,-788.46 787.13,-783.92 776.82,-781.5 777.56,-788.46\"/>\n",
       "</g>\n",
       "<!-- 4694226640 -->\n",
       "<g id=\"node190\" class=\"node\">\n",
       "<title>4694226640</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-960.5 1090.5,-1009.5 1176.25,-1009.5 1176.25,-960.5 1090.5,-960.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-992.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.781</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-985 1176.25,-985\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-967.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226832+ -->\n",
       "<g id=\"node195\" class=\"node\">\n",
       "<title>4694226832+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1239.25\" cy=\"-902\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1239.25\" y=\"-896.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694226640&#45;&gt;4694226832+ -->\n",
       "<g id=\"edge274\" class=\"edge\">\n",
       "<title>4694226640&#45;&gt;4694226832+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1165.54,-960.1C1180.44,-948.19 1198.08,-934.1 1212.25,-922.78\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1214.19,-925.71 1219.81,-916.73 1209.82,-920.24 1214.19,-925.71\"/>\n",
       "</g>\n",
       "<!-- 4694226640+&#45;&gt;4694226640 -->\n",
       "<g id=\"edge75\" class=\"edge\">\n",
       "<title>4694226640+&#45;&gt;4694226640</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1054.98,-985C1062.34,-985 1070.6,-985 1078.91,-985\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1078.69,-988.5 1088.69,-985 1078.69,-981.5 1078.69,-988.5\"/>\n",
       "</g>\n",
       "<!-- 4694226736 -->\n",
       "<g id=\"node192\" class=\"node\">\n",
       "<title>4694226736</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-824.5 1090.5,-873.5 1176.25,-873.5 1176.25,-824.5 1090.5,-824.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-856.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.805</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-849 1176.25,-849\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-831.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226736&#45;&gt;4694226832+ -->\n",
       "<g id=\"edge113\" class=\"edge\">\n",
       "<title>4694226736&#45;&gt;4694226832+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1176.62,-870.56C1186.75,-875.72 1197.38,-881.14 1206.9,-886.01\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1205.26,-889.1 1215.76,-890.52 1208.44,-882.86 1205.26,-889.1\"/>\n",
       "</g>\n",
       "<!-- 4694226736*&#45;&gt;4694226736 -->\n",
       "<g id=\"edge76\" class=\"edge\">\n",
       "<title>4694226736*&#45;&gt;4694226736</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1041.5,-728.86C1045.84,-734.45 1050.57,-740.87 1054.5,-747 1072.95,-775.79 1068.79,-788.58 1090.5,-815 1090.75,-815.3 1090.99,-815.6 1091.24,-815.89\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1088.69,-818.29 1098.12,-823.12 1093.77,-813.46 1088.69,-818.29\"/>\n",
       "</g>\n",
       "<!-- 4694226832 -->\n",
       "<g id=\"node194\" class=\"node\">\n",
       "<title>4694226832</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-877.5 1302.25,-926.5 1388,-926.5 1388,-877.5 1302.25,-877.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-909.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=2.586</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-902 1388,-902\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-884.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227024+ -->\n",
       "<g id=\"node201\" class=\"node\">\n",
       "<title>4694227024+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1451\" cy=\"-834\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1451\" y=\"-828.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694226832&#45;&gt;4694227024+ -->\n",
       "<g id=\"edge159\" class=\"edge\">\n",
       "<title>4694226832&#45;&gt;4694227024+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1384.21,-877.07C1396.49,-869.03 1409.87,-860.27 1421.34,-852.76\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1423.14,-855.77 1429.59,-847.36 1419.31,-849.91 1423.14,-855.77\"/>\n",
       "</g>\n",
       "<!-- 4694226832+&#45;&gt;4694226832 -->\n",
       "<g id=\"edge77\" class=\"edge\">\n",
       "<title>4694226832+&#45;&gt;4694226832</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1266.73,-902C1274.09,-902 1282.35,-902 1290.66,-902\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1290.44,-905.5 1300.44,-902 1290.44,-898.5 1290.44,-905.5\"/>\n",
       "</g>\n",
       "<!-- 4690040752 -->\n",
       "<g id=\"node196\" class=\"node\">\n",
       "<title>4690040752</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"0,-121.5 0,-170.5 85.75,-170.5 85.75,-121.5 0,-121.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"42.88\" y=\"-153.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.720</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"0,-146 85.75,-146\"/>\n",
       "<text text-anchor=\"middle\" x=\"42.88\" y=\"-128.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690040752&#45;&gt;4694223472* -->\n",
       "<g id=\"edge146\" class=\"edge\">\n",
       "<title>4690040752&#45;&gt;4694223472*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M86.12,-146C94.03,-146 102.25,-146 110.01,-146\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"109.82,-149.5 119.82,-146 109.82,-142.5 109.82,-149.5\"/>\n",
       "</g>\n",
       "<!-- 4690040800 -->\n",
       "<g id=\"node197\" class=\"node\">\n",
       "<title>4690040800</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-280.5 878.75,-329.5 964.5,-329.5 964.5,-280.5 878.75,-280.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-312.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;2.341</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-305 964.5,-305\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-287.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690040800&#45;&gt;4694223568+ -->\n",
       "<g id=\"edge174\" class=\"edge\">\n",
       "<title>4690040800&#45;&gt;4694223568+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M955.61,-280.03C958.75,-277.13 961.78,-274.09 964.5,-271 984.25,-248.57 1001.67,-219.12 1012.98,-198\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1015.93,-199.91 1017.47,-189.42 1009.73,-196.66 1015.93,-199.91\"/>\n",
       "</g>\n",
       "<!-- 4694226928 -->\n",
       "<g id=\"node198\" class=\"node\">\n",
       "<title>4694226928</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-809.5 1302.25,-858.5 1388,-858.5 1388,-809.5 1302.25,-809.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-841.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.082</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-834 1388,-834\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-816.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694226928&#45;&gt;4694227024+ -->\n",
       "<g id=\"edge142\" class=\"edge\">\n",
       "<title>4694226928&#45;&gt;4694227024+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1388.37,-834C1396.28,-834 1404.5,-834 1412.26,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1412.07,-837.5 1422.07,-834 1412.07,-830.5 1412.07,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4694226928*&#45;&gt;4694226928 -->\n",
       "<g id=\"edge78\" class=\"edge\">\n",
       "<title>4694226928*&#45;&gt;4694226928</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1261.27,-791.73C1270.26,-796.31 1281.19,-801.89 1292.12,-807.46\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1290.26,-810.44 1300.76,-811.87 1293.44,-804.21 1290.26,-810.44\"/>\n",
       "</g>\n",
       "<!-- 4694227024 -->\n",
       "<g id=\"node200\" class=\"node\">\n",
       "<title>4694227024</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-809.5 1514,-858.5 1599.75,-858.5 1599.75,-809.5 1514,-809.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-841.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.504</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-834 1599.75,-834\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-816.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227216+ -->\n",
       "<g id=\"node207\" class=\"node\">\n",
       "<title>4694227216+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1662.75\" cy=\"-834\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1662.75\" y=\"-828.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694227024&#45;&gt;4694227216+ -->\n",
       "<g id=\"edge232\" class=\"edge\">\n",
       "<title>4694227024&#45;&gt;4694227216+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1600.12,-834C1608.03,-834 1616.25,-834 1624.01,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1623.82,-837.5 1633.82,-834 1623.82,-830.5 1623.82,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4694227024+&#45;&gt;4694227024 -->\n",
       "<g id=\"edge79\" class=\"edge\">\n",
       "<title>4694227024+&#45;&gt;4694227024</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1478.48,-834C1485.84,-834 1494.1,-834 1502.41,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1502.19,-837.5 1512.19,-834 1502.19,-830.5 1502.19,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4694227120 -->\n",
       "<g id=\"node202\" class=\"node\">\n",
       "<title>4694227120</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-605.5 1514,-654.5 1599.75,-654.5 1599.75,-605.5 1514,-605.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-637.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.835</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-630 1599.75,-630\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-612.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227120&#45;&gt;4694227216+ -->\n",
       "<g id=\"edge212\" class=\"edge\">\n",
       "<title>4694227120&#45;&gt;4694227216+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1592.22,-654.66C1595.02,-657.59 1597.59,-660.71 1599.75,-664 1632.39,-713.77 1611.55,-738.62 1635.75,-793 1638.03,-798.12 1640.88,-803.35 1643.85,-808.28\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1640.82,-810.04 1649.15,-816.59 1646.72,-806.28 1640.82,-810.04\"/>\n",
       "</g>\n",
       "<!-- 4694227120*&#45;&gt;4694227120 -->\n",
       "<g id=\"edge80\" class=\"edge\">\n",
       "<title>4694227120*&#45;&gt;4694227120</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1478.48,-630C1485.84,-630 1494.1,-630 1502.41,-630\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1502.19,-633.5 1512.19,-630 1502.19,-626.5 1502.19,-633.5\"/>\n",
       "</g>\n",
       "<!-- 4690041040 -->\n",
       "<g id=\"node204\" class=\"node\">\n",
       "<title>4690041040</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"0,-1186.5 0,-1235.5 85.75,-1235.5 85.75,-1186.5 0,-1186.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"42.88\" y=\"-1218.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.909</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"0,-1211 85.75,-1211\"/>\n",
       "<text text-anchor=\"middle\" x=\"42.88\" y=\"-1193.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690041040&#45;&gt;4694223760* -->\n",
       "<g id=\"edge288\" class=\"edge\">\n",
       "<title>4690041040&#45;&gt;4694223760*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M86.12,-1211C94.03,-1211 102.25,-1211 110.01,-1211\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"109.82,-1214.5 119.82,-1211 109.82,-1207.5 109.82,-1214.5\"/>\n",
       "</g>\n",
       "<!-- 4690041088 -->\n",
       "<g id=\"node205\" class=\"node\">\n",
       "<title>4690041088</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"211.75,-1153.5 211.75,-1202.5 297.5,-1202.5 297.5,-1153.5 211.75,-1153.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-1185.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;7.498</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"211.75,-1178 297.5,-1178\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-1160.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690041088&#45;&gt;4694223856+ -->\n",
       "<g id=\"edge215\" class=\"edge\">\n",
       "<title>4690041088&#45;&gt;4694223856+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M297.84,-1189.99C311.59,-1193.89 326.71,-1198.18 339.91,-1201.93\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"338.91,-1205.28 349.48,-1204.65 340.82,-1198.55 338.91,-1205.28\"/>\n",
       "</g>\n",
       "<!-- 4694227216 -->\n",
       "<g id=\"node206\" class=\"node\">\n",
       "<title>4694227216</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-809.5 1725.75,-858.5 1811.5,-858.5 1811.5,-809.5 1725.75,-809.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-841.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.669</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-834 1811.5,-834\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-816.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227408+ -->\n",
       "<g id=\"node211\" class=\"node\">\n",
       "<title>4694227408+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1874.5\" cy=\"-834\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1874.5\" y=\"-828.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694227216&#45;&gt;4694227408+ -->\n",
       "<g id=\"edge134\" class=\"edge\">\n",
       "<title>4694227216&#45;&gt;4694227408+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1811.87,-834C1819.78,-834 1828,-834 1835.76,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1835.57,-837.5 1845.57,-834 1835.57,-830.5 1835.57,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4694227216+&#45;&gt;4694227216 -->\n",
       "<g id=\"edge81\" class=\"edge\">\n",
       "<title>4694227216+&#45;&gt;4694227216</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1690.23,-834C1697.59,-834 1705.85,-834 1714.16,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1713.94,-837.5 1723.94,-834 1713.94,-830.5 1713.94,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4694227312 -->\n",
       "<g id=\"node208\" class=\"node\">\n",
       "<title>4694227312</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-1149.5 1725.75,-1198.5 1811.5,-1198.5 1811.5,-1149.5 1725.75,-1149.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-1181.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.402</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-1174 1811.5,-1174\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-1156.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227312&#45;&gt;4694227408+ -->\n",
       "<g id=\"edge183\" class=\"edge\">\n",
       "<title>4694227312&#45;&gt;4694227408+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1804.83,-1149.21C1807.38,-1146.34 1809.67,-1143.27 1811.5,-1140 1869.72,-1036.38 1806.73,-986.65 1847.5,-875 1849.42,-869.73 1852.1,-864.44 1855.01,-859.48\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1857.88,-861.49 1860.33,-851.18 1851.99,-857.71 1857.88,-861.49\"/>\n",
       "</g>\n",
       "<!-- 4694227312*&#45;&gt;4694227312 -->\n",
       "<g id=\"edge82\" class=\"edge\">\n",
       "<title>4694227312*&#45;&gt;4694227312</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1687.84,-1197.81C1695.85,-1195.42 1705.12,-1192.65 1714.44,-1189.87\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1715.31,-1193.27 1723.89,-1187.05 1713.3,-1186.56 1715.31,-1193.27\"/>\n",
       "</g>\n",
       "<!-- 4694227408 -->\n",
       "<g id=\"node210\" class=\"node\">\n",
       "<title>4694227408</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-809.5 1937.5,-858.5 2023.25,-858.5 2023.25,-809.5 1937.5,-809.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-841.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=0.267</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-834 2023.25,-834\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-816.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227600+ -->\n",
       "<g id=\"node217\" class=\"node\">\n",
       "<title>4694227600+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2086.25\" cy=\"-562\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2086.25\" y=\"-556.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694227408&#45;&gt;4694227600+ -->\n",
       "<g id=\"edge214\" class=\"edge\">\n",
       "<title>4694227408&#45;&gt;4694227600+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2016.43,-809.11C2019.01,-806.27 2021.34,-803.22 2023.25,-800 2068.61,-723.42 2026.82,-685.89 2059.25,-603 2061.29,-597.78 2064.03,-592.51 2066.96,-587.56\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2069.83,-589.56 2072.27,-579.25 2063.94,-585.79 2069.83,-589.56\"/>\n",
       "</g>\n",
       "<!-- 4694227408+&#45;&gt;4694227408 -->\n",
       "<g id=\"edge83\" class=\"edge\">\n",
       "<title>4694227408+&#45;&gt;4694227408</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1901.98,-834C1909.34,-834 1917.6,-834 1925.91,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1925.69,-837.5 1935.69,-834 1925.69,-830.5 1925.69,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4690041328 -->\n",
       "<g id=\"node212\" class=\"node\">\n",
       "<title>4690041328</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-214.5 1090.5,-263.5 1176.25,-263.5 1176.25,-214.5 1090.5,-214.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-246.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.748</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-239 1176.25,-239\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-221.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690041328&#45;&gt;4694224048* -->\n",
       "<g id=\"edge227\" class=\"edge\">\n",
       "<title>4690041328&#45;&gt;4694224048*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1163.42,-263.97C1167.95,-268.44 1172.39,-273.2 1176.25,-278 1195.97,-302.54 1193.2,-313.94 1212.25,-339 1213.26,-340.33 1214.33,-341.66 1215.43,-342.98\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1212.72,-345.2 1222.01,-350.3 1217.92,-340.52 1212.72,-345.2\"/>\n",
       "</g>\n",
       "<!-- 4690041376 -->\n",
       "<g id=\"node213\" class=\"node\">\n",
       "<title>4690041376</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-265.5 1302.25,-314.5 1388,-314.5 1388,-265.5 1302.25,-265.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-297.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;6.339</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-290 1388,-290\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-272.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690041376&#45;&gt;4694224144+ -->\n",
       "<g id=\"edge129\" class=\"edge\">\n",
       "<title>4690041376&#45;&gt;4694224144+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1379.14,-314.94C1382.28,-317.85 1385.29,-320.9 1388,-324 1408.05,-346.97 1425.53,-377.24 1436.78,-398.82\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1433.58,-400.26 1441.24,-407.59 1439.82,-397.09 1433.58,-400.26\"/>\n",
       "</g>\n",
       "<!-- 4694227504 -->\n",
       "<g id=\"node214\" class=\"node\">\n",
       "<title>4694227504</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1937.5,-469.5 1937.5,-518.5 2023.25,-518.5 2023.25,-469.5 1937.5,-469.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-501.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.943</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1937.5,-494 2023.25,-494\"/>\n",
       "<text text-anchor=\"middle\" x=\"1980.38\" y=\"-476.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227504&#45;&gt;4694227600+ -->\n",
       "<g id=\"edge166\" class=\"edge\">\n",
       "<title>4694227504&#45;&gt;4694227600+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2019.46,-518.93C2031.74,-526.97 2045.12,-535.73 2056.59,-543.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2054.56,-546.09 2064.84,-548.64 2058.39,-540.23 2054.56,-546.09\"/>\n",
       "</g>\n",
       "<!-- 4694227504*&#45;&gt;4694227504 -->\n",
       "<g id=\"edge84\" class=\"edge\">\n",
       "<title>4694227504*&#45;&gt;4694227504</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1901.98,-494C1909.34,-494 1917.6,-494 1925.91,-494\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1925.69,-497.5 1935.69,-494 1925.69,-490.5 1925.69,-497.5\"/>\n",
       "</g>\n",
       "<!-- 4694227600 -->\n",
       "<g id=\"node216\" class=\"node\">\n",
       "<title>4694227600</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-537.5 2150.75,-586.5 2236.5,-586.5 2236.5,-537.5 2150.75,-537.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-569.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.675</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-562 2236.5,-562\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-544.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227792+ -->\n",
       "<g id=\"node223\" class=\"node\">\n",
       "<title>4694227792+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2301\" cy=\"-562\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2301\" y=\"-556.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694227600&#45;&gt;4694227792+ -->\n",
       "<g id=\"edge103\" class=\"edge\">\n",
       "<title>4694227600&#45;&gt;4694227792+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2236.88,-562C2245.19,-562 2253.86,-562 2262.02,-562\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2261.99,-565.5 2271.99,-562 2261.99,-558.5 2261.99,-565.5\"/>\n",
       "</g>\n",
       "<!-- 4694227600+&#45;&gt;4694227600 -->\n",
       "<g id=\"edge85\" class=\"edge\">\n",
       "<title>4694227600+&#45;&gt;4694227600</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2113.57,-562C2121.28,-562 2130.01,-562 2138.79,-562\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2138.75,-565.5 2148.75,-562 2138.75,-558.5 2138.75,-565.5\"/>\n",
       "</g>\n",
       "<!-- 4694227696 -->\n",
       "<g id=\"node218\" class=\"node\">\n",
       "<title>4694227696</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2150.75,-265.5 2150.75,-314.5 2236.5,-314.5 2236.5,-265.5 2150.75,-265.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-297.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.872</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2150.75,-290 2236.5,-290\"/>\n",
       "<text text-anchor=\"middle\" x=\"2193.62\" y=\"-272.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227696&#45;&gt;4694227792+ -->\n",
       "<g id=\"edge239\" class=\"edge\">\n",
       "<title>4694227696&#45;&gt;4694227792+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2230.93,-314.77C2233.6,-317.64 2236.02,-320.72 2238,-324 2284.02,-400.19 2241.57,-438.11 2274,-521 2276.04,-526.22 2278.78,-531.49 2281.71,-536.44\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2278.69,-538.21 2287.02,-544.75 2284.58,-534.44 2278.69,-538.21\"/>\n",
       "</g>\n",
       "<!-- 4694227696*&#45;&gt;4694227696 -->\n",
       "<g id=\"edge86\" class=\"edge\">\n",
       "<title>4694227696*&#45;&gt;4694227696</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2113.57,-290C2121.28,-290 2130.01,-290 2138.79,-290\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2138.75,-293.5 2148.75,-290 2138.75,-286.5 2138.75,-293.5\"/>\n",
       "</g>\n",
       "<!-- 4690041616 -->\n",
       "<g id=\"node220\" class=\"node\">\n",
       "<title>4690041616</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"0,-27.5 0,-76.5 85.75,-76.5 85.75,-27.5 0,-27.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"42.88\" y=\"-59.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.798</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"0,-52 85.75,-52\"/>\n",
       "<text text-anchor=\"middle\" x=\"42.88\" y=\"-34.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690041616&#45;&gt;4694224336* -->\n",
       "<g id=\"edge144\" class=\"edge\">\n",
       "<title>4690041616&#45;&gt;4694224336*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M86.12,-52C94.03,-52 102.25,-52 110.01,-52\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"109.82,-55.5 119.82,-52 109.82,-48.5 109.82,-55.5\"/>\n",
       "</g>\n",
       "<!-- 4690041664 -->\n",
       "<g id=\"node221\" class=\"node\">\n",
       "<title>4690041664</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"211.75,-68.5 211.75,-117.5 297.5,-117.5 297.5,-68.5 211.75,-68.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-100.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;6.566</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"211.75,-93 297.5,-93\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-75.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690041664&#45;&gt;4694224432+ -->\n",
       "<g id=\"edge124\" class=\"edge\">\n",
       "<title>4690041664&#45;&gt;4694224432+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M297.84,-71.85C312.98,-64.26 329.76,-55.85 343.83,-48.8\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"345.27,-52 352.64,-44.39 342.13,-45.74 345.27,-52\"/>\n",
       "</g>\n",
       "<!-- 4694227792 -->\n",
       "<g id=\"node222\" class=\"node\">\n",
       "<title>4694227792</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2365.5,-537.5 2365.5,-586.5 2451.25,-586.5 2451.25,-537.5 2365.5,-537.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-569.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.547</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2365.5,-562 2451.25,-562\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-544.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227984+ -->\n",
       "<g id=\"node229\" class=\"node\">\n",
       "<title>4694227984+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"2515.75\" cy=\"-698\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"2515.75\" y=\"-692.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694227792&#45;&gt;4694227984+ -->\n",
       "<g id=\"edge169\" class=\"edge\">\n",
       "<title>4694227792&#45;&gt;4694227984+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2443.6,-586.86C2446.84,-589.78 2449.95,-592.85 2452.75,-596 2472.99,-618.8 2490.45,-649.09 2501.63,-670.72\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2498.44,-672.16 2506.07,-679.52 2504.69,-669.01 2498.44,-672.16\"/>\n",
       "</g>\n",
       "<!-- 4694227792+&#45;&gt;4694227792 -->\n",
       "<g id=\"edge87\" class=\"edge\">\n",
       "<title>4694227792+&#45;&gt;4694227792</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2328.32,-562C2336.03,-562 2344.76,-562 2353.54,-562\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2353.5,-565.5 2363.5,-562 2353.5,-558.5 2353.5,-565.5\"/>\n",
       "</g>\n",
       "<!-- 4694219632 -->\n",
       "<g id=\"node224\" class=\"node\">\n",
       "<title>4694219632</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"211.75,-1085.5 211.75,-1134.5 297.5,-1134.5 297.5,-1085.5 211.75,-1085.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-1117.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.529</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"211.75,-1110 297.5,-1110\"/>\n",
       "<text text-anchor=\"middle\" x=\"254.62\" y=\"-1092.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694219632&#45;&gt;4694213056+ -->\n",
       "<g id=\"edge235\" class=\"edge\">\n",
       "<title>4694219632&#45;&gt;4694213056+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M281.02,-1085.19C302.05,-1064.64 331.68,-1035.69 352.1,-1015.74\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"354.44,-1018.35 359.15,-1008.85 349.55,-1013.34 354.44,-1018.35\"/>\n",
       "</g>\n",
       "<!-- 4694219632*&#45;&gt;4694219632 -->\n",
       "<g id=\"edge88\" class=\"edge\">\n",
       "<title>4694219632*&#45;&gt;4694219632</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M175.96,-1107.01C183.32,-1107.29 191.59,-1107.61 199.93,-1107.93\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"199.61,-1111.42 209.74,-1108.31 199.88,-1104.43 199.61,-1111.42\"/>\n",
       "</g>\n",
       "<!-- 4694227888 -->\n",
       "<g id=\"node226\" class=\"node\">\n",
       "<title>4694227888</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2365.5,-809.5 2365.5,-858.5 2451.25,-858.5 2451.25,-809.5 2365.5,-809.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-841.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.077</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2365.5,-834 2451.25,-834\"/>\n",
       "<text text-anchor=\"middle\" x=\"2408.38\" y=\"-816.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227888&#45;&gt;4694227984+ -->\n",
       "<g id=\"edge141\" class=\"edge\">\n",
       "<title>4694227888&#45;&gt;4694227984+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2443.6,-809.14C2446.84,-806.22 2449.95,-803.15 2452.75,-800 2472.99,-777.2 2490.45,-746.91 2501.63,-725.28\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2504.69,-726.99 2506.07,-716.48 2498.44,-723.84 2504.69,-726.99\"/>\n",
       "</g>\n",
       "<!-- 4694227888*&#45;&gt;4694227888 -->\n",
       "<g id=\"edge89\" class=\"edge\">\n",
       "<title>4694227888*&#45;&gt;4694227888</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2328.32,-834C2336.03,-834 2344.76,-834 2353.54,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2353.5,-837.5 2363.5,-834 2353.5,-830.5 2353.5,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4694227984 -->\n",
       "<g id=\"node228\" class=\"node\">\n",
       "<title>4694227984</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2580.25,-673.5 2580.25,-722.5 2666,-722.5 2666,-673.5 2580.25,-673.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2623.12\" y=\"-705.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;2.624</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2580.25,-698 2666,-698\"/>\n",
       "<text text-anchor=\"middle\" x=\"2623.12\" y=\"-680.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694227984&#45;&gt;4694226592tanh -->\n",
       "<g id=\"edge139\" class=\"edge\">\n",
       "<title>4694227984&#45;&gt;4694226592tanh</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2666.38,-698C2674.69,-698 2683.36,-698 2691.52,-698\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2691.49,-701.5 2701.49,-698 2691.49,-694.5 2691.49,-701.5\"/>\n",
       "</g>\n",
       "<!-- 4694227984+&#45;&gt;4694227984 -->\n",
       "<g id=\"edge90\" class=\"edge\">\n",
       "<title>4694227984+&#45;&gt;4694227984</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2543.07,-698C2550.78,-698 2559.51,-698 2568.29,-698\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2568.25,-701.5 2578.25,-698 2568.25,-694.5 2568.25,-701.5\"/>\n",
       "</g>\n",
       "<!-- 4690041904 -->\n",
       "<g id=\"node230\" class=\"node\">\n",
       "<title>4690041904</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-1013.5 1514,-1062.5 1599.75,-1062.5 1599.75,-1013.5 1514,-1013.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-1045.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.352</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-1038 1599.75,-1038\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-1020.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690041904&#45;&gt;4694224624* -->\n",
       "<g id=\"edge222\" class=\"edge\">\n",
       "<title>4690041904&#45;&gt;4694224624*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1600.12,-1038C1608.03,-1038 1616.25,-1038 1624.01,-1038\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1623.82,-1041.5 1633.82,-1038 1623.82,-1034.5 1623.82,-1041.5\"/>\n",
       "</g>\n",
       "<!-- 4690041952 -->\n",
       "<g id=\"node231\" class=\"node\">\n",
       "<title>4690041952</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-1285.5 1725.75,-1334.5 1811.5,-1334.5 1811.5,-1285.5 1725.75,-1285.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-1317.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;4.582</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-1310 1811.5,-1310\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-1292.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690041952&#45;&gt;4694224720+ -->\n",
       "<g id=\"edge158\" class=\"edge\">\n",
       "<title>4690041952&#45;&gt;4694224720+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1804.03,-1285.38C1806.81,-1282.44 1809.37,-1279.31 1811.5,-1276 1854.23,-1209.61 1867.58,-1114.96 1871.7,-1067.51\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1875.17,-1067.99 1872.46,-1057.75 1868.19,-1067.45 1875.17,-1067.99\"/>\n",
       "</g>\n",
       "<!-- 4694228176 -->\n",
       "<g id=\"node232\" class=\"node\">\n",
       "<title>4694228176</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-1028.5 878.75,-1077.5 964.5,-1077.5 964.5,-1028.5 878.75,-1028.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-1060.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.279</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-1053 964.5,-1053\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-1035.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228176&#45;&gt;4694228272+ -->\n",
       "<g id=\"edge223\" class=\"edge\">\n",
       "<title>4694228176&#45;&gt;4694228272+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M960.71,-1077.93C972.99,-1085.97 986.37,-1094.73 997.84,-1102.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"995.81,-1105.09 1006.09,-1107.64 999.64,-1099.23 995.81,-1105.09\"/>\n",
       "</g>\n",
       "<!-- 4694228176*&#45;&gt;4694228176 -->\n",
       "<g id=\"edge91\" class=\"edge\">\n",
       "<title>4694228176*&#45;&gt;4694228176</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M841.9,-1035.57C849.58,-1037.27 858.34,-1039.21 867.16,-1041.16\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"866.29,-1044.55 876.81,-1043.3 867.8,-1037.72 866.29,-1044.55\"/>\n",
       "</g>\n",
       "<!-- 4694228224 -->\n",
       "<g id=\"node234\" class=\"node\">\n",
       "<title>4694228224</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"2793.5,-809.5 2793.5,-858.5 2879.25,-858.5 2879.25,-809.5 2793.5,-809.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-841.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.996</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"2793.5,-834 2879.25,-834\"/>\n",
       "<text text-anchor=\"middle\" x=\"2836.38\" y=\"-816.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228224&#45;&gt;4694264656* -->\n",
       "<g id=\"edge147\" class=\"edge\">\n",
       "<title>4694228224&#45;&gt;4694264656*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2879.62,-834C2887.53,-834 2895.75,-834 2903.51,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2903.32,-837.5 2913.32,-834 2903.32,-830.5 2903.32,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4694228224tanh&#45;&gt;4694228224 -->\n",
       "<g id=\"edge92\" class=\"edge\">\n",
       "<title>4694228224tanh&#45;&gt;4694228224</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M2757.98,-834C2765.34,-834 2773.6,-834 2781.91,-834\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"2781.69,-837.5 2791.69,-834 2781.69,-830.5 2781.69,-837.5\"/>\n",
       "</g>\n",
       "<!-- 4694228272 -->\n",
       "<g id=\"node236\" class=\"node\">\n",
       "<title>4694228272</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-1096.5 1090.5,-1145.5 1176.25,-1145.5 1176.25,-1096.5 1090.5,-1096.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-1128.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.627</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-1121 1176.25,-1121\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-1103.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228464+ -->\n",
       "<g id=\"node243\" class=\"node\">\n",
       "<title>4694228464+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1239.25\" cy=\"-1038\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1239.25\" y=\"-1032.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694228272&#45;&gt;4694228464+ -->\n",
       "<g id=\"edge196\" class=\"edge\">\n",
       "<title>4694228272&#45;&gt;4694228464+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1165.54,-1096.1C1180.44,-1084.19 1198.08,-1070.1 1212.25,-1058.78\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1214.19,-1061.71 1219.81,-1052.73 1209.82,-1056.24 1214.19,-1061.71\"/>\n",
       "</g>\n",
       "<!-- 4694228272+&#45;&gt;4694228272 -->\n",
       "<g id=\"edge93\" class=\"edge\">\n",
       "<title>4694228272+&#45;&gt;4694228272</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1054.98,-1121C1062.34,-1121 1070.6,-1121 1078.91,-1121\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1078.69,-1124.5 1088.69,-1121 1078.69,-1117.5 1078.69,-1124.5\"/>\n",
       "</g>\n",
       "<!-- 4694228368 -->\n",
       "<g id=\"node238\" class=\"node\">\n",
       "<title>4694228368</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-892.5 1090.5,-941.5 1176.25,-941.5 1176.25,-892.5 1090.5,-892.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-924.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.219</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-917 1176.25,-917\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-899.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228368&#45;&gt;4694228464+ -->\n",
       "<g id=\"edge118\" class=\"edge\">\n",
       "<title>4694228368&#45;&gt;4694228464+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1166.73,-941.76C1170.06,-944.75 1173.3,-947.86 1176.25,-951 1185.99,-961.38 1206.34,-990.59 1221.08,-1012.31\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1218.05,-1014.09 1226.54,-1020.42 1223.85,-1010.17 1218.05,-1014.09\"/>\n",
       "</g>\n",
       "<!-- 4694228368*&#45;&gt;4694228368 -->\n",
       "<g id=\"edge94\" class=\"edge\">\n",
       "<title>4694228368*&#45;&gt;4694228368</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1047.55,-861.47C1058.11,-868.38 1071.75,-877.31 1084.99,-885.98\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1082.96,-888.83 1093.24,-891.38 1086.79,-882.98 1082.96,-888.83\"/>\n",
       "</g>\n",
       "<!-- 4690042288 -->\n",
       "<g id=\"node240\" class=\"node\">\n",
       "<title>4690042288</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"667,-625.5 667,-674.5 752.75,-674.5 752.75,-625.5 667,-625.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-657.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.062</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"667,-650 752.75,-650\"/>\n",
       "<text text-anchor=\"middle\" x=\"709.88\" y=\"-632.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690042288&#45;&gt;4694224912* -->\n",
       "<g id=\"edge279\" class=\"edge\">\n",
       "<title>4690042288&#45;&gt;4694224912*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M753.12,-650C761.03,-650 769.25,-650 777.01,-650\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"776.82,-653.5 786.82,-650 776.82,-646.5 776.82,-653.5\"/>\n",
       "</g>\n",
       "<!-- 4690042336 -->\n",
       "<g id=\"node241\" class=\"node\">\n",
       "<title>4690042336</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-484.5 878.75,-533.5 964.5,-533.5 964.5,-484.5 878.75,-484.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-516.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.883</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-509 964.5,-509\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-491.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690042336&#45;&gt;4694225008+ -->\n",
       "<g id=\"edge264\" class=\"edge\">\n",
       "<title>4690042336&#45;&gt;4694225008+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M964.87,-509C972.78,-509 981,-509 988.76,-509\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"988.57,-512.5 998.57,-509 988.57,-505.5 988.57,-512.5\"/>\n",
       "</g>\n",
       "<!-- 4694228464 -->\n",
       "<g id=\"node242\" class=\"node\">\n",
       "<title>4694228464</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-1013.5 1302.25,-1062.5 1388,-1062.5 1388,-1013.5 1302.25,-1013.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-1045.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.846</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-1038 1388,-1038\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-1020.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228656+ -->\n",
       "<g id=\"node249\" class=\"node\">\n",
       "<title>4694228656+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1451\" cy=\"-970\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1451\" y=\"-964.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694228464&#45;&gt;4694228656+ -->\n",
       "<g id=\"edge270\" class=\"edge\">\n",
       "<title>4694228464&#45;&gt;4694228656+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1384.21,-1013.07C1396.49,-1005.03 1409.87,-996.27 1421.34,-988.76\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1423.14,-991.77 1429.59,-983.36 1419.31,-985.91 1423.14,-991.77\"/>\n",
       "</g>\n",
       "<!-- 4694228464+&#45;&gt;4694228464 -->\n",
       "<g id=\"edge95\" class=\"edge\">\n",
       "<title>4694228464+&#45;&gt;4694228464</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1266.73,-1038C1274.09,-1038 1282.35,-1038 1290.66,-1038\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1290.44,-1041.5 1300.44,-1038 1290.44,-1034.5 1290.44,-1041.5\"/>\n",
       "</g>\n",
       "<!-- 4690042432 -->\n",
       "<g id=\"node244\" class=\"node\">\n",
       "<title>4690042432</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"878.75,-416.5 878.75,-465.5 964.5,-465.5 964.5,-416.5 878.75,-416.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-448.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.656</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"878.75,-441 964.5,-441\"/>\n",
       "<text text-anchor=\"middle\" x=\"921.62\" y=\"-423.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690042432&#45;&gt;4694225104* -->\n",
       "<g id=\"edge283\" class=\"edge\">\n",
       "<title>4690042432&#45;&gt;4694225104*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M964.87,-441C972.78,-441 981,-441 988.76,-441\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"988.57,-444.5 998.57,-441 988.57,-437.5 988.57,-444.5\"/>\n",
       "</g>\n",
       "<!-- 4694228560 -->\n",
       "<g id=\"node245\" class=\"node\">\n",
       "<title>4694228560</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-945.5 1302.25,-994.5 1388,-994.5 1388,-945.5 1302.25,-945.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-977.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.284</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-970 1388,-970\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-952.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228560&#45;&gt;4694228656+ -->\n",
       "<g id=\"edge187\" class=\"edge\">\n",
       "<title>4694228560&#45;&gt;4694228656+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1388.37,-970C1396.28,-970 1404.5,-970 1412.26,-970\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1412.07,-973.5 1422.07,-970 1412.07,-966.5 1412.07,-973.5\"/>\n",
       "</g>\n",
       "<!-- 4694228560*&#45;&gt;4694228560 -->\n",
       "<g id=\"edge96\" class=\"edge\">\n",
       "<title>4694228560*&#45;&gt;4694228560</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1266.73,-970C1274.09,-970 1282.35,-970 1290.66,-970\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1290.44,-973.5 1300.44,-970 1290.44,-966.5 1290.44,-973.5\"/>\n",
       "</g>\n",
       "<!-- 4690042528 -->\n",
       "<g id=\"node247\" class=\"node\">\n",
       "<title>4690042528</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1090.5,-620.5 1090.5,-669.5 1176.25,-669.5 1176.25,-620.5 1090.5,-620.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-652.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.044</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1090.5,-645 1176.25,-645\"/>\n",
       "<text text-anchor=\"middle\" x=\"1133.38\" y=\"-627.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690042528&#45;&gt;4694225296* -->\n",
       "<g id=\"edge247\" class=\"edge\">\n",
       "<title>4690042528&#45;&gt;4694225296*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1172.46,-669.93C1184.74,-677.97 1198.12,-686.73 1209.59,-694.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1207.56,-697.09 1217.84,-699.64 1211.39,-691.23 1207.56,-697.09\"/>\n",
       "</g>\n",
       "<!-- 4694228656 -->\n",
       "<g id=\"node248\" class=\"node\">\n",
       "<title>4694228656</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-877.5 1514,-926.5 1599.75,-926.5 1599.75,-877.5 1514,-877.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-909.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.130</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-902 1599.75,-902\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-884.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228848+ -->\n",
       "<g id=\"node255\" class=\"node\">\n",
       "<title>4694228848+</title>\n",
       "<ellipse fill=\"none\" stroke=\"black\" cx=\"1662.75\" cy=\"-902\" rx=\"27\" ry=\"18\"/>\n",
       "<text text-anchor=\"middle\" x=\"1662.75\" y=\"-896.95\" font-family=\"Times,serif\" font-size=\"14.00\">+</text>\n",
       "</g>\n",
       "<!-- 4694228656&#45;&gt;4694228848+ -->\n",
       "<g id=\"edge156\" class=\"edge\">\n",
       "<title>4694228656&#45;&gt;4694228848+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1600.12,-902C1608.03,-902 1616.25,-902 1624.01,-902\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1623.82,-905.5 1633.82,-902 1623.82,-898.5 1623.82,-905.5\"/>\n",
       "</g>\n",
       "<!-- 4694228656+&#45;&gt;4694228656 -->\n",
       "<g id=\"edge97\" class=\"edge\">\n",
       "<title>4694228656+&#45;&gt;4694228656</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1471.05,-957.53C1481.61,-950.62 1495.25,-941.69 1508.49,-933.02\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1510.29,-936.02 1516.74,-927.62 1506.46,-930.17 1510.29,-936.02\"/>\n",
       "</g>\n",
       "<!-- 4690042624 -->\n",
       "<g id=\"node250\" class=\"node\">\n",
       "<title>4690042624</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1302.25,-129.5 1302.25,-178.5 1388,-178.5 1388,-129.5 1302.25,-129.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-161.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=1.206</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1302.25,-154 1388,-154\"/>\n",
       "<text text-anchor=\"middle\" x=\"1345.12\" y=\"-136.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690042624&#45;&gt;4694225488* -->\n",
       "<g id=\"edge133\" class=\"edge\">\n",
       "<title>4690042624&#45;&gt;4694225488*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1377.5,-178.93C1381.08,-181.94 1384.65,-185 1388,-188 1401.5,-200.07 1415.95,-214.21 1427.5,-225.84\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1424.77,-228.06 1434.29,-232.72 1429.76,-223.14 1424.77,-228.06\"/>\n",
       "</g>\n",
       "<!-- 4694228752 -->\n",
       "<g id=\"node251\" class=\"node\">\n",
       "<title>4694228752</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-673.5 1514,-722.5 1599.75,-722.5 1599.75,-673.5 1514,-673.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-705.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.663</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-698 1599.75,-698\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-680.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228752&#45;&gt;4694228848+ -->\n",
       "<g id=\"edge138\" class=\"edge\">\n",
       "<title>4694228752&#45;&gt;4694228848+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1592.22,-722.66C1595.02,-725.59 1597.59,-728.71 1599.75,-732 1632.39,-781.77 1611.55,-806.62 1635.75,-861 1638.03,-866.12 1640.88,-871.35 1643.85,-876.28\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1640.82,-878.04 1649.15,-884.59 1646.72,-874.28 1640.82,-878.04\"/>\n",
       "</g>\n",
       "<!-- 4694228752*&#45;&gt;4694228752 -->\n",
       "<g id=\"edge98\" class=\"edge\">\n",
       "<title>4694228752*&#45;&gt;4694228752</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1478.48,-698C1485.84,-698 1494.1,-698 1502.41,-698\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1502.19,-701.5 1512.19,-698 1502.19,-694.5 1502.19,-701.5\"/>\n",
       "</g>\n",
       "<!-- 4690042720 -->\n",
       "<g id=\"node253\" class=\"node\">\n",
       "<title>4690042720</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1514,-1119.5 1514,-1168.5 1599.75,-1168.5 1599.75,-1119.5 1514,-1119.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-1151.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.469</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1514,-1144 1599.75,-1144\"/>\n",
       "<text text-anchor=\"middle\" x=\"1556.88\" y=\"-1126.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690042720&#45;&gt;4694225680* -->\n",
       "<g id=\"edge284\" class=\"edge\">\n",
       "<title>4690042720&#45;&gt;4694225680*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1600.12,-1144C1608.03,-1144 1616.25,-1144 1624.01,-1144\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1623.82,-1147.5 1633.82,-1144 1623.82,-1140.5 1623.82,-1147.5\"/>\n",
       "</g>\n",
       "<!-- 4694228848 -->\n",
       "<g id=\"node254\" class=\"node\">\n",
       "<title>4694228848</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-877.5 1725.75,-926.5 1811.5,-926.5 1811.5,-877.5 1725.75,-877.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-909.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;1.792</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-902 1811.5,-902\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-884.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228848&#45;&gt;4694261872+ -->\n",
       "<g id=\"edge209\" class=\"edge\">\n",
       "<title>4694228848&#45;&gt;4694261872+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1811.87,-902C1819.78,-902 1828,-902 1835.76,-902\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1835.57,-905.5 1845.57,-902 1835.57,-898.5 1835.57,-905.5\"/>\n",
       "</g>\n",
       "<!-- 4694228848+&#45;&gt;4694228848 -->\n",
       "<g id=\"edge99\" class=\"edge\">\n",
       "<title>4694228848+&#45;&gt;4694228848</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1690.23,-902C1697.59,-902 1705.85,-902 1714.16,-902\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1713.94,-905.5 1723.94,-902 1713.94,-898.5 1713.94,-905.5\"/>\n",
       "</g>\n",
       "<!-- 4690042816 -->\n",
       "<g id=\"node256\" class=\"node\">\n",
       "<title>4690042816</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-333.5 1725.75,-382.5 1811.5,-382.5 1811.5,-333.5 1725.75,-333.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-365.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.220</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-358 1811.5,-358\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-340.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4690042816&#45;&gt;4694225872* -->\n",
       "<g id=\"edge210\" class=\"edge\">\n",
       "<title>4690042816&#45;&gt;4694225872*</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1807.71,-382.93C1819.99,-390.97 1833.37,-399.73 1844.84,-407.24\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1842.81,-410.09 1853.09,-412.64 1846.64,-404.23 1842.81,-410.09\"/>\n",
       "</g>\n",
       "<!-- 4694228944 -->\n",
       "<g id=\"node257\" class=\"node\">\n",
       "<title>4694228944</title>\n",
       "<polygon fill=\"none\" stroke=\"black\" points=\"1725.75,-1217.5 1725.75,-1266.5 1811.5,-1266.5 1811.5,-1217.5 1725.75,-1217.5\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-1249.2\" font-family=\"Times,serif\" font-size=\"14.00\">data=&#45;0.391</text>\n",
       "<polyline fill=\"none\" stroke=\"black\" points=\"1725.75,-1242 1811.5,-1242\"/>\n",
       "<text text-anchor=\"middle\" x=\"1768.62\" y=\"-1224.7\" font-family=\"Times,serif\" font-size=\"14.00\">grad=0.0000</text>\n",
       "</g>\n",
       "<!-- 4694228944&#45;&gt;4694261872+ -->\n",
       "<g id=\"edge217\" class=\"edge\">\n",
       "<title>4694228944&#45;&gt;4694261872+</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1804.68,-1217.11C1807.26,-1214.27 1809.59,-1211.22 1811.5,-1208 1856.86,-1131.42 1829.17,-1098.1 1847.5,-1011 1853.24,-983.73 1860.7,-952.85 1866.15,-930.93\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1869.47,-932.08 1868.51,-921.53 1862.68,-930.38 1869.47,-932.08\"/>\n",
       "</g>\n",
       "<!-- 4694228944*&#45;&gt;4694228944 -->\n",
       "<g id=\"edge100\" class=\"edge\">\n",
       "<title>4694228944*&#45;&gt;4694228944</title>\n",
       "<path fill=\"none\" stroke=\"black\" d=\"M1689.43,-1254.8C1696.95,-1253.57 1705.46,-1252.17 1714.04,-1250.77\"/>\n",
       "<polygon fill=\"black\" stroke=\"black\" points=\"1714.47,-1254.25 1723.77,-1249.18 1713.34,-1247.34 1714.47,-1254.25\"/>\n",
       "</g>\n",
       "</g>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<graphviz.graphs.Digraph at 0x117cc2320>"
      ]
     },
     "execution_count": 8,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "x = Node(1.0)\n",
    "pred = model([x])\n",
    "draw_graph(pred)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "a97e57cc",
   "metadata": {
    "papermill": {
     "duration": 0.013944,
     "end_time": "2024-09-05T18:33:18.052327",
     "exception": false,
     "start_time": "2024-09-05T18:33:18.038383",
     "status": "completed"
    },
    "tags": []
   },
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": ".venv",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.10.4"
  },
  "papermill": {
   "default_parameters": {},
   "duration": 31.25072,
   "end_time": "2024-09-05T18:33:20.688843",
   "environment_variables": {},
   "exception": null,
   "input_path": "00d-network-training.ipynb",
   "output_path": "00d-network-training.ipynb",
   "parameters": {},
   "start_time": "2024-09-05T18:32:49.438123",
   "version": "2.6.0"
  },
  "widgets": {
   "application/vnd.jupyter.widget-state+json": {
    "state": {
     "051e81cecf0c4d2a8701460eb2af7223": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "2.0.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "2.0.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "2.0.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border_bottom": null,
       "border_left": null,
       "border_right": null,
       "border_top": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "25633724fc924d52bb59798f7a7b3be0": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "2.0.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "2.0.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "2.0.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_allow_html": false,
       "layout": "IPY_MODEL_051e81cecf0c4d2a8701460eb2af7223",
       "placeholder": "​",
       "style": "IPY_MODEL_f0c92d0622a44e7eb442b69d1c7040cd",
       "tabbable": null,
       "tooltip": null,
       "value": "100%"
      }
     },
     "38bf0278ca6d43a8919960e560ea054d": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "2.0.0",
      "model_name": "FloatProgressModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "2.0.0",
       "_model_name": "FloatProgressModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "2.0.0",
       "_view_name": "ProgressView",
       "bar_style": "success",
       "description": "",
       "description_allow_html": false,
       "layout": "IPY_MODEL_c04e547283dd461f83ebaa9c9ea31a75",
       "max": 50,
       "min": 0,
       "orientation": "horizontal",
       "style": "IPY_MODEL_ac23b661a2d64602842c2fdd1cd5eaac",
       "tabbable": null,
       "tooltip": null,
       "value": 50
      }
     },
     "7e698575ca234ae2b57fd15175181160": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "2.0.0",
      "model_name": "HBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "2.0.0",
       "_model_name": "HBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "2.0.0",
       "_view_name": "HBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_25633724fc924d52bb59798f7a7b3be0",
        "IPY_MODEL_38bf0278ca6d43a8919960e560ea054d",
        "IPY_MODEL_a6952fb9d5a243258dbf3eae7995cfaa"
       ],
       "layout": "IPY_MODEL_be5fc7b26bd54cb794de7635af23662c",
       "tabbable": null,
       "tooltip": null
      }
     },
     "a6952fb9d5a243258dbf3eae7995cfaa": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "2.0.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "2.0.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "2.0.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_allow_html": false,
       "layout": "IPY_MODEL_e0b2e3968fff4c83864f9d93bc60a9d7",
       "placeholder": "​",
       "style": "IPY_MODEL_ee853b99d039402796c0092358755f9b",
       "tabbable": null,
       "tooltip": null,
       "value": " 50/50 [00:25&lt;00:00,  2.03it/s]"
      }
     },
     "ac23b661a2d64602842c2fdd1cd5eaac": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "2.0.0",
      "model_name": "ProgressStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "2.0.0",
       "_model_name": "ProgressStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "2.0.0",
       "_view_name": "StyleView",
       "bar_color": null,
       "description_width": ""
      }
     },
     "be5fc7b26bd54cb794de7635af23662c": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "2.0.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "2.0.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "2.0.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border_bottom": null,
       "border_left": null,
       "border_right": null,
       "border_top": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "c04e547283dd461f83ebaa9c9ea31a75": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "2.0.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "2.0.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "2.0.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border_bottom": null,
       "border_left": null,
       "border_right": null,
       "border_top": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "e0b2e3968fff4c83864f9d93bc60a9d7": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "2.0.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "2.0.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "2.0.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border_bottom": null,
       "border_left": null,
       "border_right": null,
       "border_top": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "ee853b99d039402796c0092358755f9b": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "2.0.0",
      "model_name": "HTMLStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "2.0.0",
       "_model_name": "HTMLStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "2.0.0",
       "_view_name": "StyleView",
       "background": null,
       "description_width": "",
       "font_size": null,
       "text_color": null
      }
     },
     "f0c92d0622a44e7eb442b69d1c7040cd": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "2.0.0",
      "model_name": "HTMLStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "2.0.0",
       "_model_name": "HTMLStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "2.0.0",
       "_view_name": "StyleView",
       "background": null,
       "description_width": "",
       "font_size": null,
       "text_color": null
      }
     }
    },
    "version_major": 2,
    "version_minor": 0
   }
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
